@font-face {
  font-family: 'Simple Icons';
  src: url(SimpleIcons.woff) format('woff'),
    url(SimpleIcons.woff2) format('woff2'),
    url(SimpleIcons.ttf) format('truetype'),
    url(SimpleIcons.otf) format('opentype'),
    url(SimpleIcons.eot) format('embedded-opentype');
}

.si {
  font-style: normal;
  font-family: 'Simple Icons', sans-serif;
}

.si-42::before { content: "\ea01"; }
.si-42.si--color::before { color: #000000; }
.si-e::before { content: "\ea02"; }
.si-e.si--color::before { color: #000000; }
.si-dotnet::before { content: "\ea03"; }
.si-dotnet.si--color::before { color: #512BD4; }
.si-1001tracklists::before { content: "\ea04"; }
.si-1001tracklists.si--color::before { color: #40AEF0; }
.si-1password::before { content: "\ea05"; }
.si-1password.si--color::before { color: #0094F5; }
.si-3m::before { content: "\ea06"; }
.si-3m.si--color::before { color: #FF0000; }
.si-4chan::before { content: "\ea07"; }
.si-4chan.si--color::before { color: #006600; }
.si-4d::before { content: "\ea08"; }
.si-4d.si--color::before { color: #004088; }
.si-500px::before { content: "\ea09"; }
.si-500px.si--color::before { color: #0099E5; }
.si-aframe::before { content: "\ea0a"; }
.si-aframe.si--color::before { color: #EF2D5E; }
.si-abbrobotstudio::before { content: "\ea0b"; }
.si-abbrobotstudio.si--color::before { color: #FF9E0F; }
.si-abbvie::before { content: "\ea0c"; }
.si-abbvie.si--color::before { color: #071D49; }
.si-abbott::before { content: "\ea0d"; }
.si-abbott.si--color::before { color: #008FC7; }
.si-abletonlive::before { content: "\ea0e"; }
.si-abletonlive.si--color::before { color: #000000; }
.si-aboutdotme::before { content: "\ea0f"; }
.si-aboutdotme.si--color::before { color: #00A98F; }
.si-abstract::before { content: "\ea10"; }
.si-abstract.si--color::before { color: #191A1B; }
.si-academia::before { content: "\ea11"; }
.si-academia.si--color::before { color: #41454A; }
.si-accenture::before { content: "\ea12"; }
.si-accenture.si--color::before { color: #A100FF; }
.si-acclaim::before { content: "\ea13"; }
.si-acclaim.si--color::before { color: #26689A; }
.si-accusoft::before { content: "\ea14"; }
.si-accusoft.si--color::before { color: #A9225C; }
.si-acm::before { content: "\ea15"; }
.si-acm.si--color::before { color: #0085CA; }
.si-acer::before { content: "\ea16"; }
.si-acer.si--color::before { color: #83B81A; }
.si-actigraph::before { content: "\ea17"; }
.si-actigraph.si--color::before { color: #0B2C4A; }
.si-activision::before { content: "\ea18"; }
.si-activision.si--color::before { color: #000000; }
.si-adafruit::before { content: "\ea19"; }
.si-adafruit.si--color::before { color: #000000; }
.si-adblock::before { content: "\ea1a"; }
.si-adblock.si--color::before { color: #F40D12; }
.si-adblockplus::before { content: "\ea1b"; }
.si-adblockplus.si--color::before { color: #C70D2C; }
.si-adguard::before { content: "\ea1c"; }
.si-adguard.si--color::before { color: #68BC71; }
.si-addthis::before { content: "\ea1d"; }
.si-addthis.si--color::before { color: #FF6550; }
.si-adidas::before { content: "\ea1e"; }
.si-adidas.si--color::before { color: #000000; }
.si-adobe::before { content: "\ea1f"; }
.si-adobe.si--color::before { color: #FF0000; }
.si-adobeacrobatreader::before { content: "\ea20"; }
.si-adobeacrobatreader.si--color::before { color: #EC1C24; }
.si-adobeaftereffects::before { content: "\ea21"; }
.si-adobeaftereffects.si--color::before { color: #9999FF; }
.si-adobeaudition::before { content: "\ea22"; }
.si-adobeaudition.si--color::before { color: #9999FF; }
.si-adobecreativecloud::before { content: "\ea23"; }
.si-adobecreativecloud.si--color::before { color: #DA1F26; }
.si-adobedreamweaver::before { content: "\ea24"; }
.si-adobedreamweaver.si--color::before { color: #FF61F6; }
.si-adobefonts::before { content: "\ea25"; }
.si-adobefonts.si--color::before { color: #000B1D; }
.si-adobeillustrator::before { content: "\ea26"; }
.si-adobeillustrator.si--color::before { color: #FF9A00; }
.si-adobeindesign::before { content: "\ea27"; }
.si-adobeindesign.si--color::before { color: #FF3366; }
.si-adobelightroom::before { content: "\ea28"; }
.si-adobelightroom.si--color::before { color: #31A8FF; }
.si-adobelightroomclassic::before { content: "\ea29"; }
.si-adobelightroomclassic.si--color::before { color: #31A8FF; }
.si-adobephotoshop::before { content: "\ea2a"; }
.si-adobephotoshop.si--color::before { color: #31A8FF; }
.si-adobepremierepro::before { content: "\ea2b"; }
.si-adobepremierepro.si--color::before { color: #9999FF; }
.si-adobexd::before { content: "\ea2c"; }
.si-adobexd.si--color::before { color: #FF61F6; }
.si-adonisjs::before { content: "\ea2d"; }
.si-adonisjs.si--color::before { color: #220052; }
.si-adyen::before { content: "\ea2e"; }
.si-adyen.si--color::before { color: #0ABF53; }
.si-aerlingus::before { content: "\ea2f"; }
.si-aerlingus.si--color::before { color: #006272; }
.si-aeromexico::before { content: "\ea30"; }
.si-aeromexico.si--color::before { color: #0B2343; }
.si-aeroflot::before { content: "\ea31"; }
.si-aeroflot.si--color::before { color: #02458D; }
.si-aerospike::before { content: "\ea32"; }
.si-aerospike.si--color::before { color: #C41E25; }
.si-aew::before { content: "\ea33"; }
.si-aew.si--color::before { color: #000000; }
.si-affinity::before { content: "\ea34"; }
.si-affinity.si--color::before { color: #222324; }
.si-affinityphoto::before { content: "\ea35"; }
.si-affinityphoto.si--color::before { color: #7E4DD2; }
.si-affinitydesigner::before { content: "\ea36"; }
.si-affinitydesigner.si--color::before { color: #1B72BE; }
.si-affinitypublisher::before { content: "\ea37"; }
.si-affinitypublisher.si--color::before { color: #C9284D; }
.si-aidungeon::before { content: "\ea38"; }
.si-aidungeon.si--color::before { color: #000000; }
.si-aib::before { content: "\ea39"; }
.si-aib.si--color::before { color: #7F2B7B; }
.si-aiohttp::before { content: "\ea3a"; }
.si-aiohttp.si--color::before { color: #2C5BB4; }
.si-aiqfome::before { content: "\ea3b"; }
.si-aiqfome.si--color::before { color: #7A1FA2; }
.si-aircanada::before { content: "\ea3c"; }
.si-aircanada.si--color::before { color: #F01428; }
.si-airchina::before { content: "\ea3d"; }
.si-airchina.si--color::before { color: #E30E17; }
.si-airfrance::before { content: "\ea3e"; }
.si-airfrance.si--color::before { color: #002157; }
.si-airasia::before { content: "\ea3f"; }
.si-airasia.si--color::before { color: #FF0000; }
.si-airbnb::before { content: "\ea40"; }
.si-airbnb.si--color::before { color: #FF5A5F; }
.si-airbus::before { content: "\ea41"; }
.si-airbus.si--color::before { color: #00205B; }
.si-aircall::before { content: "\ea42"; }
.si-aircall.si--color::before { color: #00B388; }
.si-airplayaudio::before { content: "\ea43"; }
.si-airplayaudio.si--color::before { color: #000000; }
.si-airplayvideo::before { content: "\ea44"; }
.si-airplayvideo.si--color::before { color: #000000; }
.si-airtable::before { content: "\ea45"; }
.si-airtable.si--color::before { color: #18BFFF; }
.si-ajv::before { content: "\ea46"; }
.si-ajv.si--color::before { color: #23C8D2; }
.si-albertheijn::before { content: "\ea47"; }
.si-albertheijn.si--color::before { color: #04ACE6; }
.si-alacritty::before { content: "\ea48"; }
.si-alacritty.si--color::before { color: #F46D01; }
.si-aldinord::before { content: "\ea49"; }
.si-aldinord.si--color::before { color: #2490D7; }
.si-aldisud::before { content: "\ea4a"; }
.si-aldisud.si--color::before { color: #00005F; }
.si-alfaromeo::before { content: "\ea4b"; }
.si-alfaromeo.si--color::before { color: #981E32; }
.si-alfred::before { content: "\ea4c"; }
.si-alfred.si--color::before { color: #5C1F87; }
.si-algolia::before { content: "\ea4d"; }
.si-algolia.si--color::before { color: #5468FF; }
.si-alibabacloud::before { content: "\ea4e"; }
.si-alibabacloud.si--color::before { color: #FF6A00; }
.si-alibabadotcom::before { content: "\ea4f"; }
.si-alibabadotcom.si--color::before { color: #FF6A00; }
.si-aliexpress::before { content: "\ea50"; }
.si-aliexpress.si--color::before { color: #FF4747; }
.si-alitalia::before { content: "\ea51"; }
.si-alitalia.si--color::before { color: #006643; }
.si-alipay::before { content: "\ea52"; }
.si-alipay.si--color::before { color: #00A1E9; }
.si-allegro::before { content: "\ea53"; }
.si-allegro.si--color::before { color: #FF5A00; }
.si-alliedmodders::before { content: "\ea54"; }
.si-alliedmodders.si--color::before { color: #1578D3; }
.si-allocine::before { content: "\ea55"; }
.si-allocine.si--color::before { color: #FECC00; }
.si-alltrails::before { content: "\ea56"; }
.si-alltrails.si--color::before { color: #428813; }
.si-alpinelinux::before { content: "\ea57"; }
.si-alpinelinux.si--color::before { color: #0D597F; }
.si-alpinedotjs::before { content: "\ea58"; }
.si-alpinedotjs.si--color::before { color: #8BC0D0; }
.si-amazon::before { content: "\ea59"; }
.si-amazon.si--color::before { color: #FF9900; }
.si-altiumdesigner::before { content: "\ea5a"; }
.si-altiumdesigner.si--color::before { color: #A5915F; }
.si-amazonalexa::before { content: "\ea5b"; }
.si-amazonalexa.si--color::before { color: #00CAFF; }
.si-amazonaws::before { content: "\ea5c"; }
.si-amazonaws.si--color::before { color: #232F3E; }
.si-amazondynamodb::before { content: "\ea5d"; }
.si-amazondynamodb.si--color::before { color: #4053D6; }
.si-amazonfiretv::before { content: "\ea5e"; }
.si-amazonfiretv.si--color::before { color: #FC4C02; }
.si-amazonlumberyard::before { content: "\ea5f"; }
.si-amazonlumberyard.si--color::before { color: #66459B; }
.si-amazonpay::before { content: "\ea60"; }
.si-amazonpay.si--color::before { color: #FF9900; }
.si-amazonprime::before { content: "\ea61"; }
.si-amazonprime.si--color::before { color: #00A8E1; }
.si-amazons3::before { content: "\ea62"; }
.si-amazons3.si--color::before { color: #569A31; }
.si-amd::before { content: "\ea63"; }
.si-amd.si--color::before { color: #ED1C24; }
.si-americanairlines::before { content: "\ea64"; }
.si-americanairlines.si--color::before { color: #0078D2; }
.si-americanexpress::before { content: "\ea65"; }
.si-americanexpress.si--color::before { color: #2E77BC; }
.si-amg::before { content: "\ea66"; }
.si-amg.si--color::before { color: #000000; }
.si-amp::before { content: "\ea67"; }
.si-amp.si--color::before { color: #005AF0; }
.si-amul::before { content: "\ea68"; }
.si-amul.si--color::before { color: #ED1D24; }
.si-ana::before { content: "\ea69"; }
.si-ana.si--color::before { color: #13448F; }
.si-analogue::before { content: "\ea6a"; }
.si-analogue.si--color::before { color: #1A1A1A; }
.si-anaconda::before { content: "\ea6b"; }
.si-anaconda.si--color::before { color: #44A833; }
.si-anchor::before { content: "\ea6c"; }
.si-anchor.si--color::before { color: #5000B9; }
.si-andela::before { content: "\ea6d"; }
.si-andela.si--color::before { color: #3359DF; }
.si-android::before { content: "\ea6e"; }
.si-android.si--color::before { color: #3DDC84; }
.si-angular::before { content: "\ea6f"; }
.si-angular.si--color::before { color: #DD0031; }
.si-angularuniversal::before { content: "\ea70"; }
.si-angularuniversal.si--color::before { color: #00ACC1; }
.si-angularjs::before { content: "\ea71"; }
.si-angularjs.si--color::before { color: #E23237; }
.si-anilist::before { content: "\ea72"; }
.si-anilist.si--color::before { color: #02A9FF; }
.si-ansible::before { content: "\ea73"; }
.si-ansible.si--color::before { color: #EE0000; }
.si-ansys::before { content: "\ea74"; }
.si-ansys.si--color::before { color: #FFB71B; }
.si-antdesign::before { content: "\ea75"; }
.si-antdesign.si--color::before { color: #0170FE; }
.si-anta::before { content: "\ea76"; }
.si-anta.si--color::before { color: #D70010; }
.si-antena3::before { content: "\ea77"; }
.si-antena3.si--color::before { color: #FF7328; }
.si-anydesk::before { content: "\ea78"; }
.si-anydesk.si--color::before { color: #EF443B; }
.si-aol::before { content: "\ea79"; }
.si-aol.si--color::before { color: #3399FF; }
.si-apache::before { content: "\ea7a"; }
.si-apache.si--color::before { color: #D22128; }
.si-apacheairflow::before { content: "\ea7b"; }
.si-apacheairflow.si--color::before { color: #017CEE; }
.si-apacheant::before { content: "\ea7c"; }
.si-apacheant.si--color::before { color: #A81C7D; }
.si-apachecassandra::before { content: "\ea7d"; }
.si-apachecassandra.si--color::before { color: #1287B1; }
.si-apachecloudstack::before { content: "\ea7e"; }
.si-apachecloudstack.si--color::before { color: #2AA5DC; }
.si-apachecordova::before { content: "\ea7f"; }
.si-apachecordova.si--color::before { color: #E8E8E8; }
.si-apachecouchdb::before { content: "\ea80"; }
.si-apachecouchdb.si--color::before { color: #E42528; }
.si-apachedruid::before { content: "\ea81"; }
.si-apachedruid.si--color::before { color: #29F1FB; }
.si-apacheecharts::before { content: "\ea82"; }
.si-apacheecharts.si--color::before { color: #AA344D; }
.si-apacheflink::before { content: "\ea83"; }
.si-apacheflink.si--color::before { color: #E6526F; }
.si-apachehadoop::before { content: "\ea84"; }
.si-apachehadoop.si--color::before { color: #66CCFF; }
.si-apachegroovy::before { content: "\ea85"; }
.si-apachegroovy.si--color::before { color: #4298B8; }
.si-apachehive::before { content: "\ea86"; }
.si-apachehive.si--color::before { color: #FDEE21; }
.si-apachejmeter::before { content: "\ea87"; }
.si-apachejmeter.si--color::before { color: #D22128; }
.si-apachekafka::before { content: "\ea88"; }
.si-apachekafka.si--color::before { color: #231F20; }
.si-apachekylin::before { content: "\ea89"; }
.si-apachekylin.si--color::before { color: #F09D13; }
.si-apachemaven::before { content: "\ea8a"; }
.si-apachemaven.si--color::before { color: #C71A36; }
.si-apachenetbeanside::before { content: "\ea8b"; }
.si-apachenetbeanside.si--color::before { color: #1B6AC6; }
.si-apacheopenoffice::before { content: "\ea8c"; }
.si-apacheopenoffice.si--color::before { color: #0E85CD; }
.si-apachepulsar::before { content: "\ea8d"; }
.si-apachepulsar.si--color::before { color: #188FFF; }
.si-apacherocketmq::before { content: "\ea8e"; }
.si-apacherocketmq.si--color::before { color: #D77310; }
.si-apachesolr::before { content: "\ea8f"; }
.si-apachesolr.si--color::before { color: #D9411E; }
.si-apachespark::before { content: "\ea90"; }
.si-apachespark.si--color::before { color: #E25A1C; }
.si-apachetomcat::before { content: "\ea91"; }
.si-apachetomcat.si--color::before { color: #F8DC75; }
.si-aparat::before { content: "\ea92"; }
.si-aparat.si--color::before { color: #ED145B; }
.si-apollographql::before { content: "\ea93"; }
.si-apollographql.si--color::before { color: #311C87; }
.si-apostrophe::before { content: "\ea94"; }
.si-apostrophe.si--color::before { color: #6236FF; }
.si-appannie::before { content: "\ea95"; }
.si-appannie.si--color::before { color: #0F2346; }
.si-appstore::before { content: "\ea96"; }
.si-appstore.si--color::before { color: #0D96F6; }
.si-appian::before { content: "\ea97"; }
.si-appian.si--color::before { color: #2322F0; }
.si-apple::before { content: "\ea98"; }
.si-apple.si--color::before { color: #000000; }
.si-applearcade::before { content: "\ea99"; }
.si-applearcade.si--color::before { color: #000000; }
.si-applemusic::before { content: "\ea9a"; }
.si-applemusic.si--color::before { color: #FA243C; }
.si-applepay::before { content: "\ea9b"; }
.si-applepay.si--color::before { color: #000000; }
.si-applepodcasts::before { content: "\ea9c"; }
.si-applepodcasts.si--color::before { color: #9933CC; }
.si-appletv::before { content: "\ea9d"; }
.si-appletv.si--color::before { color: #000000; }
.si-appsignal::before { content: "\ea9e"; }
.si-appsignal.si--color::before { color: #21375A; }
.si-appwrite::before { content: "\ea9f"; }
.si-appwrite.si--color::before { color: #F02E65; }
.si-appveyor::before { content: "\eaa0"; }
.si-appveyor.si--color::before { color: #00B3E0; }
.si-aqua::before { content: "\eaa1"; }
.si-aqua.si--color::before { color: #1904DA; }
.si-aral::before { content: "\eaa2"; }
.si-aral.si--color::before { color: #0063CB; }
.si-arangodb::before { content: "\eaa3"; }
.si-arangodb.si--color::before { color: #DDE072; }
.si-archlinux::before { content: "\eaa4"; }
.si-archlinux.si--color::before { color: #1793D1; }
.si-archicad::before { content: "\eaa5"; }
.si-archicad.si--color::before { color: #2D50A5; }
.si-archiveofourown::before { content: "\eaa6"; }
.si-archiveofourown.si--color::before { color: #990000; }
.si-ardour::before { content: "\eaa7"; }
.si-ardour.si--color::before { color: #C61C3E; }
.si-arduino::before { content: "\eaa8"; }
.si-arduino.si--color::before { color: #00979D; }
.si-argos::before { content: "\eaa9"; }
.si-argos.si--color::before { color: #DA291C; }
.si-arkecosystem::before { content: "\eaaa"; }
.si-arkecosystem.si--color::before { color: #C9292C; }
.si-arlo::before { content: "\eaab"; }
.si-arlo.si--color::before { color: #49B48A; }
.si-arm::before { content: "\eaac"; }
.si-arm.si--color::before { color: #0091BD; }
.si-artifacthub::before { content: "\eaad"; }
.si-artifacthub.si--color::before { color: #417598; }
.si-artixlinux::before { content: "\eaae"; }
.si-artixlinux.si--color::before { color: #10A0CC; }
.si-artstation::before { content: "\eaaf"; }
.si-artstation.si--color::before { color: #13AFF0; }
.si-arxiv::before { content: "\eab0"; }
.si-arxiv.si--color::before { color: #B31B1B; }
.si-asana::before { content: "\eab1"; }
.si-asana.si--color::before { color: #273347; }
.si-asciidoctor::before { content: "\eab2"; }
.si-asciidoctor.si--color::before { color: #E40046; }
.si-asciinema::before { content: "\eab3"; }
.si-asciinema.si--color::before { color: #D40000; }
.si-asda::before { content: "\eab4"; }
.si-asda.si--color::before { color: #68A51C; }
.si-aseprite::before { content: "\eab5"; }
.si-aseprite.si--color::before { color: #7D929E; }
.si-askubuntu::before { content: "\eab6"; }
.si-askubuntu.si--color::before { color: #DC461D; }
.si-askfm::before { content: "\eab7"; }
.si-askfm.si--color::before { color: #DB3552; }
.si-assemblyscript::before { content: "\eab8"; }
.si-assemblyscript.si--color::before { color: #007AAC; }
.si-astonmartin::before { content: "\eab9"; }
.si-astonmartin.si--color::before { color: #000000; }
.si-astro::before { content: "\eaba"; }
.si-astro.si--color::before { color: #FF5D01; }
.si-asus::before { content: "\eabb"; }
.si-asus.si--color::before { color: #000000; }
.si-atandt::before { content: "\eabc"; }
.si-atandt.si--color::before { color: #009FDB; }
.si-atari::before { content: "\eabd"; }
.si-atari.si--color::before { color: #E4202E; }
.si-atlassian::before { content: "\eabe"; }
.si-atlassian.si--color::before { color: #0052CC; }
.si-atom::before { content: "\eabf"; }
.si-atom.si--color::before { color: #66595C; }
.si-auchan::before { content: "\eac0"; }
.si-auchan.si--color::before { color: #D6180B; }
.si-audacity::before { content: "\eac1"; }
.si-audacity.si--color::before { color: #0000CC; }
.si-audi::before { content: "\eac2"; }
.si-audi.si--color::before { color: #BB0A30; }
.si-audible::before { content: "\eac3"; }
.si-audible.si--color::before { color: #F8991C; }
.si-audiotechnica::before { content: "\eac4"; }
.si-audiotechnica.si--color::before { color: #000000; }
.si-audioboom::before { content: "\eac5"; }
.si-audioboom.si--color::before { color: #007CE2; }
.si-audiomack::before { content: "\eac6"; }
.si-audiomack.si--color::before { color: #FFA200; }
.si-aurelia::before { content: "\eac7"; }
.si-aurelia.si--color::before { color: #ED2B88; }
.si-auth0::before { content: "\eac8"; }
.si-auth0.si--color::before { color: #EB5424; }
.si-authy::before { content: "\eac9"; }
.si-authy.si--color::before { color: #EC1C24; }
.si-autodesk::before { content: "\eaca"; }
.si-autodesk.si--color::before { color: #0696D7; }
.si-autohotkey::before { content: "\eacb"; }
.si-autohotkey.si--color::before { color: #334455; }
.si-automattic::before { content: "\eacc"; }
.si-automattic.si--color::before { color: #3499CD; }
.si-autoprefixer::before { content: "\eacd"; }
.si-autoprefixer.si--color::before { color: #DD3735; }
.si-avast::before { content: "\eace"; }
.si-avast.si--color::before { color: #FF7800; }
.si-awesomelists::before { content: "\eacf"; }
.si-awesomelists.si--color::before { color: #FC60A8; }
.si-awesomewm::before { content: "\ead0"; }
.si-awesomewm.si--color::before { color: #535D6C; }
.si-awsamplify::before { content: "\ead1"; }
.si-awsamplify.si--color::before { color: #FF9900; }
.si-awslambda::before { content: "\ead2"; }
.si-awslambda.si--color::before { color: #FF9900; }
.si-azureartifacts::before { content: "\ead3"; }
.si-azureartifacts.si--color::before { color: #CB2E6D; }
.si-azuredataexplorer::before { content: "\ead4"; }
.si-azuredataexplorer.si--color::before { color: #0078D4; }
.si-azuredevops::before { content: "\ead5"; }
.si-azuredevops.si--color::before { color: #0078D7; }
.si-azurefunctions::before { content: "\ead6"; }
.si-azurefunctions.si--color::before { color: #0062AD; }
.si-azurepipelines::before { content: "\ead7"; }
.si-azurepipelines.si--color::before { color: #2560E0; }
.si-bandrautomation::before { content: "\ead8"; }
.si-bandrautomation.si--color::before { color: #FF8800; }
.si-babel::before { content: "\ead9"; }
.si-babel.si--color::before { color: #F9DC3E; }
.si-backbonedotjs::before { content: "\eada"; }
.si-backbonedotjs.si--color::before { color: #0071B5; }
.si-badgr::before { content: "\eadb"; }
.si-badgr.si--color::before { color: #282C4C; }
.si-badoo::before { content: "\eadc"; }
.si-badoo.si--color::before { color: #783BF9; }
.si-baidu::before { content: "\eadd"; }
.si-baidu.si--color::before { color: #2932E1; }
.si-bamboo::before { content: "\eade"; }
.si-bamboo.si--color::before { color: #0052CC; }
.si-bandcamp::before { content: "\eadf"; }
.si-bandcamp.si--color::before { color: #408294; }
.si-bandlab::before { content: "\eae0"; }
.si-bandlab.si--color::before { color: #F12C18; }
.si-bandsintown::before { content: "\eae1"; }
.si-bandsintown.si--color::before { color: #00CEC8; }
.si-bankofamerica::before { content: "\eae2"; }
.si-bankofamerica.si--color::before { color: #012169; }
.si-barclays::before { content: "\eae3"; }
.si-barclays.si--color::before { color: #00AEEF; }
.si-baremetrics::before { content: "\eae4"; }
.si-baremetrics.si--color::before { color: #6078FF; }
.si-basecamp::before { content: "\eae5"; }
.si-basecamp.si--color::before { color: #1D2D35; }
.si-bata::before { content: "\eae6"; }
.si-bata.si--color::before { color: #DD282E; }
.si-battledotnet::before { content: "\eae7"; }
.si-battledotnet.si--color::before { color: #148EFF; }
.si-bathasu::before { content: "\eae8"; }
.si-bathasu.si--color::before { color: #00A3E0; }
.si-bbc::before { content: "\eae9"; }
.si-bbc.si--color::before { color: #000000; }
.si-bbciplayer::before { content: "\eaea"; }
.si-bbciplayer.si--color::before { color: #F54997; }
.si-beatport::before { content: "\eaeb"; }
.si-beatport.si--color::before { color: #01FF95; }
.si-beats::before { content: "\eaec"; }
.si-beats.si--color::before { color: #005571; }
.si-beatsbydre::before { content: "\eaed"; }
.si-beatsbydre.si--color::before { color: #E01F3D; }
.si-behance::before { content: "\eaee"; }
.si-behance.si--color::before { color: #1769FF; }
.si-beijingsubway::before { content: "\eaef"; }
.si-beijingsubway.si--color::before { color: #004A9D; }
.si-bem::before { content: "\eaf0"; }
.si-bem.si--color::before { color: #000000; }
.si-bentley::before { content: "\eaf1"; }
.si-bentley.si--color::before { color: #333333; }
.si-betfair::before { content: "\eaf2"; }
.si-betfair.si--color::before { color: #FFB80B; }
.si-bigcartel::before { content: "\eaf3"; }
.si-bigcartel.si--color::before { color: #222222; }
.si-bigbasket::before { content: "\eaf4"; }
.si-bigbasket.si--color::before { color: #A5CD39; }
.si-bigbluebutton::before { content: "\eaf5"; }
.si-bigbluebutton.si--color::before { color: #283274; }
.si-bigcommerce::before { content: "\eaf6"; }
.si-bigcommerce.si--color::before { color: #121118; }
.si-bilibili::before { content: "\eaf7"; }
.si-bilibili.si--color::before { color: #00A1D6; }
.si-binance::before { content: "\eaf8"; }
.si-binance.si--color::before { color: #F0B90B; }
.si-biolink::before { content: "\eaf9"; }
.si-biolink.si--color::before { color: #000000; }
.si-bit::before { content: "\eafa"; }
.si-bit.si--color::before { color: #73398D; }
.si-bitbucket::before { content: "\eafb"; }
.si-bitbucket.si--color::before { color: #0052CC; }
.si-bitcoin::before { content: "\eafc"; }
.si-bitcoin.si--color::before { color: #F7931A; }
.si-bitcoincash::before { content: "\eafd"; }
.si-bitcoincash.si--color::before { color: #0AC18E; }
.si-bitcoinsv::before { content: "\eafe"; }
.si-bitcoinsv.si--color::before { color: #EAB300; }
.si-bitdefender::before { content: "\eaff"; }
.si-bitdefender.si--color::before { color: #ED1C24; }
.si-bitly::before { content: "\eb00"; }
.si-bitly.si--color::before { color: #EE6123; }
.si-bitrise::before { content: "\eb01"; }
.si-bitrise.si--color::before { color: #683D87; }
.si-bitwarden::before { content: "\eb02"; }
.si-bitwarden.si--color::before { color: #175DDC; }
.si-bitwig::before { content: "\eb03"; }
.si-bitwig.si--color::before { color: #FF5A00; }
.si-blackberry::before { content: "\eb04"; }
.si-blackberry.si--color::before { color: #000000; }
.si-blazemeter::before { content: "\eb05"; }
.si-blazemeter.si--color::before { color: #CA2133; }
.si-blazor::before { content: "\eb06"; }
.si-blazor.si--color::before { color: #512BD4; }
.si-blender::before { content: "\eb07"; }
.si-blender.si--color::before { color: #F5792A; }
.si-blockchaindotcom::before { content: "\eb08"; }
.si-blockchaindotcom.si--color::before { color: #121D33; }
.si-blogger::before { content: "\eb09"; }
.si-blogger.si--color::before { color: #FF5722; }
.si-bloglovin::before { content: "\eb0a"; }
.si-bloglovin.si--color::before { color: #000000; }
.si-bluetooth::before { content: "\eb0b"; }
.si-bluetooth.si--color::before { color: #0082FC; }
.si-blueprint::before { content: "\eb0c"; }
.si-blueprint.si--color::before { color: #137CBD; }
.si-bmcsoftware::before { content: "\eb0d"; }
.si-bmcsoftware.si--color::before { color: #FE5000; }
.si-bmw::before { content: "\eb0e"; }
.si-bmw.si--color::before { color: #0066B1; }
.si-boehringeringelheim::before { content: "\eb0f"; }
.si-boehringeringelheim.si--color::before { color: #003366; }
.si-boeing::before { content: "\eb10"; }
.si-boeing.si--color::before { color: #1D439C; }
.si-bookbub::before { content: "\eb11"; }
.si-bookbub.si--color::before { color: #F44336; }
.si-bookmeter::before { content: "\eb12"; }
.si-bookmeter.si--color::before { color: #64BC4B; }
.si-bookstack::before { content: "\eb13"; }
.si-bookstack.si--color::before { color: #0288D1; }
.si-boost::before { content: "\eb14"; }
.si-boost.si--color::before { color: #F7901E; }
.si-boots::before { content: "\eb15"; }
.si-boots.si--color::before { color: #05054B; }
.si-bootstrap::before { content: "\eb16"; }
.si-bootstrap.si--color::before { color: #7952B3; }
.si-bosch::before { content: "\eb17"; }
.si-bosch.si--color::before { color: #EA0016; }
.si-bose::before { content: "\eb18"; }
.si-bose.si--color::before { color: #000000; }
.si-boulanger::before { content: "\eb19"; }
.si-boulanger.si--color::before { color: #FD5300; }
.si-bower::before { content: "\eb1a"; }
.si-bower.si--color::before { color: #EF5734; }
.si-box::before { content: "\eb1b"; }
.si-box.si--color::before { color: #0061D5; }
.si-brave::before { content: "\eb1c"; }
.si-brave.si--color::before { color: #FB542B; }
.si-brandfolder::before { content: "\eb1d"; }
.si-brandfolder.si--color::before { color: #40D1F5; }
.si-breaker::before { content: "\eb1e"; }
.si-breaker.si--color::before { color: #003DAD; }
.si-britishairways::before { content: "\eb1f"; }
.si-britishairways.si--color::before { color: #2E5C99; }
.si-broadcom::before { content: "\eb20"; }
.si-broadcom.si--color::before { color: #CC092F; }
.si-bt::before { content: "\eb21"; }
.si-bt.si--color::before { color: #6400AA; }
.si-buddy::before { content: "\eb22"; }
.si-buddy.si--color::before { color: #1A86FD; }
.si-budibase::before { content: "\eb23"; }
.si-budibase.si--color::before { color: #000000; }
.si-buefy::before { content: "\eb24"; }
.si-buefy.si--color::before { color: #7957D5; }
.si-buffer::before { content: "\eb25"; }
.si-buffer.si--color::before { color: #231F20; }
.si-bugatti::before { content: "\eb26"; }
.si-bugatti.si--color::before { color: #BE0030; }
.si-bugcrowd::before { content: "\eb27"; }
.si-bugcrowd.si--color::before { color: #F26822; }
.si-bugsnag::before { content: "\eb28"; }
.si-bugsnag.si--color::before { color: #4949E4; }
.si-buildkite::before { content: "\eb29"; }
.si-buildkite.si--color::before { color: #14CC80; }
.si-bukalapak::before { content: "\eb2a"; }
.si-bukalapak.si--color::before { color: #E31E52; }
.si-bulma::before { content: "\eb2b"; }
.si-bulma.si--color::before { color: #00D1B2; }
.si-bunq::before { content: "\eb2c"; }
.si-bunq.si--color::before { color: #3394D7; }
.si-burgerking::before { content: "\eb2d"; }
.si-burgerking.si--color::before { color: #D62300; }
.si-buymeacoffee::before { content: "\eb2e"; }
.si-buymeacoffee.si--color::before { color: #FFDD00; }
.si-buzzfeed::before { content: "\eb2f"; }
.si-buzzfeed.si--color::before { color: #EE3322; }
.si-byjus::before { content: "\eb30"; }
.si-byjus.si--color::before { color: #813588; }
.si-byte::before { content: "\eb31"; }
.si-byte.si--color::before { color: #551DEF; }
.si-bytedance::before { content: "\eb32"; }
.si-bytedance.si--color::before { color: #3C8CFF; }
.si-c::before { content: "\eb33"; }
.si-c.si--color::before { color: #A8B9CC; }
.si-csharp::before { content: "\eb34"; }
.si-csharp.si--color::before { color: #239120; }
.si-cplusplus::before { content: "\eb35"; }
.si-cplusplus.si--color::before { color: #00599C; }
.si-cachet::before { content: "\eb36"; }
.si-cachet.si--color::before { color: #7ED321; }
.si-caffeine::before { content: "\eb37"; }
.si-caffeine.si--color::before { color: #0000FF; }
.si-cairometro::before { content: "\eb38"; }
.si-cairometro.si--color::before { color: #C10C0C; }
.si-cakephp::before { content: "\eb39"; }
.si-cakephp.si--color::before { color: #D33C43; }
.si-campaignmonitor::before { content: "\eb3a"; }
.si-campaignmonitor.si--color::before { color: #111324; }
.si-canonical::before { content: "\eb3b"; }
.si-canonical.si--color::before { color: #77216F; }
.si-canva::before { content: "\eb3c"; }
.si-canva.si--color::before { color: #00C4CC; }
.si-capacitor::before { content: "\eb3d"; }
.si-capacitor.si--color::before { color: #119EFF; }
.si-carthrottle::before { content: "\eb3e"; }
.si-carthrottle.si--color::before { color: #FF9C42; }
.si-carrefour::before { content: "\eb3f"; }
.si-carrefour.si--color::before { color: #004E9F; }
.si-carto::before { content: "\eb40"; }
.si-carto.si--color::before { color: #EB1510; }
.si-cashapp::before { content: "\eb41"; }
.si-cashapp.si--color::before { color: #00C244; }
.si-castbox::before { content: "\eb42"; }
.si-castbox.si--color::before { color: #F55B23; }
.si-castorama::before { content: "\eb43"; }
.si-castorama.si--color::before { color: #0078D7; }
.si-castro::before { content: "\eb44"; }
.si-castro.si--color::before { color: #00B265; }
.si-caterpillar::before { content: "\eb45"; }
.si-caterpillar.si--color::before { color: #FFCD11; }
.si-cbs::before { content: "\eb46"; }
.si-cbs.si--color::before { color: #033963; }
.si-cdprojekt::before { content: "\eb47"; }
.si-cdprojekt.si--color::before { color: #DC0D15; }
.si-celery::before { content: "\eb48"; }
.si-celery.si--color::before { color: #37814A; }
.si-centos::before { content: "\eb49"; }
.si-centos.si--color::before { color: #262577; }
.si-ceph::before { content: "\eb4a"; }
.si-ceph.si--color::before { color: #EF5C55; }
.si-cesium::before { content: "\eb4b"; }
.si-cesium.si--color::before { color: #6CADDF; }
.si-chai::before { content: "\eb4c"; }
.si-chai.si--color::before { color: #A30701; }
.si-chainlink::before { content: "\eb4d"; }
.si-chainlink.si--color::before { color: #375BD2; }
.si-chakraui::before { content: "\eb4e"; }
.si-chakraui.si--color::before { color: #319795; }
.si-chartdotjs::before { content: "\eb4f"; }
.si-chartdotjs.si--color::before { color: #FF6384; }
.si-chartmogul::before { content: "\eb50"; }
.si-chartmogul.si--color::before { color: #13324B; }
.si-chase::before { content: "\eb51"; }
.si-chase.si--color::before { color: #117ACA; }
.si-chatbot::before { content: "\eb52"; }
.si-chatbot.si--color::before { color: #FFD000; }
.si-checkio::before { content: "\eb53"; }
.si-checkio.si--color::before { color: #008DB6; }
.si-checkmarx::before { content: "\eb54"; }
.si-checkmarx.si--color::before { color: #54B848; }
.si-chef::before { content: "\eb55"; }
.si-chef.si--color::before { color: #F09820; }
.si-chemex::before { content: "\eb56"; }
.si-chemex.si--color::before { color: #4D2B1A; }
.si-chevrolet::before { content: "\eb57"; }
.si-chevrolet.si--color::before { color: #CD9834; }
.si-chinaeasternairlines::before { content: "\eb58"; }
.si-chinaeasternairlines.si--color::before { color: #1A2477; }
.si-chinasouthernairlines::before { content: "\eb59"; }
.si-chinasouthernairlines.si--color::before { color: #008BCB; }
.si-chromecast::before { content: "\eb5a"; }
.si-chromecast.si--color::before { color: #999999; }
.si-chocolatey::before { content: "\eb5b"; }
.si-chocolatey.si--color::before { color: #80B5E3; }
.si-chrysler::before { content: "\eb5c"; }
.si-chrysler.si--color::before { color: #000000; }
.si-chupachups::before { content: "\eb5d"; }
.si-chupachups.si--color::before { color: #CF103E; }
.si-cilium::before { content: "\eb5e"; }
.si-cilium.si--color::before { color: #F8C517; }
.si-cinema4d::before { content: "\eb5f"; }
.si-cinema4d.si--color::before { color: #011A6A; }
.si-circle::before { content: "\eb60"; }
.si-circle.si--color::before { color: #8669AE; }
.si-circleci::before { content: "\eb61"; }
.si-circleci.si--color::before { color: #343434; }
.si-cirrusci::before { content: "\eb62"; }
.si-cirrusci.si--color::before { color: #4051B5; }
.si-citrix::before { content: "\eb63"; }
.si-citrix.si--color::before { color: #452170; }
.si-cisco::before { content: "\eb64"; }
.si-cisco.si--color::before { color: #1BA0D7; }
.si-citroen::before { content: "\eb65"; }
.si-citroen.si--color::before { color: #6E6E6E; }
.si-civicrm::before { content: "\eb66"; }
.si-civicrm.si--color::before { color: #81C459; }
.si-civo::before { content: "\eb67"; }
.si-civo.si--color::before { color: #239DFF; }
.si-ckeditor4::before { content: "\eb68"; }
.si-ckeditor4.si--color::before { color: #0287D0; }
.si-claris::before { content: "\eb69"; }
.si-claris.si--color::before { color: #000000; }
.si-clickhouse::before { content: "\eb6a"; }
.si-clickhouse.si--color::before { color: #FFCC01; }
.si-clion::before { content: "\eb6b"; }
.si-clion.si--color::before { color: #000000; }
.si-clickup::before { content: "\eb6c"; }
.si-clickup.si--color::before { color: #7B68EE; }
.si-cliqz::before { content: "\eb6d"; }
.si-cliqz.si--color::before { color: #00AEF0; }
.si-clockify::before { content: "\eb6e"; }
.si-clockify.si--color::before { color: #03A9F4; }
.si-clojure::before { content: "\eb6f"; }
.si-clojure.si--color::before { color: #5881D8; }
.si-cloud66::before { content: "\eb70"; }
.si-cloud66.si--color::before { color: #3C72B9; }
.si-cloudfoundry::before { content: "\eb71"; }
.si-cloudfoundry.si--color::before { color: #0C9ED5; }
.si-cloudbees::before { content: "\eb72"; }
.si-cloudbees.si--color::before { color: #1997B5; }
.si-cloudcannon::before { content: "\eb73"; }
.si-cloudcannon.si--color::before { color: #407AFC; }
.si-cloudera::before { content: "\eb74"; }
.si-cloudera.si--color::before { color: #F96702; }
.si-cloudflare::before { content: "\eb75"; }
.si-cloudflare.si--color::before { color: #F38020; }
.si-cloudsmith::before { content: "\eb76"; }
.si-cloudsmith.si--color::before { color: #187EB6; }
.si-cloudways::before { content: "\eb77"; }
.si-cloudways.si--color::before { color: #2C39BD; }
.si-clubhouse::before { content: "\eb78"; }
.si-clubhouse.si--color::before { color: #6515DD; }
.si-clyp::before { content: "\eb79"; }
.si-clyp.si--color::before { color: #3CBDB1; }
.si-cmake::before { content: "\eb7a"; }
.si-cmake.si--color::before { color: #064F8C; }
.si-cncf::before { content: "\eb7b"; }
.si-cncf.si--color::before { color: #231F20; }
.si-cnn::before { content: "\eb7c"; }
.si-cnn.si--color::before { color: #CC0000; }
.si-coop::before { content: "\eb7d"; }
.si-coop.si--color::before { color: #00B1E7; }
.si-cockpit::before { content: "\eb7e"; }
.si-cockpit.si--color::before { color: #0066CC; }
.si-cockroachlabs::before { content: "\eb7f"; }
.si-cockroachlabs.si--color::before { color: #6933FF; }
.si-cocoapods::before { content: "\eb80"; }
.si-cocoapods.si--color::before { color: #EE3322; }
.si-cocos::before { content: "\eb81"; }
.si-cocos.si--color::before { color: #55C2E1; }
.si-coda::before { content: "\eb82"; }
.si-coda.si--color::before { color: #F46A54; }
.si-codacy::before { content: "\eb83"; }
.si-codacy.si--color::before { color: #222F29; }
.si-codeclimate::before { content: "\eb84"; }
.si-codeclimate.si--color::before { color: #000000; }
.si-codereview::before { content: "\eb85"; }
.si-codereview.si--color::before { color: #485A62; }
.si-codeberg::before { content: "\eb86"; }
.si-codeberg.si--color::before { color: #2185D0; }
.si-codecademy::before { content: "\eb87"; }
.si-codecademy.si--color::before { color: #1F4056; }
.si-codeceptjs::before { content: "\eb88"; }
.si-codeceptjs.si--color::before { color: #F6E05E; }
.si-codechef::before { content: "\eb89"; }
.si-codechef.si--color::before { color: #5B4638; }
.si-codecov::before { content: "\eb8a"; }
.si-codecov.si--color::before { color: #F01F7A; }
.si-codefactor::before { content: "\eb8b"; }
.si-codefactor.si--color::before { color: #F44A6A; }
.si-codeforces::before { content: "\eb8c"; }
.si-codeforces.si--color::before { color: #1F8ACB; }
.si-codeigniter::before { content: "\eb8d"; }
.si-codeigniter.si--color::before { color: #EF4223; }
.si-codemagic::before { content: "\eb8e"; }
.si-codemagic.si--color::before { color: #F45E3F; }
.si-codemirror::before { content: "\eb8f"; }
.si-codemirror.si--color::before { color: #D30707; }
.si-codenewbie::before { content: "\eb90"; }
.si-codenewbie.si--color::before { color: #9013FE; }
.si-codeproject::before { content: "\eb91"; }
.si-codeproject.si--color::before { color: #FF9900; }
.si-codepen::before { content: "\eb92"; }
.si-codepen.si--color::before { color: #000000; }
.si-codersrank::before { content: "\eb93"; }
.si-codersrank.si--color::before { color: #67A4AC; }
.si-coderwall::before { content: "\eb94"; }
.si-coderwall.si--color::before { color: #3E8DCC; }
.si-codesandbox::before { content: "\eb95"; }
.si-codesandbox.si--color::before { color: #000000; }
.si-codeship::before { content: "\eb96"; }
.si-codeship.si--color::before { color: #004466; }
.si-codewars::before { content: "\eb97"; }
.si-codewars.si--color::before { color: #B1361E; }
.si-codingninjas::before { content: "\eb98"; }
.si-codingninjas.si--color::before { color: #DD6620; }
.si-codingame::before { content: "\eb99"; }
.si-codingame.si--color::before { color: #F2BB13; }
.si-codio::before { content: "\eb9a"; }
.si-codio.si--color::before { color: #4574E0; }
.si-coffeescript::before { content: "\eb9b"; }
.si-coffeescript.si--color::before { color: #2F2625; }
.si-cognizant::before { content: "\eb9c"; }
.si-cognizant.si--color::before { color: #1A4CA1; }
.si-coil::before { content: "\eb9d"; }
.si-coil.si--color::before { color: #000000; }
.si-coinbase::before { content: "\eb9e"; }
.si-coinbase.si--color::before { color: #0052FF; }
.si-coinmarketcap::before { content: "\eb9f"; }
.si-coinmarketcap.si--color::before { color: #17181B; }
.si-commerzbank::before { content: "\eba0"; }
.si-commerzbank.si--color::before { color: #FFCC33; }
.si-commonworkflowlanguage::before { content: "\eba1"; }
.si-commonworkflowlanguage.si--color::before { color: #B5314C; }
.si-composer::before { content: "\eba2"; }
.si-composer.si--color::before { color: #885630; }
.si-comsol::before { content: "\eba3"; }
.si-comsol.si--color::before { color: #368CCB; }
.si-conan::before { content: "\eba4"; }
.si-conan.si--color::before { color: #6699CB; }
.si-concourse::before { content: "\eba5"; }
.si-concourse.si--color::before { color: #3398DC; }
.si-condaforge::before { content: "\eba6"; }
.si-condaforge.si--color::before { color: #000000; }
.si-conekta::before { content: "\eba7"; }
.si-conekta.si--color::before { color: #0A1837; }
.si-confluence::before { content: "\eba8"; }
.si-confluence.si--color::before { color: #172B4D; }
.si-construct3::before { content: "\eba9"; }
.si-construct3.si--color::before { color: #00FFDA; }
.si-consul::before { content: "\ebaa"; }
.si-consul.si--color::before { color: #F24C53; }
.si-contactlesspayment::before { content: "\ebab"; }
.si-contactlesspayment.si--color::before { color: #000000; }
.si-containerd::before { content: "\ebac"; }
.si-containerd.si--color::before { color: #575757; }
.si-contentful::before { content: "\ebad"; }
.si-contentful.si--color::before { color: #2478CC; }
.si-conventionalcommits::before { content: "\ebae"; }
.si-conventionalcommits.si--color::before { color: #FE5196; }
.si-convertio::before { content: "\ebaf"; }
.si-convertio.si--color::before { color: #FF3333; }
.si-cookiecutter::before { content: "\ebb0"; }
.si-cookiecutter.si--color::before { color: #D4AA00; }
.si-cora::before { content: "\ebb1"; }
.si-cora.si--color::before { color: #E61845; }
.si-coronaengine::before { content: "\ebb2"; }
.si-coronaengine.si--color::before { color: #F96F29; }
.si-coronarenderer::before { content: "\ebb3"; }
.si-coronarenderer.si--color::before { color: #E6502A; }
.si-corsair::before { content: "\ebb4"; }
.si-corsair.si--color::before { color: #000000; }
.si-couchbase::before { content: "\ebb5"; }
.si-couchbase.si--color::before { color: #EA2328; }
.si-counterstrike::before { content: "\ebb6"; }
.si-counterstrike.si--color::before { color: #000000; }
.si-countingworkspro::before { content: "\ebb7"; }
.si-countingworkspro.si--color::before { color: #2E3084; }
.si-coursera::before { content: "\ebb8"; }
.si-coursera.si--color::before { color: #0056D2; }
.si-coveralls::before { content: "\ebb9"; }
.si-coveralls.si--color::before { color: #3F5767; }
.si-cpanel::before { content: "\ebba"; }
.si-cpanel.si--color::before { color: #FF6C2C; }
.si-cratedb::before { content: "\ebbb"; }
.si-cratedb.si--color::before { color: #009DC7; }
.si-craftcms::before { content: "\ebbc"; }
.si-craftcms.si--color::before { color: #E5422B; }
.si-createreactapp::before { content: "\ebbd"; }
.si-createreactapp.si--color::before { color: #09D3AC; }
.si-creativecommons::before { content: "\ebbe"; }
.si-creativecommons.si--color::before { color: #EF9421; }
.si-credly::before { content: "\ebbf"; }
.si-credly.si--color::before { color: #FF6B00; }
.si-crehana::before { content: "\ebc0"; }
.si-crehana.si--color::before { color: #4B22F4; }
.si-crowdin::before { content: "\ebc1"; }
.si-crowdin.si--color::before { color: #2E3340; }
.si-crowdsource::before { content: "\ebc2"; }
.si-crowdsource.si--color::before { color: #4285F4; }
.si-crunchbase::before { content: "\ebc3"; }
.si-crunchbase.si--color::before { color: #0288D1; }
.si-crunchyroll::before { content: "\ebc4"; }
.si-crunchyroll.si--color::before { color: #F47521; }
.si-cryengine::before { content: "\ebc5"; }
.si-cryengine.si--color::before { color: #000000; }
.si-crystal::before { content: "\ebc6"; }
.si-crystal.si--color::before { color: #000000; }
.si-cssmodules::before { content: "\ebc7"; }
.si-cssmodules.si--color::before { color: #000000; }
.si-csswizardry::before { content: "\ebc8"; }
.si-csswizardry.si--color::before { color: #F43059; }
.si-css3::before { content: "\ebc9"; }
.si-css3.si--color::before { color: #1572B6; }
.si-cucumber::before { content: "\ebca"; }
.si-cucumber.si--color::before { color: #23D96C; }
.si-curl::before { content: "\ebcb"; }
.si-curl.si--color::before { color: #073551; }
.si-curseforge::before { content: "\ebcc"; }
.si-curseforge.si--color::before { color: #6441A4; }
.si-cycling74::before { content: "\ebcd"; }
.si-cycling74.si--color::before { color: #111111; }
.si-cypress::before { content: "\ebce"; }
.si-cypress.si--color::before { color: #17202C; }
.si-cytoscapedotjs::before { content: "\ebcf"; }
.si-cytoscapedotjs.si--color::before { color: #F7DF1E; }
.si-dedge::before { content: "\ebd0"; }
.si-dedge.si--color::before { color: #432975; }
.si-dwavesystems::before { content: "\ebd1"; }
.si-dwavesystems.si--color::before { color: #008CD7; }
.si-d3dotjs::before { content: "\ebd2"; }
.si-d3dotjs.si--color::before { color: #F9A03C; }
.si-dacia::before { content: "\ebd3"; }
.si-dacia.si--color::before { color: #122AFF; }
.si-daf::before { content: "\ebd4"; }
.si-daf.si--color::before { color: #00529B; }
.si-dailymotion::before { content: "\ebd5"; }
.si-dailymotion.si--color::before { color: #0D0D0D; }
.si-daimler::before { content: "\ebd6"; }
.si-daimler.si--color::before { color: #E6E6E6; }
.si-darkreader::before { content: "\ebd7"; }
.si-darkreader.si--color::before { color: #141E24; }
.si-dart::before { content: "\ebd8"; }
.si-dart.si--color::before { color: #0175C2; }
.si-darty::before { content: "\ebd9"; }
.si-darty.si--color::before { color: #EB1B23; }
.si-daserste::before { content: "\ebda"; }
.si-daserste.si--color::before { color: #001A4B; }
.si-dash::before { content: "\ebdb"; }
.si-dash.si--color::before { color: #008DE4; }
.si-dashlane::before { content: "\ebdc"; }
.si-dashlane.si--color::before { color: #0E353D; }
.si-dask::before { content: "\ebdd"; }
.si-dask.si--color::before { color: #FDA061; }
.si-dassaultsystemes::before { content: "\ebde"; }
.si-dassaultsystemes.si--color::before { color: #005386; }
.si-dataversioncontrol::before { content: "\ebdf"; }
.si-dataversioncontrol.si--color::before { color: #945DD6; }
.si-datadotai::before { content: "\ebe0"; }
.si-datadotai.si--color::before { color: #000000; }
.si-databricks::before { content: "\ebe1"; }
.si-databricks.si--color::before { color: #FF3621; }
.si-datacamp::before { content: "\ebe2"; }
.si-datacamp.si--color::before { color: #03EF62; }
.si-datadog::before { content: "\ebe3"; }
.si-datadog.si--color::before { color: #632CA6; }
.si-datagrip::before { content: "\ebe4"; }
.si-datagrip.si--color::before { color: #000000; }
.si-dataiku::before { content: "\ebe5"; }
.si-dataiku.si--color::before { color: #2AB1AC; }
.si-datastax::before { content: "\ebe6"; }
.si-datastax.si--color::before { color: #3A3A42; }
.si-datocms::before { content: "\ebe7"; }
.si-datocms.si--color::before { color: #FF7751; }
.si-datto::before { content: "\ebe8"; }
.si-datto.si--color::before { color: #199ED9; }
.si-dazn::before { content: "\ebe9"; }
.si-dazn.si--color::before { color: #F8F8F5; }
.si-dblp::before { content: "\ebea"; }
.si-dblp.si--color::before { color: #004F9F; }
.si-dbt::before { content: "\ebeb"; }
.si-dbt.si--color::before { color: #FF694B; }
.si-dcentertainment::before { content: "\ebec"; }
.si-dcentertainment.si--color::before { color: #0078F0; }
.si-delonghi::before { content: "\ebed"; }
.si-delonghi.si--color::before { color: #072240; }
.si-debian::before { content: "\ebee"; }
.si-debian.si--color::before { color: #A81D33; }
.si-deepin::before { content: "\ebef"; }
.si-deepin.si--color::before { color: #007CFF; }
.si-deepnote::before { content: "\ebf0"; }
.si-deepnote.si--color::before { color: #3793EF; }
.si-deezer::before { content: "\ebf1"; }
.si-deezer.si--color::before { color: #FEAA2D; }
.si-delicious::before { content: "\ebf2"; }
.si-delicious.si--color::before { color: #0000FF; }
.si-deliveroo::before { content: "\ebf3"; }
.si-deliveroo.si--color::before { color: #00CCBC; }
.si-dell::before { content: "\ebf4"; }
.si-dell.si--color::before { color: #007DB8; }
.si-delphi::before { content: "\ebf5"; }
.si-delphi.si--color::before { color: #EE1F35; }
.si-delta::before { content: "\ebf6"; }
.si-delta.si--color::before { color: #003366; }
.si-deno::before { content: "\ebf7"; }
.si-deno.si--color::before { color: #000000; }
.si-dependabot::before { content: "\ebf8"; }
.si-dependabot.si--color::before { color: #025E8C; }
.si-derspiegel::before { content: "\ebf9"; }
.si-derspiegel.si--color::before { color: #E64415; }
.si-designernews::before { content: "\ebfa"; }
.si-designernews.si--color::before { color: #2D72D9; }
.si-deutschebahn::before { content: "\ebfb"; }
.si-deutschebahn.si--color::before { color: #F01414; }
.si-deutschebank::before { content: "\ebfc"; }
.si-deutschebank.si--color::before { color: #0018A8; }
.si-devdotto::before { content: "\ebfd"; }
.si-devdotto.si--color::before { color: #0A0A0A; }
.si-devexpress::before { content: "\ebfe"; }
.si-devexpress.si--color::before { color: #FF7200; }
.si-deviantart::before { content: "\ebff"; }
.si-deviantart.si--color::before { color: #05CC47; }
.si-devpost::before { content: "\ec00"; }
.si-devpost.si--color::before { color: #003E54; }
.si-devrant::before { content: "\ec01"; }
.si-devrant.si--color::before { color: #F99A66; }
.si-dgraph::before { content: "\ec02"; }
.si-dgraph.si--color::before { color: #E50695; }
.si-dhl::before { content: "\ec03"; }
.si-dhl.si--color::before { color: #FFCC00; }
.si-diagramsdotnet::before { content: "\ec04"; }
.si-diagramsdotnet.si--color::before { color: #F08705; }
.si-dialogflow::before { content: "\ec05"; }
.si-dialogflow.si--color::before { color: #FF9800; }
.si-diaspora::before { content: "\ec06"; }
.si-diaspora.si--color::before { color: #000000; }
.si-digg::before { content: "\ec07"; }
.si-digg.si--color::before { color: #000000; }
.si-digikeyelectronics::before { content: "\ec08"; }
.si-digikeyelectronics.si--color::before { color: #CC0000; }
.si-digitalocean::before { content: "\ec09"; }
.si-digitalocean.si--color::before { color: #0080FF; }
.si-dior::before { content: "\ec0a"; }
.si-dior.si--color::before { color: #000000; }
.si-directus::before { content: "\ec0b"; }
.si-directus.si--color::before { color: #263238; }
.si-discogs::before { content: "\ec0c"; }
.si-discogs.si--color::before { color: #333333; }
.si-discord::before { content: "\ec0d"; }
.si-discord.si--color::before { color: #5865F2; }
.si-discover::before { content: "\ec0e"; }
.si-discover.si--color::before { color: #FF6000; }
.si-discourse::before { content: "\ec0f"; }
.si-discourse.si--color::before { color: #000000; }
.si-disqus::before { content: "\ec10"; }
.si-disqus.si--color::before { color: #2E9FFF; }
.si-disroot::before { content: "\ec11"; }
.si-disroot.si--color::before { color: #50162D; }
.si-django::before { content: "\ec12"; }
.si-django.si--color::before { color: #092E20; }
.si-dlib::before { content: "\ec13"; }
.si-dlib.si--color::before { color: #008000; }
.si-dlna::before { content: "\ec14"; }
.si-dlna.si--color::before { color: #48A842; }
.si-dm::before { content: "\ec15"; }
.si-dm.si--color::before { color: #002878; }
.si-docker::before { content: "\ec16"; }
.si-docker.si--color::before { color: #2496ED; }
.si-docsdotrs::before { content: "\ec17"; }
.si-docsdotrs.si--color::before { color: #000000; }
.si-docusign::before { content: "\ec18"; }
.si-docusign.si--color::before { color: #FFCC22; }
.si-dogecoin::before { content: "\ec19"; }
.si-dogecoin.si--color::before { color: #C2A633; }
.si-dolby::before { content: "\ec1a"; }
.si-dolby.si--color::before { color: #000000; }
.si-doordash::before { content: "\ec1b"; }
.si-doordash.si--color::before { color: #FF3008; }
.si-douban::before { content: "\ec1c"; }
.si-douban.si--color::before { color: #007722; }
.si-doubanread::before { content: "\ec1d"; }
.si-doubanread.si--color::before { color: #389EAC; }
.si-dpd::before { content: "\ec1e"; }
.si-dpd.si--color::before { color: #DC0032; }
.si-dragonframe::before { content: "\ec1f"; }
.si-dragonframe.si--color::before { color: #D4911E; }
.si-dribbble::before { content: "\ec20"; }
.si-dribbble.si--color::before { color: #EA4C89; }
.si-draugiemdotlv::before { content: "\ec21"; }
.si-draugiemdotlv.si--color::before { color: #FF6600; }
.si-drone::before { content: "\ec22"; }
.si-drone.si--color::before { color: #212121; }
.si-drooble::before { content: "\ec23"; }
.si-drooble.si--color::before { color: #19C4BE; }
.si-drupal::before { content: "\ec24"; }
.si-drupal.si--color::before { color: #0678BE; }
.si-dropbox::before { content: "\ec25"; }
.si-dropbox.si--color::before { color: #0061FF; }
.si-dsautomobiles::before { content: "\ec26"; }
.si-dsautomobiles.si--color::before { color: #1D1717; }
.si-dtube::before { content: "\ec27"; }
.si-dtube.si--color::before { color: #F01A30; }
.si-duckduckgo::before { content: "\ec28"; }
.si-duckduckgo.si--color::before { color: #DE5833; }
.si-dungeonsanddragons::before { content: "\ec29"; }
.si-dungeonsanddragons.si--color::before { color: #ED1C24; }
.si-dunked::before { content: "\ec2a"; }
.si-dunked.si--color::before { color: #2DA9D7; }
.si-duolingo::before { content: "\ec2b"; }
.si-duolingo.si--color::before { color: #58CC02; }
.si-dvc::before { content: "\ec2c"; }
.si-dvc.si--color::before { color: #13ADC7; }
.si-dwm::before { content: "\ec2d"; }
.si-dwm.si--color::before { color: #1177AA; }
.si-dynamics365::before { content: "\ec2e"; }
.si-dynamics365.si--color::before { color: #002050; }
.si-dynatrace::before { content: "\ec2f"; }
.si-dynatrace.si--color::before { color: #1496FF; }
.si-edotleclerc::before { content: "\ec30"; }
.si-edotleclerc.si--color::before { color: #0066CC; }
.si-ea::before { content: "\ec31"; }
.si-ea.si--color::before { color: #000000; }
.si-eagle::before { content: "\ec32"; }
.si-eagle.si--color::before { color: #0072EF; }
.si-easyjet::before { content: "\ec33"; }
.si-easyjet.si--color::before { color: #FF6600; }
.si-ebay::before { content: "\ec34"; }
.si-ebay.si--color::before { color: #E53238; }
.si-eclipseche::before { content: "\ec35"; }
.si-eclipseche.si--color::before { color: #525C86; }
.si-eclipseide::before { content: "\ec36"; }
.si-eclipseide.si--color::before { color: #2C2255; }
.si-eclipsejetty::before { content: "\ec37"; }
.si-eclipsejetty.si--color::before { color: #FC390E; }
.si-eclipsemosquitto::before { content: "\ec38"; }
.si-eclipsemosquitto.si--color::before { color: #3C5280; }
.si-eclipsevertdotx::before { content: "\ec39"; }
.si-eclipsevertdotx.si--color::before { color: #782A90; }
.si-edeka::before { content: "\ec3a"; }
.si-edeka.si--color::before { color: #1B66B3; }
.si-editorconfig::before { content: "\ec3b"; }
.si-editorconfig.si--color::before { color: #FEFEFE; }
.si-edx::before { content: "\ec3c"; }
.si-edx.si--color::before { color: #02262B; }
.si-egghead::before { content: "\ec3d"; }
.si-egghead.si--color::before { color: #FCFBFA; }
.si-egnyte::before { content: "\ec3e"; }
.si-egnyte.si--color::before { color: #00968F; }
.si-eljueves::before { content: "\ec3f"; }
.si-eljueves.si--color::before { color: #BE312E; }
.si-eightsleep::before { content: "\ec40"; }
.si-eightsleep.si--color::before { color: #262729; }
.si-elastic::before { content: "\ec41"; }
.si-elastic.si--color::before { color: #005571; }
.si-elasticcloud::before { content: "\ec42"; }
.si-elasticcloud.si--color::before { color: #005571; }
.si-elasticstack::before { content: "\ec43"; }
.si-elasticstack.si--color::before { color: #005571; }
.si-elasticsearch::before { content: "\ec44"; }
.si-elasticsearch.si--color::before { color: #005571; }
.si-electron::before { content: "\ec45"; }
.si-electron.si--color::before { color: #47848F; }
.si-element::before { content: "\ec46"; }
.si-element.si--color::before { color: #0DBD8B; }
.si-elementary::before { content: "\ec47"; }
.si-elementary.si--color::before { color: #64BAFF; }
.si-eleventy::before { content: "\ec48"; }
.si-eleventy.si--color::before { color: #000000; }
.si-elixir::before { content: "\ec49"; }
.si-elixir.si--color::before { color: #4B275F; }
.si-ello::before { content: "\ec4a"; }
.si-ello.si--color::before { color: #000000; }
.si-elm::before { content: "\ec4b"; }
.si-elm.si--color::before { color: #1293D8; }
.si-elsevier::before { content: "\ec4c"; }
.si-elsevier.si--color::before { color: #FF6C00; }
.si-embarcadero::before { content: "\ec4d"; }
.si-embarcadero.si--color::before { color: #ED1F35; }
.si-emberdotjs::before { content: "\ec4e"; }
.si-emberdotjs.si--color::before { color: #E04E39; }
.si-emby::before { content: "\ec4f"; }
.si-emby.si--color::before { color: #52B54B; }
.si-emirates::before { content: "\ec50"; }
.si-emirates.si--color::before { color: #D71921; }
.si-emlakjet::before { content: "\ec51"; }
.si-emlakjet.si--color::before { color: #0AE524; }
.si-empirekred::before { content: "\ec52"; }
.si-empirekred.si--color::before { color: #72BE50; }
.si-enpass::before { content: "\ec53"; }
.si-enpass.si--color::before { color: #0D47A1; }
.si-enterprisedb::before { content: "\ec54"; }
.si-enterprisedb.si--color::before { color: #FF3E00; }
.si-envato::before { content: "\ec55"; }
.si-envato.si--color::before { color: #81B441; }
.si-epel::before { content: "\ec56"; }
.si-epel.si--color::before { color: #FC0000; }
.si-epicgames::before { content: "\ec57"; }
.si-epicgames.si--color::before { color: #313131; }
.si-epson::before { content: "\ec58"; }
.si-epson.si--color::before { color: #003399; }
.si-equinixmetal::before { content: "\ec59"; }
.si-equinixmetal.si--color::before { color: #ED2224; }
.si-erlang::before { content: "\ec5a"; }
.si-erlang.si--color::before { color: #A90533; }
.si-esbuild::before { content: "\ec5b"; }
.si-esbuild.si--color::before { color: #FFCF00; }
.si-esea::before { content: "\ec5c"; }
.si-esea.si--color::before { color: #0E9648; }
.si-eslgaming::before { content: "\ec5d"; }
.si-eslgaming.si--color::before { color: #FFFF09; }
.si-eslint::before { content: "\ec5e"; }
.si-eslint.si--color::before { color: #4B32C3; }
.si-esphome::before { content: "\ec5f"; }
.si-esphome.si--color::before { color: #000000; }
.si-etcd::before { content: "\ec60"; }
.si-etcd.si--color::before { color: #419EDA; }
.si-espressif::before { content: "\ec61"; }
.si-espressif.si--color::before { color: #E7352C; }
.si-ethereum::before { content: "\ec62"; }
.si-ethereum.si--color::before { color: #3C3C3D; }
.si-ethiopianairlines::before { content: "\ec63"; }
.si-ethiopianairlines.si--color::before { color: #648B1A; }
.si-etihadairways::before { content: "\ec64"; }
.si-etihadairways.si--color::before { color: #BD8B13; }
.si-etsy::before { content: "\ec65"; }
.si-etsy.si--color::before { color: #F16521; }
.si-eventstore::before { content: "\ec66"; }
.si-eventstore.si--color::before { color: #5AB552; }
.si-eventbrite::before { content: "\ec67"; }
.si-eventbrite.si--color::before { color: #F05537; }
.si-evernote::before { content: "\ec68"; }
.si-evernote.si--color::before { color: #00A82D; }
.si-exercism::before { content: "\ec69"; }
.si-exercism.si--color::before { color: #009CAB; }
.si-exordo::before { content: "\ec6a"; }
.si-exordo.si--color::before { color: #DAA449; }
.si-exoscale::before { content: "\ec6b"; }
.si-exoscale.si--color::before { color: #DA291C; }
.si-expensify::before { content: "\ec6c"; }
.si-expensify.si--color::before { color: #0185FF; }
.si-expertsexchange::before { content: "\ec6d"; }
.si-expertsexchange.si--color::before { color: #00AAE7; }
.si-expo::before { content: "\ec6e"; }
.si-expo.si--color::before { color: #000020; }
.si-express::before { content: "\ec6f"; }
.si-express.si--color::before { color: #000000; }
.si-expressvpn::before { content: "\ec70"; }
.si-expressvpn.si--color::before { color: #DA3940; }
.si-eyeem::before { content: "\ec71"; }
.si-eyeem.si--color::before { color: #000000; }
.si-fdroid::before { content: "\ec72"; }
.si-fdroid.si--color::before { color: #1976D2; }
.si-fsecure::before { content: "\ec73"; }
.si-fsecure.si--color::before { color: #00BAFF; }
.si-facebook::before { content: "\ec74"; }
.si-facebook.si--color::before { color: #1877F2; }
.si-facebookgaming::before { content: "\ec75"; }
.si-facebookgaming.si--color::before { color: #005FED; }
.si-facebooklive::before { content: "\ec76"; }
.si-facebooklive.si--color::before { color: #ED4242; }
.si-faceit::before { content: "\ec77"; }
.si-faceit.si--color::before { color: #FF5500; }
.si-facepunch::before { content: "\ec78"; }
.si-facepunch.si--color::before { color: #EC1C24; }
.si-falcon::before { content: "\ec79"; }
.si-falcon.si--color::before { color: #F0AD4E; }
.si-fampay::before { content: "\ec7a"; }
.si-fampay.si--color::before { color: #FFAD00; }
.si-fandango::before { content: "\ec7b"; }
.si-fandango.si--color::before { color: #FF7300; }
.si-fandom::before { content: "\ec7c"; }
.si-fandom.si--color::before { color: #FA005A; }
.si-farfetch::before { content: "\ec7d"; }
.si-farfetch.si--color::before { color: #000000; }
.si-fastapi::before { content: "\ec7e"; }
.si-fastapi.si--color::before { color: #009688; }
.si-fastify::before { content: "\ec7f"; }
.si-fastify.si--color::before { color: #000000; }
.si-fastlane::before { content: "\ec80"; }
.si-fastlane.si--color::before { color: #00F200; }
.si-fastly::before { content: "\ec81"; }
.si-fastly.si--color::before { color: #FF282D; }
.si-fathom::before { content: "\ec82"; }
.si-fathom.si--color::before { color: #9187FF; }
.si-favro::before { content: "\ec83"; }
.si-favro.si--color::before { color: #512DA8; }
.si-feathub::before { content: "\ec84"; }
.si-feathub.si--color::before { color: #9B9B9B; }
.si-fedex::before { content: "\ec85"; }
.si-fedex.si--color::before { color: #4D148C; }
.si-fedora::before { content: "\ec86"; }
.si-fedora.si--color::before { color: #51A2DA; }
.si-feedly::before { content: "\ec87"; }
.si-feedly.si--color::before { color: #2BB24C; }
.si-ferrari::before { content: "\ec88"; }
.si-ferrari.si--color::before { color: #D40000; }
.si-ferrarinv::before { content: "\ec89"; }
.si-ferrarinv.si--color::before { color: #EB2E2C; }
.si-ffmpeg::before { content: "\ec8a"; }
.si-ffmpeg.si--color::before { color: #007808; }
.si-fiat::before { content: "\ec8b"; }
.si-fiat.si--color::before { color: #941711; }
.si-fidoalliance::before { content: "\ec8c"; }
.si-fidoalliance.si--color::before { color: #FFBF3B; }
.si-fifa::before { content: "\ec8d"; }
.si-fifa.si--color::before { color: #326295; }
.si-figma::before { content: "\ec8e"; }
.si-figma.si--color::before { color: #F24E1E; }
.si-figshare::before { content: "\ec8f"; }
.si-figshare.si--color::before { color: #556472; }
.si-fila::before { content: "\ec90"; }
.si-fila.si--color::before { color: #03234C; }
.si-files::before { content: "\ec91"; }
.si-files.si--color::before { color: #4285F4; }
.si-filezilla::before { content: "\ec92"; }
.si-filezilla.si--color::before { color: #BF0000; }
.si-fing::before { content: "\ec93"; }
.si-fing.si--color::before { color: #009AEE; }
.si-firebase::before { content: "\ec94"; }
.si-firebase.si--color::before { color: #FFCA28; }
.si-firefox::before { content: "\ec95"; }
.si-firefox.si--color::before { color: #FF7139; }
.si-firefoxbrowser::before { content: "\ec96"; }
.si-firefoxbrowser.si--color::before { color: #FF7139; }
.si-first::before { content: "\ec97"; }
.si-first.si--color::before { color: #0066B3; }
.si-fitbit::before { content: "\ec98"; }
.si-fitbit.si--color::before { color: #00B0B9; }
.si-fite::before { content: "\ec99"; }
.si-fite.si--color::before { color: #CA0404; }
.si-fivem::before { content: "\ec9a"; }
.si-fivem.si--color::before { color: #F40552; }
.si-fiverr::before { content: "\ec9b"; }
.si-fiverr.si--color::before { color: #1DBF73; }
.si-flask::before { content: "\ec9c"; }
.si-flask.si--color::before { color: #000000; }
.si-flat::before { content: "\ec9d"; }
.si-flat.si--color::before { color: #3481FE; }
.si-flathub::before { content: "\ec9e"; }
.si-flathub.si--color::before { color: #4A86CF; }
.si-flattr::before { content: "\ec9f"; }
.si-flattr.si--color::before { color: #000000; }
.si-flickr::before { content: "\eca0"; }
.si-flickr.si--color::before { color: #0063DC; }
.si-flipboard::before { content: "\eca1"; }
.si-flipboard.si--color::before { color: #E12828; }
.si-floatplane::before { content: "\eca2"; }
.si-floatplane.si--color::before { color: #00AEEF; }
.si-flipkart::before { content: "\eca3"; }
.si-flipkart.si--color::before { color: #2874F0; }
.si-flood::before { content: "\eca4"; }
.si-flood.si--color::before { color: #4285F4; }
.si-fluentbit::before { content: "\eca5"; }
.si-fluentbit.si--color::before { color: #49BDA5; }
.si-fluentd::before { content: "\eca6"; }
.si-fluentd.si--color::before { color: #0E83C8; }
.si-flutter::before { content: "\eca7"; }
.si-flutter.si--color::before { color: #02569B; }
.si-fmod::before { content: "\eca8"; }
.si-fmod.si--color::before { color: #000000; }
.si-flyway::before { content: "\eca9"; }
.si-flyway.si--color::before { color: #CC0200; }
.si-fnac::before { content: "\ecaa"; }
.si-fnac.si--color::before { color: #E1A925; }
.si-folium::before { content: "\ecab"; }
.si-folium.si--color::before { color: #77B829; }
.si-fonoma::before { content: "\ecac"; }
.si-fonoma.si--color::before { color: #02B78F; }
.si-fontawesome::before { content: "\ecad"; }
.si-fontawesome.si--color::before { color: #528DD7; }
.si-fontbase::before { content: "\ecae"; }
.si-fontbase.si--color::before { color: #3D03A7; }
.si-foodpanda::before { content: "\ecaf"; }
.si-foodpanda.si--color::before { color: #D70F64; }
.si-ford::before { content: "\ecb0"; }
.si-ford.si--color::before { color: #00274E; }
.si-forestry::before { content: "\ecb1"; }
.si-forestry.si--color::before { color: #343A40; }
.si-formstack::before { content: "\ecb2"; }
.si-formstack.si--color::before { color: #21B573; }
.si-fortinet::before { content: "\ecb3"; }
.si-fortinet.si--color::before { color: #EE3124; }
.si-fortran::before { content: "\ecb4"; }
.si-fortran.si--color::before { color: #734F96; }
.si-fossa::before { content: "\ecb5"; }
.si-fossa.si--color::before { color: #289E6D; }
.si-fossilscm::before { content: "\ecb6"; }
.si-fossilscm.si--color::before { color: #548294; }
.si-foursquare::before { content: "\ecb7"; }
.si-foursquare.si--color::before { color: #3333FF; }
.si-foursquarecityguide::before { content: "\ecb8"; }
.si-foursquarecityguide.si--color::before { color: #F94877; }
.si-foxtel::before { content: "\ecb9"; }
.si-foxtel.si--color::before { color: #EB5205; }
.si-fozzy::before { content: "\ecba"; }
.si-fozzy.si--color::before { color: #F15B29; }
.si-framer::before { content: "\ecbb"; }
.si-framer.si--color::before { color: #0055FF; }
.si-framework7::before { content: "\ecbc"; }
.si-framework7.si--color::before { color: #EE350F; }
.si-franprix::before { content: "\ecbd"; }
.si-franprix.si--color::before { color: #EC6237; }
.si-fraunhofergesellschaft::before { content: "\ecbe"; }
.si-fraunhofergesellschaft.si--color::before { color: #179C7D; }
.si-freebsd::before { content: "\ecbf"; }
.si-freebsd.si--color::before { color: #AB2B28; }
.si-freecodecamp::before { content: "\ecc0"; }
.si-freecodecamp.si--color::before { color: #0A0A23; }
.si-freedesktopdotorg::before { content: "\ecc1"; }
.si-freedesktopdotorg.si--color::before { color: #3B80AE; }
.si-freelancer::before { content: "\ecc2"; }
.si-freelancer.si--color::before { color: #29B2FE; }
.si-freenas::before { content: "\ecc3"; }
.si-freenas.si--color::before { color: #343434; }
.si-frontendmentor::before { content: "\ecc4"; }
.si-frontendmentor.si--color::before { color: #3F54A3; }
.si-fujifilm::before { content: "\ecc5"; }
.si-fujifilm.si--color::before { color: #ED1A3A; }
.si-fujitsu::before { content: "\ecc6"; }
.si-fujitsu.si--color::before { color: #FF0000; }
.si-funimation::before { content: "\ecc7"; }
.si-funimation.si--color::before { color: #5B0BB5; }
.si-furaffinity::before { content: "\ecc8"; }
.si-furaffinity.si--color::before { color: #36566F; }
.si-furrynetwork::before { content: "\ecc9"; }
.si-furrynetwork.si--color::before { color: #2E75B4; }
.si-futurelearn::before { content: "\ecca"; }
.si-futurelearn.si--color::before { color: #DE00A5; }
.si-g2::before { content: "\eccb"; }
.si-g2.si--color::before { color: #FF492C; }
.si-g2a::before { content: "\eccc"; }
.si-g2a.si--color::before { color: #F05F00; }
.si-gameandwatch::before { content: "\eccd"; }
.si-gameandwatch.si--color::before { color: #000000; }
.si-gamejolt::before { content: "\ecce"; }
.si-gamejolt.si--color::before { color: #CCFF00; }
.si-garmin::before { content: "\eccf"; }
.si-garmin.si--color::before { color: #000000; }
.si-gatling::before { content: "\ecd0"; }
.si-gatling.si--color::before { color: #FF9E2A; }
.si-gatsby::before { content: "\ecd1"; }
.si-gatsby.si--color::before { color: #663399; }
.si-geant::before { content: "\ecd2"; }
.si-geant.si--color::before { color: #DD1F26; }
.si-geeksforgeeks::before { content: "\ecd3"; }
.si-geeksforgeeks.si--color::before { color: #2F8D46; }
.si-generalmotors::before { content: "\ecd4"; }
.si-generalmotors.si--color::before { color: #0170CE; }
.si-generalelectric::before { content: "\ecd5"; }
.si-generalelectric.si--color::before { color: #0870D8; }
.si-genius::before { content: "\ecd6"; }
.si-genius.si--color::before { color: #FFFF64; }
.si-gentoo::before { content: "\ecd7"; }
.si-gentoo.si--color::before { color: #54487A; }
.si-geocaching::before { content: "\ecd8"; }
.si-geocaching.si--color::before { color: #00874D; }
.si-gerrit::before { content: "\ecd9"; }
.si-gerrit.si--color::before { color: #EEEEEE; }
.si-ghost::before { content: "\ecda"; }
.si-ghost.si--color::before { color: #15171A; }
.si-ghostery::before { content: "\ecdb"; }
.si-ghostery.si--color::before { color: #00AEF0; }
.si-gimp::before { content: "\ecdc"; }
.si-gimp.si--color::before { color: #5C5543; }
.si-giphy::before { content: "\ecdd"; }
.si-giphy.si--color::before { color: #FF6666; }
.si-git::before { content: "\ecde"; }
.si-git.si--color::before { color: #F05032; }
.si-gitextensions::before { content: "\ecdf"; }
.si-gitextensions.si--color::before { color: #212121; }
.si-gitlfs::before { content: "\ece0"; }
.si-gitlfs.si--color::before { color: #F64935; }
.si-gitbook::before { content: "\ece1"; }
.si-gitbook.si--color::before { color: #3884FF; }
.si-gitea::before { content: "\ece2"; }
.si-gitea.si--color::before { color: #609926; }
.si-gitee::before { content: "\ece3"; }
.si-gitee.si--color::before { color: #C71D23; }
.si-github::before { content: "\ece4"; }
.si-github.si--color::before { color: #181717; }
.si-githubactions::before { content: "\ece5"; }
.si-githubactions.si--color::before { color: #2088FF; }
.si-githubpages::before { content: "\ece6"; }
.si-githubpages.si--color::before { color: #222222; }
.si-githubsponsors::before { content: "\ece7"; }
.si-githubsponsors.si--color::before { color: #EA4AAA; }
.si-gitignoredotio::before { content: "\ece8"; }
.si-gitignoredotio.si--color::before { color: #204ECF; }
.si-gitkraken::before { content: "\ece9"; }
.si-gitkraken.si--color::before { color: #179287; }
.si-gitlab::before { content: "\ecea"; }
.si-gitlab.si--color::before { color: #FC6D26; }
.si-gitpod::before { content: "\eceb"; }
.si-gitpod.si--color::before { color: #FFAE33; }
.si-gitter::before { content: "\ecec"; }
.si-gitter.si--color::before { color: #ED1965; }
.si-glitch::before { content: "\eced"; }
.si-glitch.si--color::before { color: #3333FF; }
.si-glassdoor::before { content: "\ecee"; }
.si-glassdoor.si--color::before { color: #0CAA41; }
.si-gmail::before { content: "\ecef"; }
.si-gmail.si--color::before { color: #EA4335; }
.si-globus::before { content: "\ecf0"; }
.si-globus.si--color::before { color: #CA6201; }
.si-gnome::before { content: "\ecf1"; }
.si-gnome.si--color::before { color: #4A86CF; }
.si-gnometerminal::before { content: "\ecf2"; }
.si-gnometerminal.si--color::before { color: #241F31; }
.si-gnu::before { content: "\ecf3"; }
.si-gnu.si--color::before { color: #A42E2B; }
.si-gnubash::before { content: "\ecf4"; }
.si-gnubash.si--color::before { color: #4EAA25; }
.si-gnuemacs::before { content: "\ecf5"; }
.si-gnuemacs.si--color::before { color: #7F5AB6; }
.si-gnuicecat::before { content: "\ecf6"; }
.si-gnuicecat.si--color::before { color: #002F5B; }
.si-gnusocial::before { content: "\ecf7"; }
.si-gnusocial.si--color::before { color: #A22430; }
.si-gnuprivacyguard::before { content: "\ecf8"; }
.si-gnuprivacyguard.si--color::before { color: #0093DD; }
.si-go::before { content: "\ecf9"; }
.si-go.si--color::before { color: #00ADD8; }
.si-gocd::before { content: "\ecfa"; }
.si-gocd.si--color::before { color: #94399E; }
.si-godaddy::before { content: "\ecfb"; }
.si-godaddy.si--color::before { color: #1BDBDB; }
.si-godotengine::before { content: "\ecfc"; }
.si-godotengine.si--color::before { color: #478CBF; }
.si-gofundme::before { content: "\ecfd"; }
.si-gofundme.si--color::before { color: #00B964; }
.si-gogdotcom::before { content: "\ecfe"; }
.si-gogdotcom.si--color::before { color: #86328A; }
.si-goland::before { content: "\ecff"; }
.si-goland.si--color::before { color: #000000; }
.si-goldenline::before { content: "\ed00"; }
.si-goldenline.si--color::before { color: #FFE005; }
.si-goodreads::before { content: "\ed01"; }
.si-goodreads.si--color::before { color: #372213; }
.si-google::before { content: "\ed02"; }
.si-google.si--color::before { color: #4285F4; }
.si-googleadmob::before { content: "\ed03"; }
.si-googleadmob.si--color::before { color: #EA4335; }
.si-googleads::before { content: "\ed04"; }
.si-googleads.si--color::before { color: #4285F4; }
.si-googleadsense::before { content: "\ed05"; }
.si-googleadsense.si--color::before { color: #4285F4; }
.si-googleanalytics::before { content: "\ed06"; }
.si-googleanalytics.si--color::before { color: #E37400; }
.si-googlecalendar::before { content: "\ed07"; }
.si-googlecalendar.si--color::before { color: #4285F4; }
.si-googleassistant::before { content: "\ed08"; }
.si-googleassistant.si--color::before { color: #4285F4; }
.si-googlecardboard::before { content: "\ed09"; }
.si-googlecardboard.si--color::before { color: #FF7143; }
.si-googlechat::before { content: "\ed0a"; }
.si-googlechat.si--color::before { color: #00AC47; }
.si-googlechrome::before { content: "\ed0b"; }
.si-googlechrome.si--color::before { color: #4285F4; }
.si-googleclassroom::before { content: "\ed0c"; }
.si-googleclassroom.si--color::before { color: #0F9D58; }
.si-googlecloud::before { content: "\ed0d"; }
.si-googlecloud.si--color::before { color: #4285F4; }
.si-googlecolab::before { content: "\ed0e"; }
.si-googlecolab.si--color::before { color: #F9AB00; }
.si-googledomains::before { content: "\ed0f"; }
.si-googledomains.si--color::before { color: #4285F4; }
.si-googledrive::before { content: "\ed10"; }
.si-googledrive.si--color::before { color: #4285F4; }
.si-googleearth::before { content: "\ed11"; }
.si-googleearth.si--color::before { color: #4285F4; }
.si-googlefit::before { content: "\ed12"; }
.si-googlefit.si--color::before { color: #4285F4; }
.si-googlefonts::before { content: "\ed13"; }
.si-googlefonts.si--color::before { color: #4285F4; }
.si-googlehangouts::before { content: "\ed14"; }
.si-googlehangouts.si--color::before { color: #0C9D58; }
.si-googlekeep::before { content: "\ed15"; }
.si-googlekeep.si--color::before { color: #FFBB00; }
.si-googlelens::before { content: "\ed16"; }
.si-googlelens.si--color::before { color: #4285F4; }
.si-googlemaps::before { content: "\ed17"; }
.si-googlemaps.si--color::before { color: #4285F4; }
.si-googlemarketingplatform::before { content: "\ed18"; }
.si-googlemarketingplatform.si--color::before { color: #4285F4; }
.si-googlemeet::before { content: "\ed19"; }
.si-googlemeet.si--color::before { color: #00897B; }
.si-googlemessages::before { content: "\ed1a"; }
.si-googlemessages.si--color::before { color: #1A73E8; }
.si-googlemybusiness::before { content: "\ed1b"; }
.si-googlemybusiness.si--color::before { color: #4285F4; }
.si-googlenearby::before { content: "\ed1c"; }
.si-googlenearby.si--color::before { color: #4285F4; }
.si-googlenews::before { content: "\ed1d"; }
.si-googlenews.si--color::before { color: #174EA6; }
.si-googleoptimize::before { content: "\ed1e"; }
.si-googleoptimize.si--color::before { color: #B366F6; }
.si-googlepay::before { content: "\ed1f"; }
.si-googlepay.si--color::before { color: #4285F4; }
.si-googlephotos::before { content: "\ed20"; }
.si-googlephotos.si--color::before { color: #4285F4; }
.si-googleplay::before { content: "\ed21"; }
.si-googleplay.si--color::before { color: #414141; }
.si-googlepodcasts::before { content: "\ed22"; }
.si-googlepodcasts.si--color::before { color: #4285F4; }
.si-googlescholar::before { content: "\ed23"; }
.si-googlescholar.si--color::before { color: #4285F4; }
.si-googlesearchconsole::before { content: "\ed24"; }
.si-googlesearchconsole.si--color::before { color: #458CF5; }
.si-googlesheets::before { content: "\ed25"; }
.si-googlesheets.si--color::before { color: #34A853; }
.si-googlestreetview::before { content: "\ed26"; }
.si-googlestreetview.si--color::before { color: #FEC111; }
.si-googletagmanager::before { content: "\ed27"; }
.si-googletagmanager.si--color::before { color: #246FDB; }
.si-googletranslate::before { content: "\ed28"; }
.si-googletranslate.si--color::before { color: #4285F4; }
.si-gotomeeting::before { content: "\ed29"; }
.si-gotomeeting.si--color::before { color: #F68D2E; }
.si-grab::before { content: "\ed2a"; }
.si-grab.si--color::before { color: #00B14F; }
.si-grafana::before { content: "\ed2b"; }
.si-grafana.si--color::before { color: #F46800; }
.si-gradle::before { content: "\ed2c"; }
.si-gradle.si--color::before { color: #02303A; }
.si-grammarly::before { content: "\ed2d"; }
.si-grammarly.si--color::before { color: #15C39A; }
.si-grandfrais::before { content: "\ed2e"; }
.si-grandfrais.si--color::before { color: #ED2D2F; }
.si-graphql::before { content: "\ed2f"; }
.si-graphql.si--color::before { color: #E10098; }
.si-grav::before { content: "\ed30"; }
.si-grav.si--color::before { color: #221E1F; }
.si-gravatar::before { content: "\ed31"; }
.si-gravatar.si--color::before { color: #1E8CBE; }
.si-graylog::before { content: "\ed32"; }
.si-graylog.si--color::before { color: #FF3633; }
.si-greensock::before { content: "\ed33"; }
.si-greensock.si--color::before { color: #88CE02; }
.si-griddotai::before { content: "\ed34"; }
.si-griddotai.si--color::before { color: #78FF96; }
.si-gridsome::before { content: "\ed35"; }
.si-gridsome.si--color::before { color: #00A672; }
.si-groupme::before { content: "\ed36"; }
.si-groupme.si--color::before { color: #00AFF0; }
.si-groupon::before { content: "\ed37"; }
.si-groupon.si--color::before { color: #53A318; }
.si-grubhub::before { content: "\ed38"; }
.si-grubhub.si--color::before { color: #F63440; }
.si-grunt::before { content: "\ed39"; }
.si-grunt.si--color::before { color: #FAA918; }
.si-gtk::before { content: "\ed3a"; }
.si-gtk.si--color::before { color: #7FE719; }
.si-guangzhoumetro::before { content: "\ed3b"; }
.si-guangzhoumetro.si--color::before { color: #C51935; }
.si-guilded::before { content: "\ed3c"; }
.si-guilded.si--color::before { color: #F5C400; }
.si-gulp::before { content: "\ed3d"; }
.si-gulp.si--color::before { color: #CF4647; }
.si-gumroad::before { content: "\ed3e"; }
.si-gumroad.si--color::before { color: #36A9AE; }
.si-gumtree::before { content: "\ed3f"; }
.si-gumtree.si--color::before { color: #72EF36; }
.si-gunicorn::before { content: "\ed40"; }
.si-gunicorn.si--color::before { color: #499848; }
.si-gurobi::before { content: "\ed41"; }
.si-gurobi.si--color::before { color: #EE3524; }
.si-gutenberg::before { content: "\ed42"; }
.si-gutenberg.si--color::before { color: #000000; }
.si-habr::before { content: "\ed43"; }
.si-habr.si--color::before { color: #65A3BE; }
.si-hackclub::before { content: "\ed44"; }
.si-hackclub.si--color::before { color: #EC3750; }
.si-hackthebox::before { content: "\ed45"; }
.si-hackthebox.si--color::before { color: #9FEF00; }
.si-hackaday::before { content: "\ed46"; }
.si-hackaday.si--color::before { color: #1A1A1A; }
.si-hackernoon::before { content: "\ed47"; }
.si-hackernoon.si--color::before { color: #00FE00; }
.si-hackerearth::before { content: "\ed48"; }
.si-hackerearth.si--color::before { color: #2C3454; }
.si-hackerone::before { content: "\ed49"; }
.si-hackerone.si--color::before { color: #494649; }
.si-hackerrank::before { content: "\ed4a"; }
.si-hackerrank.si--color::before { color: #00EA64; }
.si-hackster::before { content: "\ed4b"; }
.si-hackster.si--color::before { color: #2E9FE6; }
.si-handshake::before { content: "\ed4c"; }
.si-handshake.si--color::before { color: #FF2F1C; }
.si-handlebarsdotjs::before { content: "\ed4d"; }
.si-handlebarsdotjs.si--color::before { color: #000000; }
.si-handshake_protocol::before { content: "\ed4e"; }
.si-handshake_protocol.si--color::before { color: #000000; }
.si-happycow::before { content: "\ed4f"; }
.si-happycow.si--color::before { color: #7C4EC4; }
.si-harbor::before { content: "\ed50"; }
.si-harbor.si--color::before { color: #60B932; }
.si-hashnode::before { content: "\ed51"; }
.si-hashnode.si--color::before { color: #2962FF; }
.si-haskell::before { content: "\ed52"; }
.si-haskell.si--color::before { color: #5D4F85; }
.si-hasura::before { content: "\ed53"; }
.si-hasura.si--color::before { color: #1EB4D4; }
.si-hatenabookmark::before { content: "\ed54"; }
.si-hatenabookmark.si--color::before { color: #00A4DE; }
.si-haveibeenpwned::before { content: "\ed55"; }
.si-haveibeenpwned.si--color::before { color: #2A6379; }
.si-haxe::before { content: "\ed56"; }
.si-haxe.si--color::before { color: #EA8220; }
.si-hbo::before { content: "\ed57"; }
.si-hbo.si--color::before { color: #000000; }
.si-hcl::before { content: "\ed58"; }
.si-hcl.si--color::before { color: #006BB6; }
.si-headlessui::before { content: "\ed59"; }
.si-headlessui.si--color::before { color: #66E3FF; }
.si-headspace::before { content: "\ed5a"; }
.si-headspace.si--color::before { color: #F47D31; }
.si-hellofresh::before { content: "\ed5b"; }
.si-hellofresh.si--color::before { color: #99CC33; }
.si-hellyhansen::before { content: "\ed5c"; }
.si-hellyhansen.si--color::before { color: #DA2128; }
.si-helm::before { content: "\ed5d"; }
.si-helm.si--color::before { color: #0F1689; }
.si-helpscout::before { content: "\ed5e"; }
.si-helpscout.si--color::before { color: #1292EE; }
.si-helpdesk::before { content: "\ed5f"; }
.si-helpdesk.si--color::before { color: #FFD000; }
.si-here::before { content: "\ed60"; }
.si-here.si--color::before { color: #00AFAA; }
.si-heroku::before { content: "\ed61"; }
.si-heroku.si--color::before { color: #430098; }
.si-hetzner::before { content: "\ed62"; }
.si-hetzner.si--color::before { color: #D50C2D; }
.si-hexo::before { content: "\ed63"; }
.si-hexo.si--color::before { color: #0E83CD; }
.si-hey::before { content: "\ed64"; }
.si-hey.si--color::before { color: #5522FA; }
.si-hibernate::before { content: "\ed65"; }
.si-hibernate.si--color::before { color: #59666C; }
.si-hilton::before { content: "\ed66"; }
.si-hilton.si--color::before { color: #124D97; }
.si-hitachi::before { content: "\ed67"; }
.si-hitachi.si--color::before { color: #E60027; }
.si-hive::before { content: "\ed68"; }
.si-hive.si--color::before { color: #FF7A00; }
.si-hive_blockchain::before { content: "\ed69"; }
.si-hive_blockchain.si--color::before { color: #E31337; }
.si-homeassistant::before { content: "\ed6a"; }
.si-homeassistant.si--color::before { color: #41BDF5; }
.si-homeassistantcommunitystore::before { content: "\ed6b"; }
.si-homeassistantcommunitystore.si--color::before { color: #41BDF5; }
.si-homeadvisor::before { content: "\ed6c"; }
.si-homeadvisor.si--color::before { color: #F68315; }
.si-homebrew::before { content: "\ed6d"; }
.si-homebrew.si--color::before { color: #FBB040; }
.si-homebridge::before { content: "\ed6e"; }
.si-homebridge.si--color::before { color: #491F59; }
.si-homify::before { content: "\ed6f"; }
.si-homify.si--color::before { color: #7DCDA3; }
.si-honda::before { content: "\ed70"; }
.si-honda.si--color::before { color: #E40521; }
.si-hoppscotch::before { content: "\ed71"; }
.si-hoppscotch.si--color::before { color: #31C48D; }
.si-hotelsdotcom::before { content: "\ed72"; }
.si-hotelsdotcom.si--color::before { color: #D32F2F; }
.si-hotjar::before { content: "\ed73"; }
.si-hotjar.si--color::before { color: #FD3A5C; }
.si-hootsuite::before { content: "\ed74"; }
.si-hootsuite.si--color::before { color: #143059; }
.si-houdini::before { content: "\ed75"; }
.si-houdini.si--color::before { color: #FF4713; }
.si-houzz::before { content: "\ed76"; }
.si-houzz.si--color::before { color: #4DBC15; }
.si-hp::before { content: "\ed77"; }
.si-hp.si--color::before { color: #0096D6; }
.si-htmlacademy::before { content: "\ed78"; }
.si-htmlacademy.si--color::before { color: #302683; }
.si-html5::before { content: "\ed79"; }
.si-html5.si--color::before { color: #E34F26; }
.si-httpie::before { content: "\ed7a"; }
.si-httpie.si--color::before { color: #73DC8C; }
.si-huawei::before { content: "\ed7b"; }
.si-huawei.si--color::before { color: #FF0000; }
.si-hubspot::before { content: "\ed7c"; }
.si-hubspot.si--color::before { color: #FF7A59; }
.si-hugo::before { content: "\ed7d"; }
.si-hugo.si--color::before { color: #FF4088; }
.si-hulu::before { content: "\ed7e"; }
.si-hulu.si--color::before { color: #1CE783; }
.si-humblebundle::before { content: "\ed7f"; }
.si-humblebundle.si--color::before { color: #CC2929; }
.si-hungryjacks::before { content: "\ed80"; }
.si-hungryjacks.si--color::before { color: #D0021B; }
.si-hurriyetemlak::before { content: "\ed81"; }
.si-hurriyetemlak.si--color::before { color: #E02826; }
.si-husqvarna::before { content: "\ed82"; }
.si-husqvarna.si--color::before { color: #273A60; }
.si-hyper::before { content: "\ed83"; }
.si-hyper.si--color::before { color: #000000; }
.si-hyperledger::before { content: "\ed84"; }
.si-hyperledger.si--color::before { color: #2F3134; }
.si-hypothesis::before { content: "\ed85"; }
.si-hypothesis.si--color::before { color: #BD1C2B; }
.si-hyundai::before { content: "\ed86"; }
.si-hyundai.si--color::before { color: #002C5F; }
.si-i18next::before { content: "\ed87"; }
.si-i18next.si--color::before { color: #26A69A; }
.si-iata::before { content: "\ed88"; }
.si-iata.si--color::before { color: #004E81; }
.si-ibeacon::before { content: "\ed89"; }
.si-ibeacon.si--color::before { color: #3D7EBB; }
.si-ibm::before { content: "\ed8a"; }
.si-ibm.si--color::before { color: #052FAD; }
.si-ibmcloud::before { content: "\ed8b"; }
.si-ibmcloud.si--color::before { color: #1261FE; }
.si-ibmwatson::before { content: "\ed8c"; }
.si-ibmwatson.si--color::before { color: #BE95FF; }
.si-iceland::before { content: "\ed8d"; }
.si-iceland.si--color::before { color: #CC092F; }
.si-icinga::before { content: "\ed8e"; }
.si-icinga.si--color::before { color: #06062C; }
.si-icloud::before { content: "\ed8f"; }
.si-icloud.si--color::before { color: #3693F3; }
.si-icomoon::before { content: "\ed90"; }
.si-icomoon.si--color::before { color: #825794; }
.si-icon::before { content: "\ed91"; }
.si-icon.si--color::before { color: #31B8BB; }
.si-iconfinder::before { content: "\ed92"; }
.si-iconfinder.si--color::before { color: #1A1B1F; }
.si-iconify::before { content: "\ed93"; }
.si-iconify.si--color::before { color: #1769AA; }
.si-iconjar::before { content: "\ed94"; }
.si-iconjar.si--color::before { color: #16A5F3; }
.si-icons8::before { content: "\ed95"; }
.si-icons8.si--color::before { color: #1FB141; }
.si-icq::before { content: "\ed96"; }
.si-icq.si--color::before { color: #24FF00; }
.si-ieee::before { content: "\ed97"; }
.si-ieee.si--color::before { color: #00629B; }
.si-ifood::before { content: "\ed98"; }
.si-ifood.si--color::before { color: #EA1D2C; }
.si-ifixit::before { content: "\ed99"; }
.si-ifixit.si--color::before { color: #0071CE; }
.si-iheartradio::before { content: "\ed9a"; }
.si-iheartradio.si--color::before { color: #C6002B; }
.si-ifttt::before { content: "\ed9b"; }
.si-ifttt.si--color::before { color: #000000; }
.si-ikea::before { content: "\ed9c"; }
.si-ikea.si--color::before { color: #0058A3; }
.si-imagej::before { content: "\ed9d"; }
.si-imagej.si--color::before { color: #00D8E0; }
.si-imdb::before { content: "\ed9e"; }
.si-imdb.si--color::before { color: #F5C518; }
.si-imgur::before { content: "\ed9f"; }
.si-imgur.si--color::before { color: #1BB76E; }
.si-immer::before { content: "\eda0"; }
.si-immer.si--color::before { color: #00E7C3; }
.si-imou::before { content: "\eda1"; }
.si-imou.si--color::before { color: #E89313; }
.si-indeed::before { content: "\eda2"; }
.si-indeed.si--color::before { color: #003A9B; }
.si-infiniti::before { content: "\eda3"; }
.si-infiniti.si--color::before { color: #000000; }
.si-influxdb::before { content: "\eda4"; }
.si-influxdb.si--color::before { color: #22ADF6; }
.si-informatica::before { content: "\eda5"; }
.si-informatica.si--color::before { color: #FF4D00; }
.si-infosys::before { content: "\eda6"; }
.si-infosys.si--color::before { color: #007CC3; }
.si-ingress::before { content: "\eda7"; }
.si-ingress.si--color::before { color: #783CBD; }
.si-inkscape::before { content: "\eda8"; }
.si-inkscape.si--color::before { color: #000000; }
.si-insomnia::before { content: "\eda9"; }
.si-insomnia.si--color::before { color: #4000BF; }
.si-instacart::before { content: "\edaa"; }
.si-instacart.si--color::before { color: #43B02A; }
.si-instagram::before { content: "\edab"; }
.si-instagram.si--color::before { color: #E4405F; }
.si-instapaper::before { content: "\edac"; }
.si-instapaper.si--color::before { color: #1F1F1F; }
.si-instatus::before { content: "\edad"; }
.si-instatus.si--color::before { color: #4EE3C2; }
.si-integromat::before { content: "\edae"; }
.si-integromat.si--color::before { color: #2F8CBB; }
.si-instructables::before { content: "\edaf"; }
.si-instructables.si--color::before { color: #FABF15; }
.si-intel::before { content: "\edb0"; }
.si-intel.si--color::before { color: #0071C5; }
.si-intellijidea::before { content: "\edb1"; }
.si-intellijidea.si--color::before { color: #000000; }
.si-interactjs::before { content: "\edb2"; }
.si-interactjs.si--color::before { color: #2599ED; }
.si-intercom::before { content: "\edb3"; }
.si-intercom.si--color::before { color: #6AFDEF; }
.si-intermarche::before { content: "\edb4"; }
.si-intermarche.si--color::before { color: #E2001A; }
.si-internetarchive::before { content: "\edb5"; }
.si-internetarchive.si--color::before { color: #666666; }
.si-internetexplorer::before { content: "\edb6"; }
.si-internetexplorer.si--color::before { color: #0076D6; }
.si-intigriti::before { content: "\edb7"; }
.si-intigriti.si--color::before { color: #161A36; }
.si-invision::before { content: "\edb8"; }
.si-invision.si--color::before { color: #FF3366; }
.si-invoiceninja::before { content: "\edb9"; }
.si-invoiceninja.si--color::before { color: #000000; }
.si-iobroker::before { content: "\edba"; }
.si-iobroker.si--color::before { color: #3399CC; }
.si-ionic::before { content: "\edbb"; }
.si-ionic.si--color::before { color: #3880FF; }
.si-ionos::before { content: "\edbc"; }
.si-ionos.si--color::before { color: #003D8F; }
.si-ios::before { content: "\edbd"; }
.si-ios.si--color::before { color: #000000; }
.si-iota::before { content: "\edbe"; }
.si-iota.si--color::before { color: #131F37; }
.si-ipfs::before { content: "\edbf"; }
.si-ipfs.si--color::before { color: #65C2CB; }
.si-issuu::before { content: "\edc0"; }
.si-issuu.si--color::before { color: #F36D5D; }
.si-istio::before { content: "\edc1"; }
.si-istio.si--color::before { color: #466BB0; }
.si-itchdotio::before { content: "\edc2"; }
.si-itchdotio.si--color::before { color: #FA5C5C; }
.si-iterm2::before { content: "\edc3"; }
.si-iterm2.si--color::before { color: #000000; }
.si-itunes::before { content: "\edc4"; }
.si-itunes.si--color::before { color: #FB5BC5; }
.si-iveco::before { content: "\edc5"; }
.si-iveco.si--color::before { color: #004994; }
.si-jabber::before { content: "\edc6"; }
.si-jabber.si--color::before { color: #CC0000; }
.si-jaguar::before { content: "\edc7"; }
.si-jaguar.si--color::before { color: #FFFFFF; }
.si-jamboard::before { content: "\edc8"; }
.si-jamboard.si--color::before { color: #F37C20; }
.si-jameson::before { content: "\edc9"; }
.si-jameson.si--color::before { color: #004027; }
.si-jasmine::before { content: "\edca"; }
.si-jasmine.si--color::before { color: #8A4182; }
.si-jamstack::before { content: "\edcb"; }
.si-jamstack.si--color::before { color: #F0047F; }
.si-java::before { content: "\edcc"; }
.si-java.si--color::before { color: #007396; }
.si-javascript::before { content: "\edcd"; }
.si-javascript.si--color::before { color: #F7DF1E; }
.si-jbl::before { content: "\edce"; }
.si-jbl.si--color::before { color: #FF3300; }
.si-jcb::before { content: "\edcf"; }
.si-jcb.si--color::before { color: #0B4EA2; }
.si-jeep::before { content: "\edd0"; }
.si-jeep.si--color::before { color: #000000; }
.si-jekyll::before { content: "\edd1"; }
.si-jekyll.si--color::before { color: #CC0000; }
.si-jellyfin::before { content: "\edd2"; }
.si-jellyfin.si--color::before { color: #00A4DC; }
.si-jenkins::before { content: "\edd3"; }
.si-jenkins.si--color::before { color: #D24939; }
.si-jenkinsx::before { content: "\edd4"; }
.si-jenkinsx.si--color::before { color: #73C3D5; }
.si-jest::before { content: "\edd5"; }
.si-jest.si--color::before { color: #C21325; }
.si-jet::before { content: "\edd6"; }
.si-jet.si--color::before { color: #FBBA00; }
.si-jetbrains::before { content: "\edd7"; }
.si-jetbrains.si--color::before { color: #000000; }
.si-jetpackcompose::before { content: "\edd8"; }
.si-jetpackcompose.si--color::before { color: #4285F4; }
.si-jfrog::before { content: "\edd9"; }
.si-jfrog.si--color::before { color: #41BF47; }
.si-jfrogbintray::before { content: "\edda"; }
.si-jfrogbintray.si--color::before { color: #43A047; }
.si-jinja::before { content: "\eddb"; }
.si-jinja.si--color::before { color: #B41717; }
.si-jira::before { content: "\eddc"; }
.si-jira.si--color::before { color: #0052CC; }
.si-jirasoftware::before { content: "\eddd"; }
.si-jirasoftware.si--color::before { color: #0052CC; }
.si-jitsi::before { content: "\edde"; }
.si-jitsi.si--color::before { color: #97979A; }
.si-johndeere::before { content: "\eddf"; }
.si-johndeere.si--color::before { color: #367C2B; }
.si-joomla::before { content: "\ede0"; }
.si-joomla.si--color::before { color: #5091CD; }
.si-joplin::before { content: "\ede1"; }
.si-joplin.si--color::before { color: #1071D3; }
.si-jordan::before { content: "\ede2"; }
.si-jordan.si--color::before { color: #000000; }
.si-jpeg::before { content: "\ede3"; }
.si-jpeg.si--color::before { color: #8A8A8A; }
.si-jquery::before { content: "\ede4"; }
.si-jquery.si--color::before { color: #0769AD; }
.si-jrgroup::before { content: "\ede5"; }
.si-jrgroup.si--color::before { color: #000000; }
.si-jsdelivr::before { content: "\ede6"; }
.si-jsdelivr.si--color::before { color: #E84D3D; }
.si-jsfiddle::before { content: "\ede7"; }
.si-jsfiddle.si--color::before { color: #0084FF; }
.si-json::before { content: "\ede8"; }
.si-json.si--color::before { color: #000000; }
.si-jsonwebtokens::before { content: "\ede9"; }
.si-jsonwebtokens.si--color::before { color: #000000; }
.si-jss::before { content: "\edea"; }
.si-jss.si--color::before { color: #F7DF1E; }
.si-julia::before { content: "\edeb"; }
.si-julia.si--color::before { color: #9558B2; }
.si-junipernetworks::before { content: "\edec"; }
.si-junipernetworks.si--color::before { color: #84B135; }
.si-junit5::before { content: "\eded"; }
.si-junit5.si--color::before { color: #25A162; }
.si-jupyter::before { content: "\edee"; }
.si-jupyter.si--color::before { color: #F37626; }
.si-androidauto::before { content: "\edef"; }
.si-androidauto.si--color::before { color: #3DDC84; }
.si-justeat::before { content: "\edf0"; }
.si-justeat.si--color::before { color: #F36D00; }
.si-justgiving::before { content: "\edf1"; }
.si-justgiving.si--color::before { color: #AD29B6; }
.si-k3s::before { content: "\edf2"; }
.si-k3s.si--color::before { color: #FFC61C; }
.si-kaggle::before { content: "\edf3"; }
.si-kaggle.si--color::before { color: #20BEFF; }
.si-kahoot::before { content: "\edf4"; }
.si-kahoot.si--color::before { color: #46178F; }
.si-kaios::before { content: "\edf5"; }
.si-kaios.si--color::before { color: #6F02B5; }
.si-kakao::before { content: "\edf6"; }
.si-kakao.si--color::before { color: #FFCD00; }
.si-kakaotalk::before { content: "\edf7"; }
.si-kakaotalk.si--color::before { color: #FFCD00; }
.si-kalilinux::before { content: "\edf8"; }
.si-kalilinux.si--color::before { color: #557C94; }
.si-kaniko::before { content: "\edf9"; }
.si-kaniko.si--color::before { color: #FFA600; }
.si-karlsruherverkehrsverbund::before { content: "\edfa"; }
.si-karlsruherverkehrsverbund.si--color::before { color: #9B2321; }
.si-kasasmart::before { content: "\edfb"; }
.si-kasasmart.si--color::before { color: #4ACBD6; }
.si-kashflow::before { content: "\edfc"; }
.si-kashflow.si--color::before { color: #E5426E; }
.si-katacoda::before { content: "\edfd"; }
.si-katacoda.si--color::before { color: #F48220; }
.si-kaspersky::before { content: "\edfe"; }
.si-kaspersky.si--color::before { color: #006D5C; }
.si-katana::before { content: "\edff"; }
.si-katana.si--color::before { color: #000000; }
.si-kaufland::before { content: "\ee00"; }
.si-kaufland.si--color::before { color: #E10915; }
.si-kde::before { content: "\ee01"; }
.si-kde.si--color::before { color: #1D99F3; }
.si-kdenlive::before { content: "\ee02"; }
.si-kdenlive.si--color::before { color: #527EB2; }
.si-kentico::before { content: "\ee03"; }
.si-kentico.si--color::before { color: #F05A22; }
.si-keepassxc::before { content: "\ee04"; }
.si-keepassxc.si--color::before { color: #6CAC4D; }
.si-keras::before { content: "\ee05"; }
.si-keras.si--color::before { color: #D00000; }
.si-keybase::before { content: "\ee06"; }
.si-keybase.si--color::before { color: #33A0FF; }
.si-keycdn::before { content: "\ee07"; }
.si-keycdn.si--color::before { color: #047AED; }
.si-kfc::before { content: "\ee08"; }
.si-kfc.si--color::before { color: #F40027; }
.si-khanacademy::before { content: "\ee09"; }
.si-khanacademy.si--color::before { color: #14BF96; }
.si-kia::before { content: "\ee0a"; }
.si-kia.si--color::before { color: #05141F; }
.si-khronosgroup::before { content: "\ee0b"; }
.si-khronosgroup.si--color::before { color: #CC3333; }
.si-kickstarter::before { content: "\ee0c"; }
.si-kickstarter.si--color::before { color: #05CE78; }
.si-kibana::before { content: "\ee0d"; }
.si-kibana.si--color::before { color: #005571; }
.si-kik::before { content: "\ee0e"; }
.si-kik.si--color::before { color: #82BC23; }
.si-kingstontechnology::before { content: "\ee0f"; }
.si-kingstontechnology.si--color::before { color: #000000; }
.si-kinopoisk::before { content: "\ee10"; }
.si-kinopoisk.si--color::before { color: #FF6600; }
.si-kirby::before { content: "\ee11"; }
.si-kirby.si--color::before { color: #000000; }
.si-kitsu::before { content: "\ee12"; }
.si-kitsu.si--color::before { color: #FD755C; }
.si-klarna::before { content: "\ee13"; }
.si-klarna.si--color::before { color: #FFB3C7; }
.si-klm::before { content: "\ee14"; }
.si-klm.si--color::before { color: #00A1DE; }
.si-klook::before { content: "\ee15"; }
.si-klook.si--color::before { color: #FF5722; }
.si-knative::before { content: "\ee16"; }
.si-knative.si--color::before { color: #0865AD; }
.si-knowledgebase::before { content: "\ee17"; }
.si-knowledgebase.si--color::before { color: #FFD000; }
.si-known::before { content: "\ee18"; }
.si-known.si--color::before { color: #333333; }
.si-kofi::before { content: "\ee19"; }
.si-kofi.si--color::before { color: #FF5E5B; }
.si-koa::before { content: "\ee1a"; }
.si-koa.si--color::before { color: #33333D; }
.si-koc::before { content: "\ee1b"; }
.si-koc.si--color::before { color: #F9423A; }
.si-kodi::before { content: "\ee1c"; }
.si-kodi.si--color::before { color: #17B2E7; }
.si-kofax::before { content: "\ee1d"; }
.si-kofax.si--color::before { color: #00558C; }
.si-konami::before { content: "\ee1e"; }
.si-konami.si--color::before { color: #B60014; }
.si-komoot::before { content: "\ee1f"; }
.si-komoot.si--color::before { color: #6AA127; }
.si-kong::before { content: "\ee20"; }
.si-kong.si--color::before { color: #003459; }
.si-kongregate::before { content: "\ee21"; }
.si-kongregate.si--color::before { color: #990000; }
.si-konva::before { content: "\ee22"; }
.si-konva.si--color::before { color: #0D83CD; }
.si-kotlin::before { content: "\ee23"; }
.si-kotlin.si--color::before { color: #7F52FF; }
.si-krita::before { content: "\ee24"; }
.si-krita.si--color::before { color: #3BABFF; }
.si-ktm::before { content: "\ee25"; }
.si-ktm.si--color::before { color: #FF6600; }
.si-kuaishou::before { content: "\ee26"; }
.si-kuaishou.si--color::before { color: #FF4906; }
.si-kubernetes::before { content: "\ee27"; }
.si-kubernetes.si--color::before { color: #326CE5; }
.si-kuma::before { content: "\ee28"; }
.si-kuma.si--color::before { color: #290B53; }
.si-kubuntu::before { content: "\ee29"; }
.si-kubuntu.si--color::before { color: #0079C1; }
.si-kyocera::before { content: "\ee2a"; }
.si-kyocera.si--color::before { color: #DF0522; }
.si-labview::before { content: "\ee2b"; }
.si-labview.si--color::before { color: #FFDB00; }
.si-lada::before { content: "\ee2c"; }
.si-lada.si--color::before { color: #ED6B21; }
.si-lamborghini::before { content: "\ee2d"; }
.si-lamborghini.si--color::before { color: #DDB320; }
.si-landrover::before { content: "\ee2e"; }
.si-landrover.si--color::before { color: #005A2B; }
.si-lapce::before { content: "\ee2f"; }
.si-lapce.si--color::before { color: #3B82F6; }
.si-laragon::before { content: "\ee30"; }
.si-laragon.si--color::before { color: #0E83CD; }
.si-laravel::before { content: "\ee31"; }
.si-laravel.si--color::before { color: #FF2D20; }
.si-laravelnova::before { content: "\ee32"; }
.si-laravelnova.si--color::before { color: #252D37; }
.si-laravelhorizon::before { content: "\ee33"; }
.si-laravelhorizon.si--color::before { color: #405263; }
.si-lastdotfm::before { content: "\ee34"; }
.si-lastdotfm.si--color::before { color: #D51007; }
.si-lastpass::before { content: "\ee35"; }
.si-lastpass.si--color::before { color: #D32D27; }
.si-latex::before { content: "\ee36"; }
.si-latex.si--color::before { color: #008080; }
.si-launchpad::before { content: "\ee37"; }
.si-launchpad.si--color::before { color: #F8C300; }
.si-lazarus::before { content: "\ee38"; }
.si-lazarus.si--color::before { color: #000000; }
.si-leaderprice::before { content: "\ee39"; }
.si-leaderprice.si--color::before { color: #E50005; }
.si-lbry::before { content: "\ee3a"; }
.si-lbry.si--color::before { color: #2F9176; }
.si-leaflet::before { content: "\ee3b"; }
.si-leaflet.si--color::before { color: #199900; }
.si-leetcode::before { content: "\ee3c"; }
.si-leetcode.si--color::before { color: #FFA116; }
.si-leanpub::before { content: "\ee3d"; }
.si-leanpub.si--color::before { color: #FFFFFF; }
.si-lemmy::before { content: "\ee3e"; }
.si-lemmy.si--color::before { color: #FFFFFF; }
.si-lenovo::before { content: "\ee3f"; }
.si-lenovo.si--color::before { color: #E2231A; }
.si-lens::before { content: "\ee40"; }
.si-lens.si--color::before { color: #3D90CE; }
.si-lerna::before { content: "\ee41"; }
.si-lerna.si--color::before { color: #2F0268; }
.si-leroymerlin::before { content: "\ee42"; }
.si-leroymerlin.si--color::before { color: #78BE20; }
.si-less::before { content: "\ee43"; }
.si-less.si--color::before { color: #1D365D; }
.si-letsencrypt::before { content: "\ee44"; }
.si-letsencrypt.si--color::before { color: #003A70; }
.si-letterboxd::before { content: "\ee45"; }
.si-letterboxd.si--color::before { color: #00D735; }
.si-levelsdotfyi::before { content: "\ee46"; }
.si-levelsdotfyi.si--color::before { color: #788B95; }
.si-lg::before { content: "\ee47"; }
.si-lg.si--color::before { color: #A50034; }
.si-lgtm::before { content: "\ee48"; }
.si-lgtm.si--color::before { color: #FFFFFF; }
.si-liberapay::before { content: "\ee49"; }
.si-liberapay.si--color::before { color: #F6C915; }
.si-librarything::before { content: "\ee4a"; }
.si-librarything.si--color::before { color: #251A15; }
.si-librariesdotio::before { content: "\ee4b"; }
.si-librariesdotio.si--color::before { color: #337AB7; }
.si-libreoffice::before { content: "\ee4c"; }
.si-libreoffice.si--color::before { color: #18A303; }
.si-libuv::before { content: "\ee4d"; }
.si-libuv.si--color::before { color: #403C3D; }
.si-lichess::before { content: "\ee4e"; }
.si-lichess.si--color::before { color: #000000; }
.si-lidl::before { content: "\ee4f"; }
.si-lidl.si--color::before { color: #0050AA; }
.si-lifx::before { content: "\ee50"; }
.si-lifx.si--color::before { color: #000000; }
.si-lighthouse::before { content: "\ee51"; }
.si-lighthouse.si--color::before { color: #F44B21; }
.si-lineageos::before { content: "\ee52"; }
.si-lineageos.si--color::before { color: #167C80; }
.si-line::before { content: "\ee53"; }
.si-line.si--color::before { color: #00C300; }
.si-linkedin::before { content: "\ee54"; }
.si-linkedin.si--color::before { color: #0A66C2; }
.si-linkerd::before { content: "\ee55"; }
.si-linkerd.si--color::before { color: #2BEDA7; }
.si-linkfire::before { content: "\ee56"; }
.si-linkfire.si--color::before { color: #FF3850; }
.si-linktree::before { content: "\ee57"; }
.si-linktree.si--color::before { color: #39E09B; }
.si-linode::before { content: "\ee58"; }
.si-linode.si--color::before { color: #00A95C; }
.si-linux::before { content: "\ee59"; }
.si-linux.si--color::before { color: #FCC624; }
.si-linuxcontainers::before { content: "\ee5a"; }
.si-linuxcontainers.si--color::before { color: #333333; }
.si-linuxfoundation::before { content: "\ee5b"; }
.si-linuxfoundation.si--color::before { color: #003366; }
.si-lionair::before { content: "\ee5c"; }
.si-lionair.si--color::before { color: #ED3237; }
.si-linuxmint::before { content: "\ee5d"; }
.si-linuxmint.si--color::before { color: #87CF3E; }
.si-liquibase::before { content: "\ee5e"; }
.si-liquibase.si--color::before { color: #2962FF; }
.si-lit::before { content: "\ee5f"; }
.si-lit.si--color::before { color: #324FFF; }
.si-litecoin::before { content: "\ee60"; }
.si-litecoin.si--color::before { color: #A6A9AA; }
.si-livechat::before { content: "\ee61"; }
.si-livechat.si--color::before { color: #FFD000; }
.si-livewire::before { content: "\ee62"; }
.si-livewire.si--color::before { color: #4E56A6; }
.si-livejournal::before { content: "\ee63"; }
.si-livejournal.si--color::before { color: #00B0EA; }
.si-llvm::before { content: "\ee64"; }
.si-llvm.si--color::before { color: #262D3A; }
.si-lmms::before { content: "\ee65"; }
.si-lmms.si--color::before { color: #10B146; }
.si-lodash::before { content: "\ee66"; }
.si-lodash.si--color::before { color: #3492FF; }
.si-logmein::before { content: "\ee67"; }
.si-logmein.si--color::before { color: #45B6F2; }
.si-logitech::before { content: "\ee68"; }
.si-logitech.si--color::before { color: #00B8FC; }
.si-logstash::before { content: "\ee69"; }
.si-logstash.si--color::before { color: #005571; }
.si-looker::before { content: "\ee6a"; }
.si-looker.si--color::before { color: #4285F4; }
.si-loom::before { content: "\ee6b"; }
.si-loom.si--color::before { color: #625DF5; }
.si-loop::before { content: "\ee6c"; }
.si-loop.si--color::before { color: #F29400; }
.si-loopback::before { content: "\ee6d"; }
.si-loopback.si--color::before { color: #3F5DFF; }
.si-lospec::before { content: "\ee6e"; }
.si-lospec.si--color::before { color: #EAEAEA; }
.si-lotpolishairlines::before { content: "\ee6f"; }
.si-lotpolishairlines.si--color::before { color: #11397E; }
.si-lua::before { content: "\ee70"; }
.si-lua.si--color::before { color: #2C2D72; }
.si-lubuntu::before { content: "\ee71"; }
.si-lubuntu.si--color::before { color: #0068C8; }
.si-lufthansa::before { content: "\ee72"; }
.si-lufthansa.si--color::before { color: #05164D; }
.si-lumen::before { content: "\ee73"; }
.si-lumen.si--color::before { color: #E74430; }
.si-lunacy::before { content: "\ee74"; }
.si-lunacy.si--color::before { color: #179DE3; }
.si-lyft::before { content: "\ee75"; }
.si-lyft.si--color::before { color: #FF00BF; }
.si-lydia::before { content: "\ee76"; }
.si-lydia.si--color::before { color: #0180FF; }
.si-maas::before { content: "\ee77"; }
.si-maas.si--color::before { color: #E95420; }
.si-macos::before { content: "\ee78"; }
.si-macos.si--color::before { color: #000000; }
.si-macys::before { content: "\ee79"; }
.si-macys.si--color::before { color: #E21A2C; }
.si-magasinsu::before { content: "\ee7a"; }
.si-magasinsu.si--color::before { color: #E71B34; }
.si-magento::before { content: "\ee7b"; }
.si-magento.si--color::before { color: #EE672F; }
.si-magisk::before { content: "\ee7c"; }
.si-magisk.si--color::before { color: #00AF9C; }
.si-maildotru::before { content: "\ee7d"; }
.si-maildotru.si--color::before { color: #005FF9; }
.si-mailchimp::before { content: "\ee7e"; }
.si-mailchimp.si--color::before { color: #FFE01B; }
.si-mailgun::before { content: "\ee7f"; }
.si-mailgun.si--color::before { color: #F06B66; }
.si-majorleaguehacking::before { content: "\ee80"; }
.si-majorleaguehacking.si--color::before { color: #265A8F; }
.si-makerbot::before { content: "\ee81"; }
.si-makerbot.si--color::before { color: #FF1E0D; }
.si-mamp::before { content: "\ee82"; }
.si-mamp.si--color::before { color: #02749C; }
.si-manageiq::before { content: "\ee83"; }
.si-manageiq.si--color::before { color: #EF2929; }
.si-man::before { content: "\ee84"; }
.si-man.si--color::before { color: #E40045; }
.si-manjaro::before { content: "\ee85"; }
.si-manjaro.si--color::before { color: #35BF5C; }
.si-mapbox::before { content: "\ee86"; }
.si-mapbox.si--color::before { color: #000000; }
.si-mariadb::before { content: "\ee87"; }
.si-mariadb.si--color::before { color: #003545; }
.si-mariadbfoundation::before { content: "\ee88"; }
.si-mariadbfoundation.si--color::before { color: #1F305F; }
.si-markdown::before { content: "\ee89"; }
.si-markdown.si--color::before { color: #000000; }
.si-marketo::before { content: "\ee8a"; }
.si-marketo.si--color::before { color: #5C4C9F; }
.si-marko::before { content: "\ee8b"; }
.si-marko.si--color::before { color: #2596BE; }
.si-marriott::before { content: "\ee8c"; }
.si-marriott.si--color::before { color: #A70023; }
.si-maserati::before { content: "\ee8d"; }
.si-maserati.si--color::before { color: #0C2340; }
.si-mastercard::before { content: "\ee8e"; }
.si-mastercard.si--color::before { color: #EB001B; }
.si-mastercomfig::before { content: "\ee8f"; }
.si-mastercomfig.si--color::before { color: #009688; }
.si-mastodon::before { content: "\ee90"; }
.si-mastodon.si--color::before { color: #3088D4; }
.si-materialdesign::before { content: "\ee91"; }
.si-materialdesign.si--color::before { color: #757575; }
.si-materialdesignicons::before { content: "\ee92"; }
.si-materialdesignicons.si--color::before { color: #2196F3; }
.si-matomo::before { content: "\ee93"; }
.si-matomo.si--color::before { color: #3152A0; }
.si-matrix::before { content: "\ee94"; }
.si-matrix.si--color::before { color: #000000; }
.si-matterdotjs::before { content: "\ee95"; }
.si-matterdotjs.si--color::before { color: #4B5562; }
.si-mattermost::before { content: "\ee96"; }
.si-mattermost.si--color::before { color: #0058CC; }
.si-matternet::before { content: "\ee97"; }
.si-matternet.si--color::before { color: #261C29; }
.si-max::before { content: "\ee98"; }
.si-max.si--color::before { color: #525252; }
.si-maytag::before { content: "\ee99"; }
.si-maytag.si--color::before { color: #002E5F; }
.si-maxplanckgesellschaft::before { content: "\ee9a"; }
.si-maxplanckgesellschaft.si--color::before { color: #006C66; }
.si-mazda::before { content: "\ee9b"; }
.si-mazda.si--color::before { color: #101010; }
.si-mcafee::before { content: "\ee9c"; }
.si-mcafee.si--color::before { color: #C01818; }
.si-mclaren::before { content: "\ee9d"; }
.si-mclaren.si--color::before { color: #FF0000; }
.si-mcdonalds::before { content: "\ee9e"; }
.si-mcdonalds.si--color::before { color: #FBC817; }
.si-mdbook::before { content: "\ee9f"; }
.si-mdbook.si--color::before { color: #000000; }
.si-mdnwebdocs::before { content: "\eea0"; }
.si-mdnwebdocs.si--color::before { color: #000000; }
.si-mdx::before { content: "\eea1"; }
.si-mdx.si--color::before { color: #1B1F24; }
.si-mediafire::before { content: "\eea2"; }
.si-mediafire.si--color::before { color: #1299F3; }
.si-mediatek::before { content: "\eea3"; }
.si-mediatek.si--color::before { color: #EC9430; }
.si-mediamarkt::before { content: "\eea4"; }
.si-mediamarkt.si--color::before { color: #DF0000; }
.si-medium::before { content: "\eea5"; }
.si-medium.si--color::before { color: #000000; }
.si-mediatemple::before { content: "\eea6"; }
.si-mediatemple.si--color::before { color: #000000; }
.si-meetup::before { content: "\eea7"; }
.si-meetup.si--color::before { color: #ED1C40; }
.si-mega::before { content: "\eea8"; }
.si-mega.si--color::before { color: #D9272E; }
.si-mendeley::before { content: "\eea9"; }
.si-mendeley.si--color::before { color: #9D1620; }
.si-mercedes::before { content: "\eeaa"; }
.si-mercedes.si--color::before { color: #242424; }
.si-merck::before { content: "\eeab"; }
.si-merck.si--color::before { color: #007A73; }
.si-mercurial::before { content: "\eeac"; }
.si-mercurial.si--color::before { color: #999999; }
.si-messenger::before { content: "\eead"; }
.si-messenger.si--color::before { color: #00B2FF; }
.si-meta::before { content: "\eeae"; }
.si-meta.si--color::before { color: #0467DF; }
.si-metabase::before { content: "\eeaf"; }
.si-metabase.si--color::before { color: #509EE3; }
.si-metafilter::before { content: "\eeb0"; }
.si-metafilter.si--color::before { color: #065A8F; }
.si-meteor::before { content: "\eeb1"; }
.si-meteor.si--color::before { color: #DE4F4F; }
.si-metrodelaciudaddemexico::before { content: "\eeb2"; }
.si-metrodelaciudaddemexico.si--color::before { color: #F77E1C; }
.si-metro::before { content: "\eeb3"; }
.si-metro.si--color::before { color: #EF4242; }
.si-metrodemadrid::before { content: "\eeb4"; }
.si-metrodemadrid.si--color::before { color: #255E9C; }
.si-metrodeparis::before { content: "\eeb5"; }
.si-metrodeparis.si--color::before { color: #003E95; }
.si-mewe::before { content: "\eeb6"; }
.si-mewe.si--color::before { color: #17377F; }
.si-microbit::before { content: "\eeb7"; }
.si-microbit.si--color::before { color: #00ED00; }
.si-microdotblog::before { content: "\eeb8"; }
.si-microdotblog.si--color::before { color: #FF8800; }
.si-microgenetics::before { content: "\eeb9"; }
.si-microgenetics.si--color::before { color: #FF0000; }
.si-microsoft::before { content: "\eeba"; }
.si-microsoft.si--color::before { color: #5E5E5E; }
.si-micropython::before { content: "\eebb"; }
.si-micropython.si--color::before { color: #2B2728; }
.si-microsoftacademic::before { content: "\eebc"; }
.si-microsoftacademic.si--color::before { color: #2D9FD9; }
.si-microsoftaccess::before { content: "\eebd"; }
.si-microsoftaccess.si--color::before { color: #A4373A; }
.si-microsoftazure::before { content: "\eebe"; }
.si-microsoftazure.si--color::before { color: #0078D4; }
.si-microsoftbing::before { content: "\eebf"; }
.si-microsoftbing.si--color::before { color: #258FFA; }
.si-microsoftedge::before { content: "\eec0"; }
.si-microsoftedge.si--color::before { color: #0078D7; }
.si-microsoftexcel::before { content: "\eec1"; }
.si-microsoftexcel.si--color::before { color: #217346; }
.si-microsoftexchange::before { content: "\eec2"; }
.si-microsoftexchange.si--color::before { color: #0078D4; }
.si-microsoftoffice::before { content: "\eec3"; }
.si-microsoftoffice.si--color::before { color: #D83B01; }
.si-microsoftonenote::before { content: "\eec4"; }
.si-microsoftonenote.si--color::before { color: #7719AA; }
.si-microsoftonedrive::before { content: "\eec5"; }
.si-microsoftonedrive.si--color::before { color: #0078D4; }
.si-microsoftoutlook::before { content: "\eec6"; }
.si-microsoftoutlook.si--color::before { color: #0078D4; }
.si-microsoftpowerpoint::before { content: "\eec7"; }
.si-microsoftpowerpoint.si--color::before { color: #B7472A; }
.si-microsoftsharepoint::before { content: "\eec8"; }
.si-microsoftsharepoint.si--color::before { color: #0078D4; }
.si-microsoftsqlserver::before { content: "\eec9"; }
.si-microsoftsqlserver.si--color::before { color: #CC2927; }
.si-microsoftteams::before { content: "\eeca"; }
.si-microsoftteams.si--color::before { color: #6264A7; }
.si-microsofttranslator::before { content: "\eecb"; }
.si-microsofttranslator.si--color::before { color: #057B00; }
.si-microsoftvisio::before { content: "\eecc"; }
.si-microsoftvisio.si--color::before { color: #3955A3; }
.si-microsoftword::before { content: "\eecd"; }
.si-microsoftword.si--color::before { color: #2B579A; }
.si-midi::before { content: "\eece"; }
.si-midi.si--color::before { color: #000000; }
.si-microstrategy::before { content: "\eecf"; }
.si-microstrategy.si--color::before { color: #D9232E; }
.si-minds::before { content: "\eed0"; }
.si-minds.si--color::before { color: #FED12F; }
.si-minecraft::before { content: "\eed1"; }
.si-minecraft.si--color::before { color: #62B47A; }
.si-minetest::before { content: "\eed2"; }
.si-minetest.si--color::before { color: #53AC56; }
.si-mini::before { content: "\eed3"; }
.si-mini.si--color::before { color: #000000; }
.si-minutemailer::before { content: "\eed4"; }
.si-minutemailer.si--color::before { color: #30B980; }
.si-miro::before { content: "\eed5"; }
.si-miro.si--color::before { color: #050038; }
.si-mitsubishi::before { content: "\eed6"; }
.si-mitsubishi.si--color::before { color: #E60012; }
.si-mix::before { content: "\eed7"; }
.si-mix.si--color::before { color: #FF8126; }
.si-mixcloud::before { content: "\eed8"; }
.si-mixcloud.si--color::before { color: #5000FF; }
.si-mlb::before { content: "\eed9"; }
.si-mlb.si--color::before { color: #041E42; }
.si-mobx::before { content: "\eeda"; }
.si-mobx.si--color::before { color: #FF9955; }
.si-mobxstatetree::before { content: "\eedb"; }
.si-mobxstatetree.si--color::before { color: #FF7102; }
.si-modx::before { content: "\eedc"; }
.si-modx.si--color::before { color: #102C53; }
.si-mocha::before { content: "\eedd"; }
.si-mocha.si--color::before { color: #8D6748; }
.si-mojangstudios::before { content: "\eede"; }
.si-mojangstudios.si--color::before { color: #EF323D; }
.si-moleculer::before { content: "\eedf"; }
.si-moleculer.si--color::before { color: #3CAFCE; }
.si-momenteo::before { content: "\eee0"; }
.si-momenteo.si--color::before { color: #5A6AB1; }
.si-moneygram::before { content: "\eee1"; }
.si-moneygram.si--color::before { color: #FF6600; }
.si-monero::before { content: "\eee2"; }
.si-monero.si--color::before { color: #FF6600; }
.si-mongodb::before { content: "\eee3"; }
.si-mongodb.si--color::before { color: #47A248; }
.si-monoprix::before { content: "\eee4"; }
.si-monoprix.si--color::before { color: #FB1911; }
.si-monkeytie::before { content: "\eee5"; }
.si-monkeytie.si--color::before { color: #1A52C2; }
.si-monster::before { content: "\eee6"; }
.si-monster.si--color::before { color: #6D4C9F; }
.si-monzo::before { content: "\eee7"; }
.si-monzo.si--color::before { color: #14233C; }
.si-moo::before { content: "\eee8"; }
.si-moo.si--color::before { color: #00945E; }
.si-morrisons::before { content: "\eee9"; }
.si-morrisons.si--color::before { color: #007531; }
.si-moscowmetro::before { content: "\eeea"; }
.si-moscowmetro.si--color::before { color: #D9232E; }
.si-motorola::before { content: "\eeeb"; }
.si-motorola.si--color::before { color: #E1140A; }
.si-mozilla::before { content: "\eeec"; }
.si-mozilla.si--color::before { color: #000000; }
.si-msi::before { content: "\eeed"; }
.si-msi.si--color::before { color: #FF0000; }
.si-mta::before { content: "\eeee"; }
.si-mta.si--color::before { color: #0039A6; }
.si-mtr::before { content: "\eeef"; }
.si-mtr.si--color::before { color: #AC2E45; }
.si-mui::before { content: "\eef0"; }
.si-mui.si--color::before { color: #007FFF; }
.si-mulesoft::before { content: "\eef1"; }
.si-mulesoft.si--color::before { color: #00A0DF; }
.si-muller::before { content: "\eef2"; }
.si-muller.si--color::before { color: #F46519; }
.si-mumble::before { content: "\eef3"; }
.si-mumble.si--color::before { color: #FFFFFF; }
.si-musescore::before { content: "\eef4"; }
.si-musescore.si--color::before { color: #1A70B8; }
.si-musicbrainz::before { content: "\eef5"; }
.si-musicbrainz.si--color::before { color: #BA478F; }
.si-mxlinux::before { content: "\eef6"; }
.si-mxlinux.si--color::before { color: #000000; }
.si-myanimelist::before { content: "\eef7"; }
.si-myanimelist.si--color::before { color: #2E51A2; }
.si-myob::before { content: "\eef8"; }
.si-myob.si--color::before { color: #6100A5; }
.si-myspace::before { content: "\eef9"; }
.si-myspace.si--color::before { color: #030303; }
.si-mysql::before { content: "\eefa"; }
.si-mysql.si--color::before { color: #4479A1; }
.si-n26::before { content: "\eefb"; }
.si-n26.si--color::before { color: #48AC98; }
.si-namebase::before { content: "\eefc"; }
.si-namebase.si--color::before { color: #0068FF; }
.si-namecheap::before { content: "\eefd"; }
.si-namecheap.si--color::before { color: #DE3723; }
.si-nano::before { content: "\eefe"; }
.si-nano.si--color::before { color: #4A90E2; }
.si-nasa::before { content: "\eeff"; }
.si-nasa.si--color::before { color: #E03C31; }
.si-nationalgrid::before { content: "\ef00"; }
.si-nationalgrid.si--color::before { color: #00148C; }
.si-naver::before { content: "\ef01"; }
.si-naver.si--color::before { color: #03C75A; }
.si-nativescript::before { content: "\ef02"; }
.si-nativescript.si--color::before { color: #3655FF; }
.si-nba::before { content: "\ef03"; }
.si-nba.si--color::before { color: #253B73; }
.si-nbb::before { content: "\ef04"; }
.si-nbb.si--color::before { color: #FF7100; }
.si-ndr::before { content: "\ef05"; }
.si-ndr.si--color::before { color: #0C1754; }
.si-nec::before { content: "\ef06"; }
.si-nec.si--color::before { color: #1414A0; }
.si-neo4j::before { content: "\ef07"; }
.si-neo4j.si--color::before { color: #008CC1; }
.si-neovim::before { content: "\ef08"; }
.si-neovim.si--color::before { color: #57A143; }
.si-nestjs::before { content: "\ef09"; }
.si-nestjs.si--color::before { color: #E0234E; }
.si-netbsd::before { content: "\ef0a"; }
.si-netbsd.si--color::before { color: #FF6600; }
.si-netapp::before { content: "\ef0b"; }
.si-netapp.si--color::before { color: #0067C5; }
.si-netflix::before { content: "\ef0c"; }
.si-netflix.si--color::before { color: #E50914; }
.si-netlify::before { content: "\ef0d"; }
.si-netlify.si--color::before { color: #00C7B7; }
.si-nette::before { content: "\ef0e"; }
.si-nette.si--color::before { color: #3484D2; }
.si-netto::before { content: "\ef0f"; }
.si-netto.si--color::before { color: #FFE500; }
.si-newbalance::before { content: "\ef10"; }
.si-newbalance.si--color::before { color: #CF0A2C; }
.si-newjapanprowrestling::before { content: "\ef11"; }
.si-newjapanprowrestling.si--color::before { color: #FF160B; }
.si-newrelic::before { content: "\ef12"; }
.si-newrelic.si--color::before { color: #008C99; }
.si-newyorktimes::before { content: "\ef13"; }
.si-newyorktimes.si--color::before { color: #000000; }
.si-nextdotjs::before { content: "\ef14"; }
.si-nextdotjs.si--color::before { color: #000000; }
.si-nextcloud::before { content: "\ef15"; }
.si-nextcloud.si--color::before { color: #0082C9; }
.si-nextdoor::before { content: "\ef16"; }
.si-nextdoor.si--color::before { color: #8ED500; }
.si-nfc::before { content: "\ef17"; }
.si-nfc.si--color::before { color: #002E5F; }
.si-nginx::before { content: "\ef18"; }
.si-nginx.si--color::before { color: #009639; }
.si-ngrok::before { content: "\ef19"; }
.si-ngrok.si--color::before { color: #1F1E37; }
.si-nike::before { content: "\ef1a"; }
.si-nike.si--color::before { color: #111111; }
.si-niconico::before { content: "\ef1b"; }
.si-niconico.si--color::before { color: #231815; }
.si-nim::before { content: "\ef1c"; }
.si-nim.si--color::before { color: #FFE953; }
.si-nintendo::before { content: "\ef1d"; }
.si-nintendo.si--color::before { color: #8F8F8F; }
.si-nintendo3ds::before { content: "\ef1e"; }
.si-nintendo3ds.si--color::before { color: #D12228; }
.si-nintendogamecube::before { content: "\ef1f"; }
.si-nintendogamecube.si--color::before { color: #6A5FBB; }
.si-nintendonetwork::before { content: "\ef20"; }
.si-nintendonetwork.si--color::before { color: #FF7D00; }
.si-nintendoswitch::before { content: "\ef21"; }
.si-nintendoswitch.si--color::before { color: #E60012; }
.si-nixos::before { content: "\ef22"; }
.si-nixos.si--color::before { color: #5277C3; }
.si-nissan::before { content: "\ef23"; }
.si-nissan.si--color::before { color: #C3002F; }
.si-nodedotjs::before { content: "\ef24"; }
.si-nodedotjs.si--color::before { color: #339933; }
.si-nodered::before { content: "\ef25"; }
.si-nodered.si--color::before { color: #8F0000; }
.si-nodemon::before { content: "\ef26"; }
.si-nodemon.si--color::before { color: #76D04B; }
.si-nokia::before { content: "\ef27"; }
.si-nokia.si--color::before { color: #124191; }
.si-norco::before { content: "\ef28"; }
.si-norco.si--color::before { color: #00FF00; }
.si-nordvpn::before { content: "\ef29"; }
.si-nordvpn.si--color::before { color: #4687FF; }
.si-norwegian::before { content: "\ef2a"; }
.si-norwegian.si--color::before { color: #D81939; }
.si-notepadplusplus::before { content: "\ef2b"; }
.si-notepadplusplus.si--color::before { color: #90E59A; }
.si-notion::before { content: "\ef2c"; }
.si-notion.si--color::before { color: #000000; }
.si-notist::before { content: "\ef2d"; }
.si-notist.si--color::before { color: #333333; }
.si-nounproject::before { content: "\ef2e"; }
.si-nounproject.si--color::before { color: #000000; }
.si-now::before { content: "\ef2f"; }
.si-now.si--color::before { color: #001211; }
.si-npm::before { content: "\ef30"; }
.si-npm.si--color::before { color: #CB3837; }
.si-nrwl::before { content: "\ef31"; }
.si-nrwl.si--color::before { color: #96D7E8; }
.si-nubank::before { content: "\ef32"; }
.si-nubank.si--color::before { color: #820AD1; }
.si-nucleo::before { content: "\ef33"; }
.si-nucleo.si--color::before { color: #252B2D; }
.si-nuget::before { content: "\ef34"; }
.si-nuget.si--color::before { color: #004880; }
.si-nuke::before { content: "\ef35"; }
.si-nuke.si--color::before { color: #000000; }
.si-numba::before { content: "\ef36"; }
.si-numba.si--color::before { color: #00A3E0; }
.si-numpy::before { content: "\ef37"; }
.si-numpy.si--color::before { color: #013243; }
.si-nutanix::before { content: "\ef38"; }
.si-nutanix.si--color::before { color: #024DA1; }
.si-nuxtdotjs::before { content: "\ef39"; }
.si-nuxtdotjs.si--color::before { color: #00DC82; }
.si-nx::before { content: "\ef3a"; }
.si-nx.si--color::before { color: #143055; }
.si-nzxt::before { content: "\ef3b"; }
.si-nzxt.si--color::before { color: #000000; }
.si-nvidia::before { content: "\ef3c"; }
.si-nvidia.si--color::before { color: #76B900; }
.si-oreilly::before { content: "\ef3d"; }
.si-oreilly.si--color::before { color: #D3002D; }
.si-obsstudio::before { content: "\ef3e"; }
.si-obsstudio.si--color::before { color: #302E31; }
.si-observable::before { content: "\ef3f"; }
.si-observable.si--color::before { color: #353E58; }
.si-obsidian::before { content: "\ef40"; }
.si-obsidian.si--color::before { color: #483699; }
.si-ocaml::before { content: "\ef41"; }
.si-ocaml.si--color::before { color: #EC6813; }
.si-octanerender::before { content: "\ef42"; }
.si-octanerender.si--color::before { color: #000000; }
.si-oculus::before { content: "\ef43"; }
.si-oculus.si--color::before { color: #1C1E20; }
.si-octave::before { content: "\ef44"; }
.si-octave.si--color::before { color: #0790C0; }
.si-octopusdeploy::before { content: "\ef45"; }
.si-octopusdeploy.si--color::before { color: #2F93E0; }
.si-odnoklassniki::before { content: "\ef46"; }
.si-odnoklassniki.si--color::before { color: #EE8208; }
.si-odysee::before { content: "\ef47"; }
.si-odysee.si--color::before { color: #EF1970; }
.si-ohdear::before { content: "\ef48"; }
.si-ohdear.si--color::before { color: #FFFFFF; }
.si-okcupid::before { content: "\ef49"; }
.si-okcupid.si--color::before { color: #0500BE; }
.si-okta::before { content: "\ef4a"; }
.si-okta.si--color::before { color: #007DC1; }
.si-oneplus::before { content: "\ef4b"; }
.si-oneplus.si--color::before { color: #F5010C; }
.si-onlyfans::before { content: "\ef4c"; }
.si-onlyfans.si--color::before { color: #00AFF0; }
.si-onlyoffice::before { content: "\ef4d"; }
.si-onlyoffice.si--color::before { color: #444444; }
.si-onnx::before { content: "\ef4e"; }
.si-onnx.si--color::before { color: #005CED; }
.si-onstar::before { content: "\ef4f"; }
.si-onstar.si--color::before { color: #003D7D; }
.si-opel::before { content: "\ef50"; }
.si-opel.si--color::before { color: #F7FF14; }
.si-openaccess::before { content: "\ef51"; }
.si-openaccess.si--color::before { color: #F68212; }
.si-openbadges::before { content: "\ef52"; }
.si-openbadges.si--color::before { color: #073B5A; }
.si-openbugbounty::before { content: "\ef53"; }
.si-openbugbounty.si--color::before { color: #F67909; }
.si-opencontainersinitiative::before { content: "\ef54"; }
.si-opencontainersinitiative.si--color::before { color: #262261; }
.si-opencollective::before { content: "\ef55"; }
.si-opencollective.si--color::before { color: #7FADF2; }
.si-opensourceinitiative::before { content: "\ef56"; }
.si-opensourceinitiative.si--color::before { color: #3DA639; }
.si-openaigym::before { content: "\ef57"; }
.si-openaigym.si--color::before { color: #0081A5; }
.si-openai::before { content: "\ef58"; }
.si-openai.si--color::before { color: #412991; }
.si-openapiinitiative::before { content: "\ef59"; }
.si-openapiinitiative.si--color::before { color: #6BA539; }
.si-openbsd::before { content: "\ef5a"; }
.si-openbsd.si--color::before { color: #F2CA30; }
.si-opencv::before { content: "\ef5b"; }
.si-opencv.si--color::before { color: #5C3EE8; }
.si-openfaas::before { content: "\ef5c"; }
.si-openfaas.si--color::before { color: #3B5EE9; }
.si-opengl::before { content: "\ef5d"; }
.si-opengl.si--color::before { color: #5586A4; }
.si-openid::before { content: "\ef5e"; }
.si-openid.si--color::before { color: #F78C40; }
.si-openjdk::before { content: "\ef5f"; }
.si-openjdk.si--color::before { color: #FFFFFF; }
.si-openlayers::before { content: "\ef60"; }
.si-openlayers.si--color::before { color: #1F6B75; }
.si-openmined::before { content: "\ef61"; }
.si-openmined.si--color::before { color: #ED986C; }
.si-opennebula::before { content: "\ef62"; }
.si-opennebula.si--color::before { color: #0097C2; }
.si-opensea::before { content: "\ef63"; }
.si-opensea.si--color::before { color: #2081E2; }
.si-opensearch::before { content: "\ef64"; }
.si-opensearch.si--color::before { color: #005EB8; }
.si-openstack::before { content: "\ef65"; }
.si-openstack.si--color::before { color: #ED1944; }
.si-openssl::before { content: "\ef66"; }
.si-openssl.si--color::before { color: #721412; }
.si-openstreetmap::before { content: "\ef67"; }
.si-openstreetmap.si--color::before { color: #7EBC6F; }
.si-opensuse::before { content: "\ef68"; }
.si-opensuse.si--color::before { color: #73BA25; }
.si-opentelemetry::before { content: "\ef69"; }
.si-opentelemetry.si--color::before { color: #000000; }
.si-openvpn::before { content: "\ef6a"; }
.si-openvpn.si--color::before { color: #EA7E20; }
.si-openwrt::before { content: "\ef6b"; }
.si-openwrt.si--color::before { color: #00B5E2; }
.si-openzfs::before { content: "\ef6c"; }
.si-openzfs.si--color::before { color: #2A667F; }
.si-opera::before { content: "\ef6d"; }
.si-opera.si--color::before { color: #FF1B2D; }
.si-opnsense::before { content: "\ef6e"; }
.si-opnsense.si--color::before { color: #D94F00; }
.si-opsgenie::before { content: "\ef6f"; }
.si-opsgenie.si--color::before { color: #172B4D; }
.si-opslevel::before { content: "\ef70"; }
.si-opslevel.si--color::before { color: #1890FF; }
.si-oracle::before { content: "\ef71"; }
.si-oracle.si--color::before { color: #F80000; }
.si-orcid::before { content: "\ef72"; }
.si-orcid.si--color::before { color: #A6CE39; }
.si-origin::before { content: "\ef73"; }
.si-origin.si--color::before { color: #F56C2D; }
.si-org::before { content: "\ef74"; }
.si-org.si--color::before { color: #77AA99; }
.si-osano::before { content: "\ef75"; }
.si-osano.si--color::before { color: #7764FA; }
.si-oshkosh::before { content: "\ef76"; }
.si-oshkosh.si--color::before { color: #E6830F; }
.si-osmc::before { content: "\ef77"; }
.si-osmc.si--color::before { color: #17394A; }
.si-osu::before { content: "\ef78"; }
.si-osu.si--color::before { color: #FF66AA; }
.si-otto::before { content: "\ef79"; }
.si-otto.si--color::before { color: #D4021D; }
.si-overcast::before { content: "\ef7a"; }
.si-overcast.si--color::before { color: #FC7E0F; }
.si-ovh::before { content: "\ef7b"; }
.si-ovh.si--color::before { color: #123F6D; }
.si-overleaf::before { content: "\ef7c"; }
.si-overleaf.si--color::before { color: #47A141; }
.si-owasp::before { content: "\ef7d"; }
.si-owasp.si--color::before { color: #000000; }
.si-oyo::before { content: "\ef7e"; }
.si-oyo.si--color::before { color: #EE2E24; }
.si-oxygen::before { content: "\ef7f"; }
.si-oxygen.si--color::before { color: #3A209E; }
.si-p5dotjs::before { content: "\ef80"; }
.si-p5dotjs.si--color::before { color: #ED225D; }
.si-packagist::before { content: "\ef81"; }
.si-packagist.si--color::before { color: #F28D1A; }
.si-packer::before { content: "\ef82"; }
.si-packer.si--color::before { color: #02A8EF; }
.si-paddypower::before { content: "\ef83"; }
.si-paddypower.si--color::before { color: #004833; }
.si-pagekit::before { content: "\ef84"; }
.si-pagekit.si--color::before { color: #212121; }
.si-pagespeedinsights::before { content: "\ef85"; }
.si-pagespeedinsights.si--color::before { color: #4285F4; }
.si-pagseguro::before { content: "\ef86"; }
.si-pagseguro.si--color::before { color: #FFC801; }
.si-pagerduty::before { content: "\ef87"; }
.si-pagerduty.si--color::before { color: #06AC38; }
.si-palantir::before { content: "\ef88"; }
.si-palantir.si--color::before { color: #101113; }
.si-paloaltosoftware::before { content: "\ef89"; }
.si-paloaltosoftware.si--color::before { color: #83DA77; }
.si-pandas::before { content: "\ef8a"; }
.si-pandas.si--color::before { color: #150458; }
.si-pandora::before { content: "\ef8b"; }
.si-pandora.si--color::before { color: #224099; }
.si-pantheon::before { content: "\ef8c"; }
.si-pantheon.si--color::before { color: #FFDC28; }
.si-paperspace::before { content: "\ef8d"; }
.si-paperspace.si--color::before { color: #000000; }
.si-paritysubstrate::before { content: "\ef8e"; }
.si-paritysubstrate.si--color::before { color: #282828; }
.si-parsedotly::before { content: "\ef8f"; }
.si-parsedotly.si--color::before { color: #5BA745; }
.si-passport::before { content: "\ef90"; }
.si-passport.si--color::before { color: #34E27A; }
.si-pastebin::before { content: "\ef91"; }
.si-pastebin.si--color::before { color: #02456C; }
.si-patreon::before { content: "\ef92"; }
.si-patreon.si--color::before { color: #FF424D; }
.si-payoneer::before { content: "\ef93"; }
.si-payoneer.si--color::before { color: #FF4800; }
.si-paytm::before { content: "\ef94"; }
.si-paytm.si--color::before { color: #20336B; }
.si-paypal::before { content: "\ef95"; }
.si-paypal.si--color::before { color: #00457C; }
.si-pcgamingwiki::before { content: "\ef96"; }
.si-pcgamingwiki.si--color::before { color: #556DB3; }
.si-peakdesign::before { content: "\ef97"; }
.si-peakdesign.si--color::before { color: #1C1B1C; }
.si-peertube::before { content: "\ef98"; }
.si-peertube.si--color::before { color: #F1680D; }
.si-pegasusairlines::before { content: "\ef99"; }
.si-pegasusairlines.si--color::before { color: #FDC43E; }
.si-pelican::before { content: "\ef9a"; }
.si-pelican.si--color::before { color: #14A0C4; }
.si-peloton::before { content: "\ef9b"; }
.si-peloton.si--color::before { color: #181A1D; }
.si-penny::before { content: "\ef9c"; }
.si-penny.si--color::before { color: #CD1414; }
.si-pepsi::before { content: "\ef9d"; }
.si-pepsi.si--color::before { color: #2151A1; }
.si-percy::before { content: "\ef9e"; }
.si-percy.si--color::before { color: #9E66BF; }
.si-perforce::before { content: "\ef9f"; }
.si-perforce.si--color::before { color: #404040; }
.si-perl::before { content: "\efa0"; }
.si-perl.si--color::before { color: #39457E; }
.si-personio::before { content: "\efa1"; }
.si-personio.si--color::before { color: #FFFFFF; }
.si-peugeot::before { content: "\efa2"; }
.si-peugeot.si--color::before { color: #000000; }
.si-petsathome::before { content: "\efa3"; }
.si-petsathome.si--color::before { color: #4BA840; }
.si-pexels::before { content: "\efa4"; }
.si-pexels.si--color::before { color: #05A081; }
.si-pfsense::before { content: "\efa5"; }
.si-pfsense.si--color::before { color: #212121; }
.si-philipshue::before { content: "\efa6"; }
.si-philipshue.si--color::before { color: #0065D3; }
.si-phabricator::before { content: "\efa7"; }
.si-phabricator.si--color::before { color: #4A5F88; }
.si-phonepe::before { content: "\efa8"; }
.si-phonepe.si--color::before { color: #5F259F; }
.si-photobucket::before { content: "\efa9"; }
.si-photobucket.si--color::before { color: #0672CB; }
.si-photocrowd::before { content: "\efaa"; }
.si-photocrowd.si--color::before { color: #3DAD4B; }
.si-photopea::before { content: "\efab"; }
.si-photopea.si--color::before { color: #18A497; }
.si-php::before { content: "\efac"; }
.si-php.si--color::before { color: #777BB4; }
.si-phpmyadmin::before { content: "\efad"; }
.si-phpmyadmin.si--color::before { color: #6C78AF; }
.si-phpstorm::before { content: "\efae"; }
.si-phpstorm.si--color::before { color: #000000; }
.si-pihole::before { content: "\efaf"; }
.si-pihole.si--color::before { color: #96060C; }
.si-picardsurgeles::before { content: "\efb0"; }
.si-picardsurgeles.si--color::before { color: #2D4999; }
.si-picartodottv::before { content: "\efb1"; }
.si-picartodottv.si--color::before { color: #1DA456; }
.si-picnic::before { content: "\efb2"; }
.si-picnic.si--color::before { color: #E1171E; }
.si-picpay::before { content: "\efb3"; }
.si-picpay.si--color::before { color: #21C25E; }
.si-pimcore::before { content: "\efb4"; }
.si-pimcore.si--color::before { color: #6428B4; }
.si-pinboard::before { content: "\efb5"; }
.si-pinboard.si--color::before { color: #0000FF; }
.si-pingdom::before { content: "\efb6"; }
.si-pingdom.si--color::before { color: #FFF000; }
.si-pinterest::before { content: "\efb7"; }
.si-pinterest.si--color::before { color: #BD081C; }
.si-pivotaltracker::before { content: "\efb8"; }
.si-pivotaltracker.si--color::before { color: #517A9E; }
.si-pioneerdj::before { content: "\efb9"; }
.si-pioneerdj.si--color::before { color: #1A1928; }
.si-piwigo::before { content: "\efba"; }
.si-piwigo.si--color::before { color: #FF7700; }
.si-pix::before { content: "\efbb"; }
.si-pix.si--color::before { color: #77B6A8; }
.si-pixabay::before { content: "\efbc"; }
.si-pixabay.si--color::before { color: #2EC66D; }
.si-pixiv::before { content: "\efbd"; }
.si-pixiv.si--color::before { color: #0096FA; }
.si-pkgsrc::before { content: "\efbe"; }
.si-pkgsrc.si--color::before { color: #FF6600; }
.si-planet::before { content: "\efbf"; }
.si-planet.si--color::before { color: #009DB1; }
.si-plangrid::before { content: "\efc0"; }
.si-plangrid.si--color::before { color: #0085DE; }
.si-platformdotsh::before { content: "\efc1"; }
.si-platformdotsh.si--color::before { color: #1A182A; }
.si-platzi::before { content: "\efc2"; }
.si-platzi.si--color::before { color: #98CA3F; }
.si-plausibleanalytics::before { content: "\efc3"; }
.si-plausibleanalytics.si--color::before { color: #5850EC; }
.si-playcanvas::before { content: "\efc4"; }
.si-playcanvas.si--color::before { color: #E05F2C; }
.si-playerfm::before { content: "\efc5"; }
.si-playerfm.si--color::before { color: #C8122A; }
.si-playerdotme::before { content: "\efc6"; }
.si-playerdotme.si--color::before { color: #C0379A; }
.si-playstation::before { content: "\efc7"; }
.si-playstation.si--color::before { color: #003791; }
.si-playstation2::before { content: "\efc8"; }
.si-playstation2.si--color::before { color: #003791; }
.si-playstation3::before { content: "\efc9"; }
.si-playstation3.si--color::before { color: #003791; }
.si-playstation4::before { content: "\efca"; }
.si-playstation4.si--color::before { color: #003791; }
.si-playstation5::before { content: "\efcb"; }
.si-playstation5.si--color::before { color: #003791; }
.si-playstationvita::before { content: "\efcc"; }
.si-playstationvita.si--color::before { color: #003791; }
.si-pleroma::before { content: "\efcd"; }
.si-pleroma.si--color::before { color: #FBA457; }
.si-plesk::before { content: "\efce"; }
.si-plesk.si--color::before { color: #52BBE6; }
.si-plex::before { content: "\efcf"; }
.si-plex.si--color::before { color: #E5A00D; }
.si-plotly::before { content: "\efd0"; }
.si-plotly.si--color::before { color: #3F4F75; }
.si-pluralsight::before { content: "\efd1"; }
.si-pluralsight.si--color::before { color: #F15B2A; }
.si-plurk::before { content: "\efd2"; }
.si-plurk.si--color::before { color: #FF574D; }
.si-pluscodes::before { content: "\efd3"; }
.si-pluscodes.si--color::before { color: #4285F4; }
.si-pm2::before { content: "\efd4"; }
.si-pm2.si--color::before { color: #2B037A; }
.si-pnpm::before { content: "\efd5"; }
.si-pnpm.si--color::before { color: #F69220; }
.si-pocket::before { content: "\efd6"; }
.si-pocket.si--color::before { color: #EF3F56; }
.si-pocketcasts::before { content: "\efd7"; }
.si-pocketcasts.si--color::before { color: #F43E37; }
.si-podcastaddict::before { content: "\efd8"; }
.si-podcastaddict.si--color::before { color: #F4842D; }
.si-podman::before { content: "\efd9"; }
.si-podman.si--color::before { color: #892CA0; }
.si-poetry::before { content: "\efda"; }
.si-poetry.si--color::before { color: #60A5FA; }
.si-pointy::before { content: "\efdb"; }
.si-pointy.si--color::before { color: #009DE0; }
.si-pokemon::before { content: "\efdc"; }
.si-pokemon.si--color::before { color: #FFCB05; }
.si-polkadot::before { content: "\efdd"; }
.si-polkadot.si--color::before { color: #E6007A; }
.si-poly::before { content: "\efde"; }
.si-poly.si--color::before { color: #EB3C00; }
.si-polymerproject::before { content: "\efdf"; }
.si-polymerproject.si--color::before { color: #FF4470; }
.si-polywork::before { content: "\efe0"; }
.si-polywork.si--color::before { color: #543DE0; }
.si-popos::before { content: "\efe1"; }
.si-popos.si--color::before { color: #48B9C7; }
.si-porsche::before { content: "\efe2"; }
.si-porsche.si--color::before { color: #B12B28; }
.si-postcss::before { content: "\efe3"; }
.si-postcss.si--color::before { color: #DD3A0A; }
.si-portainer::before { content: "\efe4"; }
.si-portainer.si--color::before { color: #13BEF9; }
.si-postgresql::before { content: "\efe5"; }
.si-postgresql.si--color::before { color: #4169E1; }
.si-postman::before { content: "\efe6"; }
.si-postman.si--color::before { color: #FF6C37; }
.si-postmates::before { content: "\efe7"; }
.si-postmates.si--color::before { color: #FFDF18; }
.si-powerapps::before { content: "\efe8"; }
.si-powerapps.si--color::before { color: #742774; }
.si-powerautomate::before { content: "\efe9"; }
.si-powerautomate.si--color::before { color: #0066FF; }
.si-powerbi::before { content: "\efea"; }
.si-powerbi.si--color::before { color: #F2C811; }
.si-powervirtualagents::before { content: "\efeb"; }
.si-powervirtualagents.si--color::before { color: #0B556A; }
.si-powers::before { content: "\efec"; }
.si-powers.si--color::before { color: #E74536; }
.si-powershell::before { content: "\efed"; }
.si-powershell.si--color::before { color: #5391FE; }
.si-prdotco::before { content: "\efee"; }
.si-prdotco.si--color::before { color: #0080FF; }
.si-precommit::before { content: "\efef"; }
.si-precommit.si--color::before { color: #FAB040; }
.si-preact::before { content: "\eff0"; }
.si-preact.si--color::before { color: #673AB8; }
.si-premierleague::before { content: "\eff1"; }
.si-premierleague.si--color::before { color: #360D3A; }
.si-prestashop::before { content: "\eff2"; }
.si-prestashop.si--color::before { color: #DF0067; }
.si-presto::before { content: "\eff3"; }
.si-presto.si--color::before { color: #5890FF; }
.si-prettier::before { content: "\eff4"; }
.si-prettier.si--color::before { color: #F7B93E; }
.si-prime::before { content: "\eff5"; }
.si-prime.si--color::before { color: #00A8E1; }
.si-prezi::before { content: "\eff6"; }
.si-prezi.si--color::before { color: #3181FF; }
.si-primevideo::before { content: "\eff7"; }
.si-primevideo.si--color::before { color: #1F2E3E; }
.si-prisma::before { content: "\eff8"; }
.si-prisma.si--color::before { color: #2D3748; }
.si-prismic::before { content: "\eff9"; }
.si-prismic.si--color::before { color: #5163BA; }
.si-privateinternetaccess::before { content: "\effa"; }
.si-privateinternetaccess.si--color::before { color: #4BB749; }
.si-protools::before { content: "\effb"; }
.si-protools.si--color::before { color: #7ACB10; }
.si-probot::before { content: "\effc"; }
.si-probot.si--color::before { color: #00B0D8; }
.si-processingfoundation::before { content: "\effd"; }
.si-processingfoundation.si--color::before { color: #006699; }
.si-processwire::before { content: "\effe"; }
.si-processwire.si--color::before { color: #2480E6; }
.si-producthunt::before { content: "\efff"; }
.si-producthunt.si--color::before { color: #DA552F; }
.si-progate::before { content: "\f000"; }
.si-progate.si--color::before { color: #380953; }
.si-progress::before { content: "\f001"; }
.si-progress.si--color::before { color: #5CE500; }
.si-prometheus::before { content: "\f002"; }
.si-prometheus.si--color::before { color: #E6522C; }
.si-prosieben::before { content: "\f003"; }
.si-prosieben.si--color::before { color: #E6000F; }
.si-protodotio::before { content: "\f004"; }
.si-protodotio.si--color::before { color: #34A7C1; }
.si-protocolsdotio::before { content: "\f005"; }
.si-protocolsdotio.si--color::before { color: #4D9FE7; }
.si-protondb::before { content: "\f006"; }
.si-protondb.si--color::before { color: #F50057; }
.si-protonmail::before { content: "\f007"; }
.si-protonmail.si--color::before { color: #8B89CC; }
.si-protonvpn::before { content: "\f008"; }
.si-protonvpn.si--color::before { color: #56B366; }
.si-protractor::before { content: "\f009"; }
.si-protractor.si--color::before { color: #ED163A; }
.si-proxmox::before { content: "\f00a"; }
.si-proxmox.si--color::before { color: #E57000; }
.si-pubg::before { content: "\f00b"; }
.si-pubg.si--color::before { color: #FEAB02; }
.si-publons::before { content: "\f00c"; }
.si-publons.si--color::before { color: #336699; }
.si-pubmed::before { content: "\f00d"; }
.si-pubmed.si--color::before { color: #326599; }
.si-pug::before { content: "\f00e"; }
.si-pug.si--color::before { color: #A86454; }
.si-pulumi::before { content: "\f00f"; }
.si-pulumi.si--color::before { color: #8A3391; }
.si-puma::before { content: "\f010"; }
.si-puma.si--color::before { color: #242B2F; }
.si-puppet::before { content: "\f011"; }
.si-puppet.si--color::before { color: #FFAE1A; }
.si-puppeteer::before { content: "\f012"; }
.si-puppeteer.si--color::before { color: #40B5A4; }
.si-purescript::before { content: "\f013"; }
.si-purescript.si--color::before { color: #14161A; }
.si-purgecss::before { content: "\f014"; }
.si-purgecss.si--color::before { color: #14161A; }
.si-purism::before { content: "\f015"; }
.si-purism.si--color::before { color: #2D2D2D; }
.si-pusher::before { content: "\f016"; }
.si-pusher.si--color::before { color: #300D4F; }
.si-pwa::before { content: "\f017"; }
.si-pwa.si--color::before { color: #5A0FC8; }
.si-pycharm::before { content: "\f018"; }
.si-pycharm.si--color::before { color: #000000; }
.si-pypi::before { content: "\f019"; }
.si-pypi.si--color::before { color: #3775A9; }
.si-pyscaffold::before { content: "\f01a"; }
.si-pyscaffold.si--color::before { color: #005CA0; }
.si-pypy::before { content: "\f01b"; }
.si-pypy.si--color::before { color: #193440; }
.si-pytest::before { content: "\f01c"; }
.si-pytest.si--color::before { color: #0A9EDC; }
.si-python::before { content: "\f01d"; }
.si-python.si--color::before { color: #3776AB; }
.si-pytorch::before { content: "\f01e"; }
.si-pytorch.si--color::before { color: #EE4C2C; }
.si-pytorchlightning::before { content: "\f01f"; }
.si-pytorchlightning.si--color::before { color: #792EE5; }
.si-pyup::before { content: "\f020"; }
.si-pyup.si--color::before { color: #9F55FF; }
.si-qantas::before { content: "\f021"; }
.si-qantas.si--color::before { color: #E40000; }
.si-qatarairways::before { content: "\f022"; }
.si-qatarairways.si--color::before { color: #5C0D34; }
.si-qemu::before { content: "\f023"; }
.si-qemu.si--color::before { color: #FF6600; }
.si-qgis::before { content: "\f024"; }
.si-qgis.si--color::before { color: #589632; }
.si-qi::before { content: "\f025"; }
.si-qi.si--color::before { color: #000000; }
.si-qiita::before { content: "\f026"; }
.si-qiita.si--color::before { color: #55C500; }
.si-qiskit::before { content: "\f027"; }
.si-qiskit.si--color::before { color: #6929C4; }
.si-qiwi::before { content: "\f028"; }
.si-qiwi.si--color::before { color: #FF8C00; }
.si-qualtrics::before { content: "\f029"; }
.si-qualtrics.si--color::before { color: #00B4EF; }
.si-qt::before { content: "\f02a"; }
.si-qt.si--color::before { color: #41CD52; }
.si-qualcomm::before { content: "\f02b"; }
.si-qualcomm.si--color::before { color: #3253DC; }
.si-quantcast::before { content: "\f02c"; }
.si-quantcast.si--color::before { color: #000000; }
.si-qualys::before { content: "\f02d"; }
.si-qualys.si--color::before { color: #ED2E26; }
.si-quantconnect::before { content: "\f02e"; }
.si-quantconnect.si--color::before { color: #F5AE29; }
.si-quarkus::before { content: "\f02f"; }
.si-quarkus.si--color::before { color: #4695EB; }
.si-quasar::before { content: "\f030"; }
.si-quasar.si--color::before { color: #1976D2; }
.si-qubesos::before { content: "\f031"; }
.si-qubesos.si--color::before { color: #3874D8; }
.si-quest::before { content: "\f032"; }
.si-quest.si--color::before { color: #FB4F14; }
.si-quickbooks::before { content: "\f033"; }
.si-quickbooks.si--color::before { color: #2CA01C; }
.si-quicklook::before { content: "\f034"; }
.si-quicklook.si--color::before { color: #22A2E3; }
.si-quicktime::before { content: "\f035"; }
.si-quicktime.si--color::before { color: #1C69F0; }
.si-quip::before { content: "\f036"; }
.si-quip.si--color::before { color: #F27557; }
.si-quora::before { content: "\f037"; }
.si-quora.si--color::before { color: #B92B27; }
.si-qwiklabs::before { content: "\f038"; }
.si-qwiklabs.si--color::before { color: #F5CD0E; }
.si-qzone::before { content: "\f039"; }
.si-qzone.si--color::before { color: #FECE00; }
.si-r::before { content: "\f03a"; }
.si-r.si--color::before { color: #276DC3; }
.si-r3::before { content: "\f03b"; }
.si-r3.si--color::before { color: #EC1D24; }
.si-rabbitmq::before { content: "\f03c"; }
.si-rabbitmq.si--color::before { color: #FF6600; }
.si-racket::before { content: "\f03d"; }
.si-racket.si--color::before { color: #9F1D20; }
.si-radar::before { content: "\f03e"; }
.si-radar.si--color::before { color: #007AFF; }
.si-radiopublic::before { content: "\f03f"; }
.si-radiopublic.si--color::before { color: #CE262F; }
.si-railway::before { content: "\f040"; }
.si-railway.si--color::before { color: #0B0D0E; }
.si-rainmeter::before { content: "\f041"; }
.si-rainmeter.si--color::before { color: #19519B; }
.si-rakuten::before { content: "\f042"; }
.si-rakuten.si--color::before { color: #BF0000; }
.si-rancher::before { content: "\f043"; }
.si-rancher.si--color::before { color: #0075A8; }
.si-ram::before { content: "\f044"; }
.si-ram.si--color::before { color: #000000; }
.si-raspberrypi::before { content: "\f045"; }
.si-raspberrypi.si--color::before { color: #A22846; }
.si-rarible::before { content: "\f046"; }
.si-rarible.si--color::before { color: #FEDA03; }
.si-ray::before { content: "\f047"; }
.si-ray.si--color::before { color: #028CF0; }
.si-razer::before { content: "\f048"; }
.si-razer.si--color::before { color: #00FF00; }
.si-razorpay::before { content: "\f049"; }
.si-razorpay.si--color::before { color: #0C2451; }
.si-react::before { content: "\f04a"; }
.si-react.si--color::before { color: #61DAFB; }
.si-reactquery::before { content: "\f04b"; }
.si-reactquery.si--color::before { color: #FF4154; }
.si-reactrouter::before { content: "\f04c"; }
.si-reactrouter.si--color::before { color: #CA4245; }
.si-reacttable::before { content: "\f04d"; }
.si-reacttable.si--color::before { color: #FF4154; }
.si-reactivex::before { content: "\f04e"; }
.si-reactivex.si--color::before { color: #B7178C; }
.si-reactos::before { content: "\f04f"; }
.si-reactos.si--color::before { color: #0088CC; }
.si-realm::before { content: "\f050"; }
.si-realm.si--color::before { color: #39477F; }
.si-readthedocs::before { content: "\f051"; }
.si-readthedocs.si--color::before { color: #8CA1AF; }
.si-reasonstudios::before { content: "\f052"; }
.si-reasonstudios.si--color::before { color: #FFFFFF; }
.si-reason::before { content: "\f053"; }
.si-reason.si--color::before { color: #DD4B39; }
.si-redhat::before { content: "\f054"; }
.si-redhat.si--color::before { color: #EE0000; }
.si-redhatopenshift::before { content: "\f055"; }
.si-redhatopenshift.si--color::before { color: #EE0000; }
.si-redbubble::before { content: "\f056"; }
.si-redbubble.si--color::before { color: #E41321; }
.si-reddit::before { content: "\f057"; }
.si-reddit.si--color::before { color: #FF4500; }
.si-redis::before { content: "\f058"; }
.si-redis.si--color::before { color: #DC382D; }
.si-redmine::before { content: "\f059"; }
.si-redmine.si--color::before { color: #B32024; }
.si-redux::before { content: "\f05a"; }
.si-redux.si--color::before { color: #764ABC; }
.si-reebok::before { content: "\f05b"; }
.si-reebok.si--color::before { color: #E41D1B; }
.si-reduxsaga::before { content: "\f05c"; }
.si-reduxsaga.si--color::before { color: #999999; }
.si-redwoodjs::before { content: "\f05d"; }
.si-redwoodjs.si--color::before { color: #BF4722; }
.si-relianceindustrieslimited::before { content: "\f05e"; }
.si-relianceindustrieslimited.si--color::before { color: #D1AB66; }
.si-remix::before { content: "\f05f"; }
.si-remix.si--color::before { color: #000000; }
.si-renpy::before { content: "\f060"; }
.si-renpy.si--color::before { color: #FF7F7F; }
.si-renault::before { content: "\f061"; }
.si-renault.si--color::before { color: #FFCC33; }
.si-renren::before { content: "\f062"; }
.si-renren.si--color::before { color: #217DC6; }
.si-renovatebot::before { content: "\f063"; }
.si-renovatebot.si--color::before { color: #1A1F6C; }
.si-replit::before { content: "\f064"; }
.si-replit.si--color::before { color: #667881; }
.si-republicofgamers::before { content: "\f065"; }
.si-republicofgamers.si--color::before { color: #FF0029; }
.si-rescript::before { content: "\f066"; }
.si-rescript.si--color::before { color: #E6484F; }
.si-rescuetime::before { content: "\f067"; }
.si-rescuetime.si--color::before { color: #161A3B; }
.si-researchgate::before { content: "\f068"; }
.si-researchgate.si--color::before { color: #00CCBB; }
.si-resurrectionremixos::before { content: "\f069"; }
.si-resurrectionremixos.si--color::before { color: #000000; }
.si-retroarch::before { content: "\f06a"; }
.si-retroarch.si--color::before { color: #000000; }
.si-retropie::before { content: "\f06b"; }
.si-retropie.si--color::before { color: #CC0000; }
.si-revealdotjs::before { content: "\f06c"; }
.si-revealdotjs.si--color::before { color: #F2E142; }
.si-reverbnation::before { content: "\f06d"; }
.si-reverbnation.si--color::before { color: #E43526; }
.si-revolut::before { content: "\f06e"; }
.si-revolut.si--color::before { color: #0075EB; }
.si-revue::before { content: "\f06f"; }
.si-revue.si--color::before { color: #E15718; }
.si-rewe::before { content: "\f070"; }
.si-rewe.si--color::before { color: #CC071E; }
.si-rezgo::before { content: "\f071"; }
.si-rezgo.si--color::before { color: #F76C00; }
.si-rhinoceros::before { content: "\f072"; }
.si-rhinoceros.si--color::before { color: #801010; }
.si-rider::before { content: "\f073"; }
.si-rider.si--color::before { color: #000000; }
.si-rimacautomobili::before { content: "\f074"; }
.si-rimacautomobili.si--color::before { color: #0A222E; }
.si-ring::before { content: "\f075"; }
.si-ring.si--color::before { color: #1C9AD6; }
.si-riotgames::before { content: "\f076"; }
.si-riotgames.si--color::before { color: #D32936; }
.si-riseup::before { content: "\f077"; }
.si-riseup.si--color::before { color: #FF0000; }
.si-ripple::before { content: "\f078"; }
.si-ripple.si--color::before { color: #0085C0; }
.si-roamresearch::before { content: "\f079"; }
.si-roamresearch.si--color::before { color: #343A40; }
.si-roblox::before { content: "\f07a"; }
.si-roblox.si--color::before { color: #000000; }
.si-rocketdotchat::before { content: "\f07b"; }
.si-rocketdotchat.si--color::before { color: #F5455C; }
.si-robotframework::before { content: "\f07c"; }
.si-robotframework.si--color::before { color: #000000; }
.si-rocksdb::before { content: "\f07d"; }
.si-rocksdb.si--color::before { color: #2A2A2A; }
.si-rockylinux::before { content: "\f07e"; }
.si-rockylinux.si--color::before { color: #10B981; }
.si-roku::before { content: "\f07f"; }
.si-roku.si--color::before { color: #662D91; }
.si-rollsroyce::before { content: "\f080"; }
.si-rollsroyce.si--color::before { color: #281432; }
.si-rollupdotjs::before { content: "\f081"; }
.si-rollupdotjs.si--color::before { color: #EC4A3F; }
.si-rome::before { content: "\f082"; }
.si-rome.si--color::before { color: #27272A; }
.si-roots::before { content: "\f083"; }
.si-roots.si--color::before { color: #525DDC; }
.si-rootsbedrock::before { content: "\f084"; }
.si-rootsbedrock.si--color::before { color: #525DDC; }
.si-rootssage::before { content: "\f085"; }
.si-rootssage.si--color::before { color: #525DDC; }
.si-ros::before { content: "\f086"; }
.si-ros.si--color::before { color: #22314E; }
.si-rossmann::before { content: "\f087"; }
.si-rossmann.si--color::before { color: #C3002D; }
.si-rottentomatoes::before { content: "\f088"; }
.si-rottentomatoes.si--color::before { color: #FA320A; }
.si-rotaryinternational::before { content: "\f089"; }
.si-rotaryinternational.si--color::before { color: #F7A81B; }
.si-roundcube::before { content: "\f08a"; }
.si-roundcube.si--color::before { color: #37BEFF; }
.si-rss::before { content: "\f08b"; }
.si-rss.si--color::before { color: #FFA500; }
.si-rte::before { content: "\f08c"; }
.si-rte.si--color::before { color: #00A7B3; }
.si-rstudio::before { content: "\f08d"; }
.si-rstudio.si--color::before { color: #75AADB; }
.si-rtl::before { content: "\f08e"; }
.si-rtl.si--color::before { color: #E9113B; }
.si-rtlzwei::before { content: "\f08f"; }
.si-rtlzwei.si--color::before { color: #00BCF6; }
.si-rubocop::before { content: "\f090"; }
.si-rubocop.si--color::before { color: #000000; }
.si-ruby::before { content: "\f091"; }
.si-ruby.si--color::before { color: #CC342D; }
.si-rubyonrails::before { content: "\f092"; }
.si-rubyonrails.si--color::before { color: #CC0000; }
.si-rubysinatra::before { content: "\f093"; }
.si-rubysinatra.si--color::before { color: #000000; }
.si-runkeeper::before { content: "\f094"; }
.si-runkeeper.si--color::before { color: #001E62; }
.si-rubygems::before { content: "\f095"; }
.si-rubygems.si--color::before { color: #E9573F; }
.si-runkit::before { content: "\f096"; }
.si-runkit.si--color::before { color: #491757; }
.si-rust::before { content: "\f097"; }
.si-rust.si--color::before { color: #000000; }
.si-rxdb::before { content: "\f098"; }
.si-rxdb.si--color::before { color: #8D1F89; }
.si-ryanair::before { content: "\f099"; }
.si-ryanair.si--color::before { color: #073590; }
.si-s7airlines::before { content: "\f09a"; }
.si-s7airlines.si--color::before { color: #C4D600; }
.si-sabanci::before { content: "\f09b"; }
.si-sabanci.si--color::before { color: #004B93; }
.si-sahibinden::before { content: "\f09c"; }
.si-sahibinden.si--color::before { color: #FFE800; }
.si-safari::before { content: "\f09d"; }
.si-safari.si--color::before { color: #000000; }
.si-salesforce::before { content: "\f09e"; }
.si-salesforce.si--color::before { color: #00A1E0; }
.si-sailfishos::before { content: "\f09f"; }
.si-sailfishos.si--color::before { color: #053766; }
.si-saltproject::before { content: "\f0a0"; }
.si-saltproject.si--color::before { color: #57BCAD; }
.si-samsung::before { content: "\f0a1"; }
.si-samsung.si--color::before { color: #1428A0; }
.si-samsungpay::before { content: "\f0a2"; }
.si-samsungpay.si--color::before { color: #1428A0; }
.si-sandisk::before { content: "\f0a3"; }
.si-sandisk.si--color::before { color: #ED1C24; }
.si-sanfranciscomunicipalrailway::before { content: "\f0a4"; }
.si-sanfranciscomunicipalrailway.si--color::before { color: #BA0C2F; }
.si-saopaulometro::before { content: "\f0a5"; }
.si-saopaulometro.si--color::before { color: #004382; }
.si-sap::before { content: "\f0a6"; }
.si-sap.si--color::before { color: #0FAAFF; }
.si-sass::before { content: "\f0a7"; }
.si-sass.si--color::before { color: #CC6699; }
.si-sat1::before { content: "\f0a8"; }
.si-sat1.si--color::before { color: #047DA3; }
.si-saturn::before { content: "\f0a9"; }
.si-saturn.si--color::before { color: #EB680B; }
.si-saucelabs::before { content: "\f0aa"; }
.si-saucelabs.si--color::before { color: #E2231A; }
.si-scala::before { content: "\f0ab"; }
.si-scala.si--color::before { color: #DC322F; }
.si-scaleway::before { content: "\f0ac"; }
.si-scaleway.si--color::before { color: #4F0599; }
.si-scania::before { content: "\f0ad"; }
.si-scania.si--color::before { color: #041E42; }
.si-schneiderelectric::before { content: "\f0ae"; }
.si-schneiderelectric.si--color::before { color: #3DCD58; }
.si-scikitlearn::before { content: "\f0af"; }
.si-scikitlearn.si--color::before { color: #F7931E; }
.si-scipy::before { content: "\f0b0"; }
.si-scipy.si--color::before { color: #8CAAE6; }
.si-scopus::before { content: "\f0b1"; }
.si-scopus.si--color::before { color: #E9711C; }
.si-scpfoundation::before { content: "\f0b2"; }
.si-scpfoundation.si--color::before { color: #FFFFFF; }
.si-scratch::before { content: "\f0b3"; }
.si-scratch.si--color::before { color: #4D97FF; }
.si-screencastify::before { content: "\f0b4"; }
.si-screencastify.si--color::before { color: #FF8282; }
.si-scribd::before { content: "\f0b5"; }
.si-scribd.si--color::before { color: #1E7B85; }
.si-scrimba::before { content: "\f0b6"; }
.si-scrimba.si--color::before { color: #2B283A; }
.si-scrollreveal::before { content: "\f0b7"; }
.si-scrollreveal.si--color::before { color: #FFCB36; }
.si-scrumalliance::before { content: "\f0b8"; }
.si-scrumalliance.si--color::before { color: #009FDA; }
.si-scrutinizerci::before { content: "\f0b9"; }
.si-scrutinizerci.si--color::before { color: #8A9296; }
.si-seagate::before { content: "\f0ba"; }
.si-seagate.si--color::before { color: #6EBE49; }
.si-sefaria::before { content: "\f0bb"; }
.si-sefaria.si--color::before { color: #212E50; }
.si-sega::before { content: "\f0bc"; }
.si-sega.si--color::before { color: #0089CF; }
.si-seat::before { content: "\f0bd"; }
.si-seat.si--color::before { color: #33302E; }
.si-sellfy::before { content: "\f0be"; }
.si-sellfy.si--color::before { color: #21B352; }
.si-semanticuireact::before { content: "\f0bf"; }
.si-semanticuireact.si--color::before { color: #35BDB2; }
.si-semanticweb::before { content: "\f0c0"; }
.si-semanticweb.si--color::before { color: #005A9C; }
.si-selenium::before { content: "\f0c1"; }
.si-selenium.si--color::before { color: #43B02A; }
.si-semanticrelease::before { content: "\f0c2"; }
.si-semanticrelease.si--color::before { color: #494949; }
.si-semaphoreci::before { content: "\f0c3"; }
.si-semaphoreci.si--color::before { color: #19A974; }
.si-semver::before { content: "\f0c4"; }
.si-semver.si--color::before { color: #3F4551; }
.si-sencha::before { content: "\f0c5"; }
.si-sencha.si--color::before { color: #86BC40; }
.si-sensu::before { content: "\f0c6"; }
.si-sensu.si--color::before { color: #89C967; }
.si-sennheiser::before { content: "\f0c7"; }
.si-sennheiser.si--color::before { color: #000000; }
.si-sentry::before { content: "\f0c8"; }
.si-sentry.si--color::before { color: #362D59; }
.si-sepa::before { content: "\f0c9"; }
.si-sepa.si--color::before { color: #2350A9; }
.si-sequelize::before { content: "\f0ca"; }
.si-sequelize.si--color::before { color: #52B0E7; }
.si-serverfault::before { content: "\f0cb"; }
.si-serverfault.si--color::before { color: #E7282D; }
.si-serverless::before { content: "\f0cc"; }
.si-serverless.si--color::before { color: #FD5750; }
.si-sfml::before { content: "\f0cd"; }
.si-sfml.si--color::before { color: #8CC445; }
.si-shadow::before { content: "\f0ce"; }
.si-shadow.si--color::before { color: #0A0C0D; }
.si-shanghaimetro::before { content: "\f0cf"; }
.si-shanghaimetro.si--color::before { color: #EC1C24; }
.si-sharp::before { content: "\f0d0"; }
.si-sharp.si--color::before { color: #99CC00; }
.si-shazam::before { content: "\f0d1"; }
.si-shazam.si--color::before { color: #0088FF; }
.si-shell::before { content: "\f0d2"; }
.si-shell.si--color::before { color: #FFD500; }
.si-shelly::before { content: "\f0d3"; }
.si-shelly.si--color::before { color: #4495D1; }
.si-shenzhenmetro::before { content: "\f0d4"; }
.si-shenzhenmetro.si--color::before { color: #009943; }
.si-shieldsdotio::before { content: "\f0d5"; }
.si-shieldsdotio.si--color::before { color: #000000; }
.si-shikimori::before { content: "\f0d6"; }
.si-shikimori.si--color::before { color: #343434; }
.si-shopify::before { content: "\f0d7"; }
.si-shopify.si--color::before { color: #7AB55C; }
.si-shopware::before { content: "\f0d8"; }
.si-shopware.si--color::before { color: #189EFF; }
.si-shotcut::before { content: "\f0d9"; }
.si-shotcut.si--color::before { color: #115C77; }
.si-showpad::before { content: "\f0da"; }
.si-showpad.si--color::before { color: #2D2E83; }
.si-showtime::before { content: "\f0db"; }
.si-showtime.si--color::before { color: #B10000; }
.si-shutterstock::before { content: "\f0dc"; }
.si-shutterstock.si--color::before { color: #EE2B24; }
.si-siemens::before { content: "\f0dd"; }
.si-siemens.si--color::before { color: #009999; }
.si-signal::before { content: "\f0de"; }
.si-signal.si--color::before { color: #3A76F0; }
.si-simkl::before { content: "\f0df"; }
.si-simkl.si--color::before { color: #000000; }
.si-simpleanalytics::before { content: "\f0e0"; }
.si-simpleanalytics.si--color::before { color: #FF4F64; }
.si-simplenote::before { content: "\f0e1"; }
.si-simplenote.si--color::before { color: #3361CC; }
.si-simpleicons::before { content: "\f0e2"; }
.si-simpleicons.si--color::before { color: #111111; }
.si-sinaweibo::before { content: "\f0e3"; }
.si-sinaweibo.si--color::before { color: #E6162D; }
.si-singlestore::before { content: "\f0e4"; }
.si-singlestore.si--color::before { color: #AA00FF; }
.si-sitepoint::before { content: "\f0e5"; }
.si-sitepoint.si--color::before { color: #258AAF; }
.si-sketch::before { content: "\f0e6"; }
.si-sketch.si--color::before { color: #F7B500; }
.si-sketchfab::before { content: "\f0e7"; }
.si-sketchfab.si--color::before { color: #1CAAD9; }
.si-sketchup::before { content: "\f0e8"; }
.si-sketchup.si--color::before { color: #005F9E; }
.si-skillshare::before { content: "\f0e9"; }
.si-skillshare.si--color::before { color: #00FF84; }
.si-skoda::before { content: "\f0ea"; }
.si-skoda.si--color::before { color: #4BA82E; }
.si-sky::before { content: "\f0eb"; }
.si-sky.si--color::before { color: #0072C9; }
.si-skynet::before { content: "\f0ec"; }
.si-skynet.si--color::before { color: #00C65E; }
.si-skypack::before { content: "\f0ed"; }
.si-skypack.si--color::before { color: #3167FF; }
.si-skype::before { content: "\f0ee"; }
.si-skype.si--color::before { color: #00AFF0; }
.si-skypeforbusiness::before { content: "\f0ef"; }
.si-skypeforbusiness.si--color::before { color: #00AFF0; }
.si-slack::before { content: "\f0f0"; }
.si-slack.si--color::before { color: #4A154B; }
.si-slackware::before { content: "\f0f1"; }
.si-slackware.si--color::before { color: #000000; }
.si-slickpic::before { content: "\f0f2"; }
.si-slickpic.si--color::before { color: #FF880F; }
.si-slashdot::before { content: "\f0f3"; }
.si-slashdot.si--color::before { color: #026664; }
.si-slides::before { content: "\f0f4"; }
.si-slides.si--color::before { color: #E4637C; }
.si-slideshare::before { content: "\f0f5"; }
.si-slideshare.si--color::before { color: #008ED2; }
.si-smart::before { content: "\f0f6"; }
.si-smart.si--color::before { color: #FABC0C; }
.si-smartthings::before { content: "\f0f7"; }
.si-smartthings.si--color::before { color: #15BFFF; }
.si-smashingmagazine::before { content: "\f0f8"; }
.si-smashingmagazine.si--color::before { color: #E85C33; }
.si-smashdotgg::before { content: "\f0f9"; }
.si-smashdotgg.si--color::before { color: #CB333B; }
.si-smrt::before { content: "\f0fa"; }
.si-smrt.si--color::before { color: #EE2E24; }
.si-smugmug::before { content: "\f0fb"; }
.si-smugmug.si--color::before { color: #6DB944; }
.si-snapchat::before { content: "\f0fc"; }
.si-snapchat.si--color::before { color: #FFFC00; }
.si-snapcraft::before { content: "\f0fd"; }
.si-snapcraft.si--color::before { color: #82BEA0; }
.si-snowflake::before { content: "\f0fe"; }
.si-snowflake.si--color::before { color: #29B5E8; }
.si-snowpack::before { content: "\f0ff"; }
.si-snowpack.si--color::before { color: #2E5E82; }
.si-snyk::before { content: "\f100"; }
.si-snyk.si--color::before { color: #4C4A73; }
.si-society6::before { content: "\f101"; }
.si-society6.si--color::before { color: #000000; }
.si-socialblade::before { content: "\f102"; }
.si-socialblade.si--color::before { color: #B3382C; }
.si-socketdotio::before { content: "\f103"; }
.si-socketdotio.si--color::before { color: #010101; }
.si-sogou::before { content: "\f104"; }
.si-sogou.si--color::before { color: #FB6022; }
.si-solid::before { content: "\f105"; }
.si-solid.si--color::before { color: #2C4F7C; }
.si-solidity::before { content: "\f106"; }
.si-solidity.si--color::before { color: #363636; }
.si-sololearn::before { content: "\f107"; }
.si-sololearn.si--color::before { color: #149EF2; }
.si-sonarcloud::before { content: "\f108"; }
.si-sonarcloud.si--color::before { color: #F3702A; }
.si-solus::before { content: "\f109"; }
.si-solus.si--color::before { color: #5294E2; }
.si-sonarlint::before { content: "\f10a"; }
.si-sonarlint.si--color::before { color: #CB2029; }
.si-sonarqube::before { content: "\f10b"; }
.si-sonarqube.si--color::before { color: #4E9BCD; }
.si-sonarsource::before { content: "\f10c"; }
.si-sonarsource.si--color::before { color: #CB3032; }
.si-songkick::before { content: "\f10d"; }
.si-songkick.si--color::before { color: #F80046; }
.si-songoda::before { content: "\f10e"; }
.si-songoda.si--color::before { color: #FC494A; }
.si-sonicwall::before { content: "\f10f"; }
.si-sonicwall.si--color::before { color: #FF791A; }
.si-sony::before { content: "\f110"; }
.si-sony.si--color::before { color: #FFFFFF; }
.si-sonos::before { content: "\f111"; }
.si-sonos.si--color::before { color: #000000; }
.si-soundcharts::before { content: "\f112"; }
.si-soundcharts.si--color::before { color: #0C1528; }
.si-soundcloud::before { content: "\f113"; }
.si-soundcloud.si--color::before { color: #FF3300; }
.si-sourceengine::before { content: "\f114"; }
.si-sourceengine.si--color::before { color: #F79A10; }
.si-sourceforge::before { content: "\f115"; }
.si-sourceforge.si--color::before { color: #FF6600; }
.si-sourcegraph::before { content: "\f116"; }
.si-sourcegraph.si--color::before { color: #00CBEC; }
.si-sourcetree::before { content: "\f117"; }
.si-sourcetree.si--color::before { color: #0052CC; }
.si-southwestairlines::before { content: "\f118"; }
.si-southwestairlines.si--color::before { color: #304CB2; }
.si-spacemacs::before { content: "\f119"; }
.si-spacemacs.si--color::before { color: #9266CC; }
.si-spacex::before { content: "\f11a"; }
.si-spacex.si--color::before { color: #000000; }
.si-spacy::before { content: "\f11b"; }
.si-spacy.si--color::before { color: #09A3D5; }
.si-sparkar::before { content: "\f11c"; }
.si-sparkar.si--color::before { color: #FF5C83; }
.si-sparkasse::before { content: "\f11d"; }
.si-sparkasse.si--color::before { color: #FF0000; }
.si-sparkfun::before { content: "\f11e"; }
.si-sparkfun.si--color::before { color: #E53525; }
.si-sparkpost::before { content: "\f11f"; }
.si-sparkpost.si--color::before { color: #FA6423; }
.si-spdx::before { content: "\f120"; }
.si-spdx.si--color::before { color: #4398CC; }
.si-speakerdeck::before { content: "\f121"; }
.si-speakerdeck.si--color::before { color: #009287; }
.si-speedtest::before { content: "\f122"; }
.si-speedtest.si--color::before { color: #141526; }
.si-spectrum::before { content: "\f123"; }
.si-spectrum.si--color::before { color: #7B16FF; }
.si-spinnaker::before { content: "\f124"; }
.si-spinnaker.si--color::before { color: #139BB4; }
.si-spinrilla::before { content: "\f125"; }
.si-spinrilla.si--color::before { color: #460856; }
.si-splunk::before { content: "\f126"; }
.si-splunk.si--color::before { color: #000000; }
.si-spond::before { content: "\f127"; }
.si-spond.si--color::before { color: #EE4353; }
.si-spotify::before { content: "\f128"; }
.si-spotify.si--color::before { color: #1DB954; }
.si-spotlight::before { content: "\f129"; }
.si-spotlight.si--color::before { color: #352A71; }
.si-spreadshirt::before { content: "\f12a"; }
.si-spreadshirt.si--color::before { color: #00B2A5; }
.si-spreaker::before { content: "\f12b"; }
.si-spreaker.si--color::before { color: #F5C300; }
.si-spring::before { content: "\f12c"; }
.si-spring.si--color::before { color: #6DB33F; }
.si-spring_creators::before { content: "\f12d"; }
.si-spring_creators.si--color::before { color: #000000; }
.si-springboot::before { content: "\f12e"; }
.si-springboot.si--color::before { color: #6DB33F; }
.si-springsecurity::before { content: "\f12f"; }
.si-springsecurity.si--color::before { color: #6DB33F; }
.si-spyderide::before { content: "\f130"; }
.si-spyderide.si--color::before { color: #FF0000; }
.si-sqlite::before { content: "\f131"; }
.si-sqlite.si--color::before { color: #003B57; }
.si-square::before { content: "\f132"; }
.si-square.si--color::before { color: #3E4348; }
.si-squareenix::before { content: "\f133"; }
.si-squareenix.si--color::before { color: #ED1C24; }
.si-squarespace::before { content: "\f134"; }
.si-squarespace.si--color::before { color: #000000; }
.si-ssrn::before { content: "\f135"; }
.si-ssrn.si--color::before { color: #154881; }
.si-stackoverflow::before { content: "\f136"; }
.si-stackoverflow.si--color::before { color: #F58025; }
.si-stackexchange::before { content: "\f137"; }
.si-stackexchange.si--color::before { color: #1E5397; }
.si-stackbit::before { content: "\f138"; }
.si-stackbit.si--color::before { color: #207BEA; }
.si-stackedit::before { content: "\f139"; }
.si-stackedit.si--color::before { color: #606060; }
.si-stackpath::before { content: "\f13a"; }
.si-stackpath.si--color::before { color: #000000; }
.si-stackshare::before { content: "\f13b"; }
.si-stackshare.si--color::before { color: #0690FA; }
.si-stadia::before { content: "\f13c"; }
.si-stadia.si--color::before { color: #CD2640; }
.si-staffbase::before { content: "\f13d"; }
.si-staffbase.si--color::before { color: #00A4FD; }
.si-startrek::before { content: "\f13e"; }
.si-startrek.si--color::before { color: #FFE200; }
.si-starbucks::before { content: "\f13f"; }
.si-starbucks.si--color::before { color: #006241; }
.si-stardock::before { content: "\f140"; }
.si-stardock.si--color::before { color: #004B8D; }
.si-starlingbank::before { content: "\f141"; }
.si-starlingbank.si--color::before { color: #6935D3; }
.si-starship::before { content: "\f142"; }
.si-starship.si--color::before { color: #DD0B78; }
.si-starz::before { content: "\f143"; }
.si-starz.si--color::before { color: #000000; }
.si-statamic::before { content: "\f144"; }
.si-statamic.si--color::before { color: #FF269E; }
.si-statuspage::before { content: "\f145"; }
.si-statuspage.si--color::before { color: #172B4D; }
.si-statuspal::before { content: "\f146"; }
.si-statuspal.si--color::before { color: #4934BF; }
.si-steam::before { content: "\f147"; }
.si-steam.si--color::before { color: #000000; }
.si-steamdeck::before { content: "\f148"; }
.si-steamdeck.si--color::before { color: #1A9FFF; }
.si-steamdb::before { content: "\f149"; }
.si-steamdb.si--color::before { color: #000000; }
.si-steamworks::before { content: "\f14a"; }
.si-steamworks.si--color::before { color: #1E1E1E; }
.si-steelseries::before { content: "\f14b"; }
.si-steelseries.si--color::before { color: #FF5200; }
.si-steem::before { content: "\f14c"; }
.si-steem.si--color::before { color: #171FC9; }
.si-steemit::before { content: "\f14d"; }
.si-steemit.si--color::before { color: #06D6A9; }
.si-steinberg::before { content: "\f14e"; }
.si-steinberg.si--color::before { color: #C90827; }
.si-stellar::before { content: "\f14f"; }
.si-stellar.si--color::before { color: #7D00FF; }
.si-stimulus::before { content: "\f150"; }
.si-stimulus.si--color::before { color: #77E8B9; }
.si-stencyl::before { content: "\f151"; }
.si-stencyl.si--color::before { color: #8E1C04; }
.si-stitcher::before { content: "\f152"; }
.si-stitcher.si--color::before { color: #000000; }
.si-stmicroelectronics::before { content: "\f153"; }
.si-stmicroelectronics.si--color::before { color: #03234B; }
.si-stopstalk::before { content: "\f154"; }
.si-stopstalk.si--color::before { color: #536DFE; }
.si-storyblok::before { content: "\f155"; }
.si-storyblok.si--color::before { color: #09B3AF; }
.si-strapi::before { content: "\f156"; }
.si-strapi.si--color::before { color: #2F2E8B; }
.si-storybook::before { content: "\f157"; }
.si-storybook.si--color::before { color: #FF4785; }
.si-streamlit::before { content: "\f158"; }
.si-streamlit.si--color::before { color: #FF4B4B; }
.si-strava::before { content: "\f159"; }
.si-strava.si--color::before { color: #FC4C02; }
.si-stripe::before { content: "\f15a"; }
.si-stripe.si--color::before { color: #008CDD; }
.si-strongswan::before { content: "\f15b"; }
.si-strongswan.si--color::before { color: #E00033; }
.si-stubhub::before { content: "\f15c"; }
.si-stubhub.si--color::before { color: #003168; }
.si-styledcomponents::before { content: "\f15d"; }
.si-styledcomponents.si--color::before { color: #DB7093; }
.si-stylelint::before { content: "\f15e"; }
.si-stylelint.si--color::before { color: #263238; }
.si-styleshare::before { content: "\f15f"; }
.si-styleshare.si--color::before { color: #212121; }
.si-stylus::before { content: "\f160"; }
.si-stylus.si--color::before { color: #333333; }
.si-subaru::before { content: "\f161"; }
.si-subaru.si--color::before { color: #013C74; }
.si-sublimetext::before { content: "\f162"; }
.si-sublimetext.si--color::before { color: #FF9800; }
.si-substack::before { content: "\f163"; }
.si-substack.si--color::before { color: #FF6719; }
.si-subversion::before { content: "\f164"; }
.si-subversion.si--color::before { color: #809CC9; }
.si-suckless::before { content: "\f165"; }
.si-suckless.si--color::before { color: #1177AA; }
.si-supabase::before { content: "\f166"; }
.si-supabase.si--color::before { color: #3ECF8E; }
.si-sumologic::before { content: "\f167"; }
.si-sumologic.si--color::before { color: #000099; }
.si-superuser::before { content: "\f168"; }
.si-superuser.si--color::before { color: #38A1CE; }
.si-supermicro::before { content: "\f169"; }
.si-supermicro.si--color::before { color: #151F6D; }
.si-suse::before { content: "\f16a"; }
.si-suse.si--color::before { color: #0C322C; }
.si-surveymonkey::before { content: "\f16b"; }
.si-surveymonkey.si--color::before { color: #00BF6F; }
.si-suzuki::before { content: "\f16c"; }
.si-suzuki.si--color::before { color: #E30613; }
.si-svelte::before { content: "\f16d"; }
.si-svelte.si--color::before { color: #FF3E00; }
.si-svg::before { content: "\f16e"; }
.si-svg.si--color::before { color: #FFB13B; }
.si-svgo::before { content: "\f16f"; }
.si-svgo.si--color::before { color: #3E7FC1; }
.si-swagger::before { content: "\f170"; }
.si-swagger.si--color::before { color: #85EA2D; }
.si-swarm::before { content: "\f171"; }
.si-swarm.si--color::before { color: #FFA633; }
.si-swc::before { content: "\f172"; }
.si-swc.si--color::before { color: #FFFFFF; }
.si-swift::before { content: "\f173"; }
.si-swift.si--color::before { color: #F05138; }
.si-swiggy::before { content: "\f174"; }
.si-swiggy.si--color::before { color: #FC8019; }
.si-swiper::before { content: "\f175"; }
.si-swiper.si--color::before { color: #6332F6; }
.si-symantec::before { content: "\f176"; }
.si-symantec.si--color::before { color: #FDB511; }
.si-symfony::before { content: "\f177"; }
.si-symfony.si--color::before { color: #000000; }
.si-sympy::before { content: "\f178"; }
.si-sympy.si--color::before { color: #3B5526; }
.si-symphony::before { content: "\f179"; }
.si-symphony.si--color::before { color: #0098FF; }
.si-synology::before { content: "\f17a"; }
.si-synology.si--color::before { color: #B5B5B6; }
.si-tmobile::before { content: "\f17b"; }
.si-tmobile.si--color::before { color: #E20074; }
.si-tableau::before { content: "\f17c"; }
.si-tableau.si--color::before { color: #E97627; }
.si-tado::before { content: "\f17d"; }
.si-tado.si--color::before { color: #FFA900; }
.si-tails::before { content: "\f17e"; }
.si-tails.si--color::before { color: #56347C; }
.si-tailwindcss::before { content: "\f17f"; }
.si-tailwindcss.si--color::before { color: #06B6D4; }
.si-talend::before { content: "\f180"; }
.si-talend.si--color::before { color: #FF6D70; }
.si-talenthouse::before { content: "\f181"; }
.si-talenthouse.si--color::before { color: #FFFFFF; }
.si-taobao::before { content: "\f182"; }
.si-taobao.si--color::before { color: #E94F20; }
.si-tampermonkey::before { content: "\f183"; }
.si-tampermonkey.si--color::before { color: #00485B; }
.si-tapas::before { content: "\f184"; }
.si-tapas.si--color::before { color: #FFCE00; }
.si-target::before { content: "\f185"; }
.si-target.si--color::before { color: #CC0000; }
.si-tasmota::before { content: "\f186"; }
.si-tasmota.si--color::before { color: #1FA3EC; }
.si-tata::before { content: "\f187"; }
.si-tata.si--color::before { color: #486AAE; }
.si-tauri::before { content: "\f188"; }
.si-tauri.si--color::before { color: #FFC131; }
.si-taxbuzz::before { content: "\f189"; }
.si-taxbuzz.si--color::before { color: #ED8B0B; }
.si-teamcity::before { content: "\f18a"; }
.si-teamcity.si--color::before { color: #000000; }
.si-teamspeak::before { content: "\f18b"; }
.si-teamspeak.si--color::before { color: #2580C3; }
.si-teamviewer::before { content: "\f18c"; }
.si-teamviewer.si--color::before { color: #004680; }
.si-ted::before { content: "\f18d"; }
.si-ted.si--color::before { color: #E62B1E; }
.si-teespring::before { content: "\f18e"; }
.si-teespring.si--color::before { color: #ED2761; }
.si-tekton::before { content: "\f18f"; }
.si-tekton.si--color::before { color: #FD495C; }
.si-tele5::before { content: "\f190"; }
.si-tele5.si--color::before { color: #C2AD6F; }
.si-telegram::before { content: "\f191"; }
.si-telegram.si--color::before { color: #26A5E4; }
.si-temporal::before { content: "\f192"; }
.si-temporal.si--color::before { color: #000000; }
.si-telegraph::before { content: "\f193"; }
.si-telegraph.si--color::before { color: #FAFAFA; }
.si-tencentqq::before { content: "\f194"; }
.si-tencentqq.si--color::before { color: #EB1923; }
.si-tensorflow::before { content: "\f195"; }
.si-tensorflow.si--color::before { color: #FF6F00; }
.si-teradata::before { content: "\f196"; }
.si-teradata.si--color::before { color: #F37440; }
.si-terraform::before { content: "\f197"; }
.si-terraform.si--color::before { color: #7B42BC; }
.si-teratail::before { content: "\f198"; }
.si-teratail.si--color::before { color: #F4C51C; }
.si-tesco::before { content: "\f199"; }
.si-tesco.si--color::before { color: #00539F; }
.si-tesla::before { content: "\f19a"; }
.si-tesla.si--color::before { color: #CC0000; }
.si-testcafe::before { content: "\f19b"; }
.si-testcafe.si--color::before { color: #36B6E5; }
.si-testin::before { content: "\f19c"; }
.si-testin.si--color::before { color: #007DD7; }
.si-testinglibrary::before { content: "\f19d"; }
.si-testinglibrary.si--color::before { color: #E33332; }
.si-tether::before { content: "\f19e"; }
.si-tether.si--color::before { color: #50AF95; }
.si-thealgorithms::before { content: "\f19f"; }
.si-thealgorithms.si--color::before { color: #00BCB4; }
.si-textpattern::before { content: "\f1a0"; }
.si-textpattern.si--color::before { color: #FFDA44; }
.si-theconversation::before { content: "\f1a1"; }
.si-theconversation.si--color::before { color: #D8352A; }
.si-theirishtimes::before { content: "\f1a2"; }
.si-theirishtimes.si--color::before { color: #000000; }
.si-themighty::before { content: "\f1a3"; }
.si-themighty.si--color::before { color: #D0072A; }
.si-themodelsresource::before { content: "\f1a4"; }
.si-themodelsresource.si--color::before { color: #3A75BD; }
.si-themoviedatabase::before { content: "\f1a5"; }
.si-themoviedatabase.si--color::before { color: #01B4E4; }
.si-thenorthface::before { content: "\f1a6"; }
.si-thenorthface.si--color::before { color: #000000; }
.si-theregister::before { content: "\f1a7"; }
.si-theregister.si--color::before { color: #FF0000; }
.si-thesoundsresource::before { content: "\f1a8"; }
.si-thesoundsresource.si--color::before { color: #39BE6B; }
.si-thespritersresource::before { content: "\f1a9"; }
.si-thespritersresource.si--color::before { color: #BE3939; }
.si-thewashingtonpost::before { content: "\f1aa"; }
.si-thewashingtonpost.si--color::before { color: #231F20; }
.si-thingiverse::before { content: "\f1ab"; }
.si-thingiverse.si--color::before { color: #248BFB; }
.si-thinkpad::before { content: "\f1ac"; }
.si-thinkpad.si--color::before { color: #EE2624; }
.si-threadless::before { content: "\f1ad"; }
.si-threadless.si--color::before { color: #0099FF; }
.si-threedotjs::before { content: "\f1ae"; }
.si-threedotjs.si--color::before { color: #000000; }
.si-threema::before { content: "\f1af"; }
.si-threema.si--color::before { color: #3FE669; }
.si-thumbtack::before { content: "\f1b0"; }
.si-thumbtack.si--color::before { color: #009FD9; }
.si-thunderbird::before { content: "\f1b1"; }
.si-thunderbird.si--color::before { color: #0A84FF; }
.si-thymeleaf::before { content: "\f1b2"; }
.si-thymeleaf.si--color::before { color: #005F0F; }
.si-ticketmaster::before { content: "\f1b3"; }
.si-ticketmaster.si--color::before { color: #026CDF; }
.si-tidal::before { content: "\f1b4"; }
.si-tidal.si--color::before { color: #000000; }
.si-tide::before { content: "\f1b5"; }
.si-tide.si--color::before { color: #4050FB; }
.si-tietoevry::before { content: "\f1b6"; }
.si-tietoevry.si--color::before { color: #063752; }
.si-tiktok::before { content: "\f1b7"; }
.si-tiktok.si--color::before { color: #000000; }
.si-tile::before { content: "\f1b8"; }
.si-tile.si--color::before { color: #000000; }
.si-timescale::before { content: "\f1b9"; }
.si-timescale.si--color::before { color: #FDB515; }
.si-tinder::before { content: "\f1ba"; }
.si-tinder.si--color::before { color: #FF6B6B; }
.si-tinyletter::before { content: "\f1bb"; }
.si-tinyletter.si--color::before { color: #ED1C24; }
.si-tmux::before { content: "\f1bc"; }
.si-tmux.si--color::before { color: #1BB91F; }
.si-todoist::before { content: "\f1bd"; }
.si-todoist.si--color::before { color: #E44332; }
.si-toggl::before { content: "\f1be"; }
.si-toggl.si--color::before { color: #E01B22; }
.si-tokyometro::before { content: "\f1bf"; }
.si-tokyometro.si--color::before { color: #149DD3; }
.si-tomorrowland::before { content: "\f1c0"; }
.si-tomorrowland.si--color::before { color: #000000; }
.si-topcoder::before { content: "\f1c1"; }
.si-topcoder.si--color::before { color: #29A7DF; }
.si-toptal::before { content: "\f1c2"; }
.si-toptal.si--color::before { color: #3863A0; }
.si-torbrowser::before { content: "\f1c3"; }
.si-torbrowser.si--color::before { color: #7D4698; }
.si-torproject::before { content: "\f1c4"; }
.si-torproject.si--color::before { color: #7E4798; }
.si-toshiba::before { content: "\f1c5"; }
.si-toshiba.si--color::before { color: #FF0000; }
.si-toyota::before { content: "\f1c6"; }
.si-toyota.si--color::before { color: #EB0A1E; }
.si-tplink::before { content: "\f1c7"; }
.si-tplink.si--color::before { color: #4ACBD6; }
.si-tqdm::before { content: "\f1c8"; }
.si-tqdm.si--color::before { color: #FFC107; }
.si-traefikmesh::before { content: "\f1c9"; }
.si-traefikmesh.si--color::before { color: #9D0FB0; }
.si-trainerroad::before { content: "\f1ca"; }
.si-trainerroad.si--color::before { color: #DA291C; }
.si-trakt::before { content: "\f1cb"; }
.si-trakt.si--color::before { color: #ED1C24; }
.si-transferwise::before { content: "\f1cc"; }
.si-transferwise.si--color::before { color: #00B9FF; }
.si-transportforireland::before { content: "\f1cd"; }
.si-transportforireland.si--color::before { color: #00B274; }
.si-transportforlondon::before { content: "\f1ce"; }
.si-transportforlondon.si--color::before { color: #113B92; }
.si-travisci::before { content: "\f1cf"; }
.si-travisci.si--color::before { color: #3EAAAF; }
.si-treehouse::before { content: "\f1d0"; }
.si-treehouse.si--color::before { color: #5FCF80; }
.si-trendmicro::before { content: "\f1d1"; }
.si-trendmicro.si--color::before { color: #D71921; }
.si-trello::before { content: "\f1d2"; }
.si-trello.si--color::before { color: #0052CC; }
.si-treyarch::before { content: "\f1d3"; }
.si-treyarch.si--color::before { color: #000000; }
.si-triller::before { content: "\f1d4"; }
.si-triller.si--color::before { color: #FF0089; }
.si-trino::before { content: "\f1d5"; }
.si-trino.si--color::before { color: #DD00A1; }
.si-tripdotcom::before { content: "\f1d6"; }
.si-tripdotcom.si--color::before { color: #287DFA; }
.si-tripadvisor::before { content: "\f1d7"; }
.si-tripadvisor.si--color::before { color: #34E0A1; }
.si-trove::before { content: "\f1d8"; }
.si-trove.si--color::before { color: #2D004B; }
.si-truenas::before { content: "\f1d9"; }
.si-truenas.si--color::before { color: #0095D5; }
.si-trulia::before { content: "\f1da"; }
.si-trulia.si--color::before { color: #0A0B09; }
.si-trustedshops::before { content: "\f1db"; }
.si-trustedshops.si--color::before { color: #FFDC0F; }
.si-trustpilot::before { content: "\f1dc"; }
.si-trustpilot.si--color::before { color: #00B67A; }
.si-tryitonline::before { content: "\f1dd"; }
.si-tryitonline.si--color::before { color: #303030; }
.si-tryhackme::before { content: "\f1de"; }
.si-tryhackme.si--color::before { color: #212C42; }
.si-tubi::before { content: "\f1df"; }
.si-tubi.si--color::before { color: #000000; }
.si-tsnode::before { content: "\f1e0"; }
.si-tsnode.si--color::before { color: #3178C6; }
.si-tui::before { content: "\f1e1"; }
.si-tui.si--color::before { color: #D40E14; }
.si-tumblr::before { content: "\f1e2"; }
.si-tumblr.si--color::before { color: #36465D; }
.si-tunein::before { content: "\f1e3"; }
.si-tunein.si--color::before { color: #14D8CC; }
.si-turborepo::before { content: "\f1e4"; }
.si-turborepo.si--color::before { color: #EF4444; }
.si-turbosquid::before { content: "\f1e5"; }
.si-turbosquid.si--color::before { color: #FF8135; }
.si-turkishairlines::before { content: "\f1e6"; }
.si-turkishairlines.si--color::before { color: #C70A0C; }
.si-tutanota::before { content: "\f1e7"; }
.si-tutanota.si--color::before { color: #840010; }
.si-twilio::before { content: "\f1e8"; }
.si-twilio.si--color::before { color: #F22F46; }
.si-tvtime::before { content: "\f1e9"; }
.si-tvtime.si--color::before { color: #FFD400; }
.si-twitter::before { content: "\f1ea"; }
.si-twitter.si--color::before { color: #1DA1F2; }
.si-twitch::before { content: "\f1eb"; }
.si-twitch.si--color::before { color: #9146FF; }
.si-typeform::before { content: "\f1ec"; }
.si-typeform.si--color::before { color: #262627; }
.si-twoo::before { content: "\f1ed"; }
.si-twoo.si--color::before { color: #FF7102; }
.si-typescript::before { content: "\f1ee"; }
.si-typescript.si--color::before { color: #3178C6; }
.si-angellist::before { content: "\f1ef"; }
.si-angellist.si--color::before { color: #000000; }
.si-uber::before { content: "\f1f0"; }
.si-uber.si--color::before { color: #000000; }
.si-ubereats::before { content: "\f1f1"; }
.si-ubereats.si--color::before { color: #06C167; }
.si-ubiquiti::before { content: "\f1f2"; }
.si-ubiquiti.si--color::before { color: #0559C9; }
.si-ubisoft::before { content: "\f1f3"; }
.si-ubisoft.si--color::before { color: #000000; }
.si-ublockorigin::before { content: "\f1f4"; }
.si-ublockorigin.si--color::before { color: #800000; }
.si-ubuntu::before { content: "\f1f5"; }
.si-ubuntu.si--color::before { color: #E95420; }
.si-udacity::before { content: "\f1f6"; }
.si-udacity.si--color::before { color: #02B3E4; }
.si-udemy::before { content: "\f1f7"; }
.si-udemy.si--color::before { color: #A435F0; }
.si-uikit::before { content: "\f1f8"; }
.si-uikit.si--color::before { color: #2396F3; }
.si-ufc::before { content: "\f1f9"; }
.si-ufc.si--color::before { color: #D20A0A; }
.si-ulule::before { content: "\f1fa"; }
.si-ulule.si--color::before { color: #18A5D6; }
.si-umbraco::before { content: "\f1fb"; }
.si-umbraco.si--color::before { color: #3544B1; }
.si-unacademy::before { content: "\f1fc"; }
.si-unacademy.si--color::before { color: #08BD80; }
.si-underarmour::before { content: "\f1fd"; }
.si-underarmour.si--color::before { color: #1D1D1D; }
.si-underscoredotjs::before { content: "\f1fe"; }
.si-underscoredotjs.si--color::before { color: #0371B5; }
.si-undertale::before { content: "\f1ff"; }
.si-undertale.si--color::before { color: #E71D29; }
.si-unicode::before { content: "\f200"; }
.si-unicode.si--color::before { color: #5455FE; }
.si-unilever::before { content: "\f201"; }
.si-unilever.si--color::before { color: #1F36C7; }
.si-unitedairlines::before { content: "\f202"; }
.si-unitedairlines.si--color::before { color: #002244; }
.si-unity::before { content: "\f203"; }
.si-unity.si--color::before { color: #FFFFFF; }
.si-unraid::before { content: "\f204"; }
.si-unraid.si--color::before { color: #F15A2C; }
.si-unrealengine::before { content: "\f205"; }
.si-unrealengine.si--color::before { color: #0E1128; }
.si-untangle::before { content: "\f206"; }
.si-untangle.si--color::before { color: #68BD49; }
.si-untappd::before { content: "\f207"; }
.si-untappd.si--color::before { color: #FFC000; }
.si-unsplash::before { content: "\f208"; }
.si-unsplash.si--color::before { color: #000000; }
.si-upcloud::before { content: "\f209"; }
.si-upcloud.si--color::before { color: #7B00FF; }
.si-uplabs::before { content: "\f20a"; }
.si-uplabs.si--color::before { color: #3930D8; }
.si-uploaded::before { content: "\f20b"; }
.si-uploaded.si--color::before { color: #0E70CB; }
.si-upstash::before { content: "\f20c"; }
.si-upstash.si--color::before { color: #00E9A3; }
.si-ups::before { content: "\f20d"; }
.si-ups.si--color::before { color: #150400; }
.si-uptobox::before { content: "\f20e"; }
.si-uptobox.si--color::before { color: #5CE1E6; }
.si-upwork::before { content: "\f20f"; }
.si-upwork.si--color::before { color: #6FDA44; }
.si-usps::before { content: "\f210"; }
.si-usps.si--color::before { color: #333366; }
.si-v::before { content: "\f211"; }
.si-v.si--color::before { color: #5D87BF; }
.si-v8::before { content: "\f212"; }
.si-v8.si--color::before { color: #4B8BF5; }
.si-vaadin::before { content: "\f213"; }
.si-vaadin.si--color::before { color: #00B4F0; }
.si-vagrant::before { content: "\f214"; }
.si-vagrant.si--color::before { color: #1868F2; }
.si-valorant::before { content: "\f215"; }
.si-valorant.si--color::before { color: #FA4454; }
.si-vapor::before { content: "\f216"; }
.si-vapor.si--color::before { color: #0D0D0D; }
.si-valve::before { content: "\f217"; }
.si-valve.si--color::before { color: #F74843; }
.si-vault::before { content: "\f218"; }
.si-vault.si--color::before { color: #000000; }
.si-vauxhall::before { content: "\f219"; }
.si-vauxhall.si--color::before { color: #EB001E; }
.si-vbulletin::before { content: "\f21a"; }
.si-vbulletin.si--color::before { color: #184D66; }
.si-vectorlogozone::before { content: "\f21b"; }
.si-vectorlogozone.si--color::before { color: #184D66; }
.si-vectorworks::before { content: "\f21c"; }
.si-vectorworks.si--color::before { color: #000000; }
.si-veeam::before { content: "\f21d"; }
.si-veeam.si--color::before { color: #00B336; }
.si-velog::before { content: "\f21e"; }
.si-velog.si--color::before { color: #20C997; }
.si-veepee::before { content: "\f21f"; }
.si-veepee.si--color::before { color: #EC008C; }
.si-venmo::before { content: "\f220"; }
.si-venmo.si--color::before { color: #3D95CE; }
.si-vercel::before { content: "\f221"; }
.si-vercel.si--color::before { color: #000000; }
.si-verdaccio::before { content: "\f222"; }
.si-verdaccio.si--color::before { color: #4B5E40; }
.si-veritas::before { content: "\f223"; }
.si-veritas.si--color::before { color: #B1181E; }
.si-verizon::before { content: "\f224"; }
.si-verizon.si--color::before { color: #CD040B; }
.si-vexxhost::before { content: "\f225"; }
.si-vexxhost.si--color::before { color: #2A1659; }
.si-vfairs::before { content: "\f226"; }
.si-vfairs.si--color::before { color: #EF4678; }
.si-viadeo::before { content: "\f227"; }
.si-viadeo.si--color::before { color: #F07355; }
.si-viber::before { content: "\f228"; }
.si-viber.si--color::before { color: #7360F2; }
.si-vim::before { content: "\f229"; }
.si-vim.si--color::before { color: #019733; }
.si-vimeo::before { content: "\f22a"; }
.si-vimeo.si--color::before { color: #1AB7EA; }
.si-virgin::before { content: "\f22b"; }
.si-virgin.si--color::before { color: #E10A0A; }
.si-vimeolivestream::before { content: "\f22c"; }
.si-vimeolivestream.si--color::before { color: #0A0A20; }
.si-virtualbox::before { content: "\f22d"; }
.si-virtualbox.si--color::before { color: #183A61; }
.si-virustotal::before { content: "\f22e"; }
.si-virustotal.si--color::before { color: #394EFF; }
.si-visa::before { content: "\f22f"; }
.si-visa.si--color::before { color: #1A1F71; }
.si-visualstudio::before { content: "\f230"; }
.si-visualstudio.si--color::before { color: #5C2D91; }
.si-vite::before { content: "\f231"; }
.si-vite.si--color::before { color: #646CFF; }
.si-visualstudiocode::before { content: "\f232"; }
.si-visualstudiocode.si--color::before { color: #007ACC; }
.si-vivaldi::before { content: "\f233"; }
.si-vivaldi.si--color::before { color: #EF3939; }
.si-vivino::before { content: "\f234"; }
.si-vivino.si--color::before { color: #AA1329; }
.si-vk::before { content: "\f235"; }
.si-vk.si--color::before { color: #0077FF; }
.si-vlcmediaplayer::before { content: "\f236"; }
.si-vlcmediaplayer.si--color::before { color: #FF8800; }
.si-vmware::before { content: "\f237"; }
.si-vmware.si--color::before { color: #607078; }
.si-volkswagen::before { content: "\f238"; }
.si-volkswagen.si--color::before { color: #151F5D; }
.si-vodafone::before { content: "\f239"; }
.si-vodafone.si--color::before { color: #E60000; }
.si-volvo::before { content: "\f23a"; }
.si-volvo.si--color::before { color: #003057; }
.si-vonage::before { content: "\f23b"; }
.si-vonage.si--color::before { color: #FFFFFF; }
.si-vowpalwabbit::before { content: "\f23c"; }
.si-vowpalwabbit.si--color::before { color: #FF81F9; }
.si-vox::before { content: "\f23d"; }
.si-vox.si--color::before { color: #DA074A; }
.si-vsco::before { content: "\f23e"; }
.si-vsco.si--color::before { color: #000000; }
.si-vtex::before { content: "\f23f"; }
.si-vtex.si--color::before { color: #ED125F; }
.si-vuedotjs::before { content: "\f240"; }
.si-vuedotjs.si--color::before { color: #4FC08D; }
.si-vuetify::before { content: "\f241"; }
.si-vuetify.si--color::before { color: #1867C0; }
.si-vultr::before { content: "\f242"; }
.si-vultr.si--color::before { color: #007BFC; }
.si-vulkan::before { content: "\f243"; }
.si-vulkan.si--color::before { color: #AC162C; }
.si-w3c::before { content: "\f244"; }
.si-w3c.si--color::before { color: #005A9C; }
.si-wagtail::before { content: "\f245"; }
.si-wagtail.si--color::before { color: #43B1B0; }
.si-wakatime::before { content: "\f246"; }
.si-wakatime.si--color::before { color: #000000; }
.si-walkman::before { content: "\f247"; }
.si-walkman.si--color::before { color: #000000; }
.si-wallabag::before { content: "\f248"; }
.si-wallabag.si--color::before { color: #3F6184; }
.si-walmart::before { content: "\f249"; }
.si-walmart.si--color::before { color: #0071CE; }
.si-wappalyzer::before { content: "\f24a"; }
.si-wappalyzer.si--color::before { color: #32067C; }
.si-warnerbros::before { content: "\f24b"; }
.si-warnerbros.si--color::before { color: #004DB4; }
.si-wattpad::before { content: "\f24c"; }
.si-wattpad.si--color::before { color: #FF500A; }
.si-waze::before { content: "\f24d"; }
.si-waze.si--color::before { color: #33CCFF; }
.si-wearos::before { content: "\f24e"; }
.si-wearos.si--color::before { color: #4285F4; }
.si-weasyl::before { content: "\f24f"; }
.si-weasyl.si--color::before { color: #990000; }
.si-web3dotjs::before { content: "\f250"; }
.si-web3dotjs.si--color::before { color: #F16822; }
.si-webassembly::before { content: "\f251"; }
.si-webassembly.si--color::before { color: #654FF0; }
.si-webauthn::before { content: "\f252"; }
.si-webauthn.si--color::before { color: #3423A6; }
.si-webcomponentsdotorg::before { content: "\f253"; }
.si-webcomponentsdotorg.si--color::before { color: #29ABE2; }
.si-webdriverio::before { content: "\f254"; }
.si-webdriverio.si--color::before { color: #EA5906; }
.si-webflow::before { content: "\f255"; }
.si-webflow.si--color::before { color: #4353FF; }
.si-webhint::before { content: "\f256"; }
.si-webhint.si--color::before { color: #4700A3; }
.si-webgl::before { content: "\f257"; }
.si-webgl.si--color::before { color: #990000; }
.si-weblate::before { content: "\f258"; }
.si-weblate.si--color::before { color: #2ECCAA; }
.si-webmin::before { content: "\f259"; }
.si-webmin.si--color::before { color: #7DA0D0; }
.si-webmoney::before { content: "\f25a"; }
.si-webmoney.si--color::before { color: #036CB5; }
.si-webpack::before { content: "\f25b"; }
.si-webpack.si--color::before { color: #8DD6F9; }
.si-webrtc::before { content: "\f25c"; }
.si-webrtc.si--color::before { color: #333333; }
.si-webstorm::before { content: "\f25d"; }
.si-webstorm.si--color::before { color: #000000; }
.si-webtoon::before { content: "\f25e"; }
.si-webtoon.si--color::before { color: #00D564; }
.si-wechat::before { content: "\f25f"; }
.si-wechat.si--color::before { color: #07C160; }
.si-wegame::before { content: "\f260"; }
.si-wegame.si--color::before { color: #FAAB00; }
.si-weightsandbiases::before { content: "\f261"; }
.si-weightsandbiases.si--color::before { color: #FFBE00; }
.si-welcometothejungle::before { content: "\f262"; }
.si-welcometothejungle.si--color::before { color: #FFCD00; }
.si-wemo::before { content: "\f263"; }
.si-wemo.si--color::before { color: #72D44C; }
.si-westerndigital::before { content: "\f264"; }
.si-westerndigital.si--color::before { color: #000000; }
.si-wetransfer::before { content: "\f265"; }
.si-wetransfer.si--color::before { color: #409FFF; }
.si-whatsapp::before { content: "\f266"; }
.si-whatsapp.si--color::before { color: #25D366; }
.si-wheniwork::before { content: "\f267"; }
.si-wheniwork.si--color::before { color: #51A33D; }
.si-wii::before { content: "\f268"; }
.si-wii.si--color::before { color: #8B8B8B; }
.si-whitesource::before { content: "\f269"; }
.si-whitesource.si--color::before { color: #161D4E; }
.si-wiiu::before { content: "\f26a"; }
.si-wiiu.si--color::before { color: #8B8B8B; }
.si-wikidotjs::before { content: "\f26b"; }
.si-wikidotjs.si--color::before { color: #1976D2; }
.si-wikidata::before { content: "\f26c"; }
.si-wikidata.si--color::before { color: #006699; }
.si-wikimediacommons::before { content: "\f26d"; }
.si-wikimediacommons.si--color::before { color: #006699; }
.si-wikipedia::before { content: "\f26e"; }
.si-wikipedia.si--color::before { color: #000000; }
.si-wikiquote::before { content: "\f26f"; }
.si-wikiquote.si--color::before { color: #006699; }
.si-wikivoyage::before { content: "\f270"; }
.si-wikivoyage.si--color::before { color: #006699; }
.si-winamp::before { content: "\f271"; }
.si-winamp.si--color::before { color: #F93821; }
.si-windicss::before { content: "\f272"; }
.si-windicss.si--color::before { color: #48B0F1; }
.si-windows::before { content: "\f273"; }
.si-windows.si--color::before { color: #0078D6; }
.si-windows95::before { content: "\f274"; }
.si-windows95.si--color::before { color: #008080; }
.si-windowsterminal::before { content: "\f275"; }
.si-windowsterminal.si--color::before { color: #4D4D4D; }
.si-winmate::before { content: "\f276"; }
.si-winmate.si--color::before { color: #C11920; }
.si-windowsxp::before { content: "\f277"; }
.si-windowsxp.si--color::before { color: #003399; }
.si-wire::before { content: "\f278"; }
.si-wire.si--color::before { color: #000000; }
.si-wipro::before { content: "\f279"; }
.si-wipro.si--color::before { color: #341C53; }
.si-wireguard::before { content: "\f27a"; }
.si-wireguard.si--color::before { color: #88171A; }
.si-wireshark::before { content: "\f27b"; }
.si-wireshark.si--color::before { color: #1679A7; }
.si-wise::before { content: "\f27c"; }
.si-wise.si--color::before { color: #00B9FF; }
.si-wish::before { content: "\f27d"; }
.si-wish.si--color::before { color: #2FB7EC; }
.si-wistia::before { content: "\f27e"; }
.si-wistia.si--color::before { color: #54BBFF; }
.si-wix::before { content: "\f27f"; }
.si-wix.si--color::before { color: #0C6EFC; }
.si-wizzair::before { content: "\f280"; }
.si-wizzair.si--color::before { color: #C6007E; }
.si-wolfram::before { content: "\f281"; }
.si-wolfram.si--color::before { color: #DD1100; }
.si-wolframlanguage::before { content: "\f282"; }
.si-wolframlanguage.si--color::before { color: #DD1100; }
.si-wolframmathematica::before { content: "\f283"; }
.si-wolframmathematica.si--color::before { color: #DD1100; }
.si-woo::before { content: "\f284"; }
.si-woo.si--color::before { color: #96588A; }
.si-woocommerce::before { content: "\f285"; }
.si-woocommerce.si--color::before { color: #96588A; }
.si-wordpress::before { content: "\f286"; }
.si-wordpress.si--color::before { color: #21759B; }
.si-workplace::before { content: "\f287"; }
.si-workplace.si--color::before { color: #4326C4; }
.si-worldhealthorganization::before { content: "\f288"; }
.si-worldhealthorganization.si--color::before { color: #0093D5; }
.si-wpengine::before { content: "\f289"; }
.si-wpengine.si--color::before { color: #0ECAD4; }
.si-wprocket::before { content: "\f28a"; }
.si-wprocket.si--color::before { color: #F56640; }
.si-writedotas::before { content: "\f28b"; }
.si-writedotas.si--color::before { color: #5BC4EE; }
.si-wwe::before { content: "\f28c"; }
.si-wwe.si--color::before { color: #000000; }
.si-wwise::before { content: "\f28d"; }
.si-wwise.si--color::before { color: #00549F; }
.si-xdotorg::before { content: "\f28e"; }
.si-xdotorg.si--color::before { color: #F28834; }
.si-xamarin::before { content: "\f28f"; }
.si-xamarin.si--color::before { color: #3498DB; }
.si-xaml::before { content: "\f290"; }
.si-xaml.si--color::before { color: #0C54C2; }
.si-xampp::before { content: "\f291"; }
.si-xampp.si--color::before { color: #FB7A24; }
.si-xbox::before { content: "\f292"; }
.si-xbox.si--color::before { color: #107C10; }
.si-xcode::before { content: "\f293"; }
.si-xcode.si--color::before { color: #147EFB; }
.si-xdadevelopers::before { content: "\f294"; }
.si-xdadevelopers.si--color::before { color: #EA7100; }
.si-xero::before { content: "\f295"; }
.si-xero.si--color::before { color: #13B5EA; }
.si-xfce::before { content: "\f296"; }
.si-xfce.si--color::before { color: #2284F2; }
.si-xiaomi::before { content: "\f297"; }
.si-xiaomi.si--color::before { color: #FF6900; }
.si-xing::before { content: "\f298"; }
.si-xing.si--color::before { color: #006567; }
.si-xilinx::before { content: "\f299"; }
.si-xilinx.si--color::before { color: #E01F27; }
.si-xmpp::before { content: "\f29a"; }
.si-xmpp.si--color::before { color: #002B5C; }
.si-xrp::before { content: "\f29b"; }
.si-xrp.si--color::before { color: #25A768; }
.si-xsplit::before { content: "\f29c"; }
.si-xsplit.si--color::before { color: #0095DE; }
.si-xstate::before { content: "\f29d"; }
.si-xstate.si--color::before { color: #2C3E50; }
.si-yahoo::before { content: "\f29e"; }
.si-yahoo.si--color::before { color: #6001D2; }
.si-ycombinator::before { content: "\f29f"; }
.si-ycombinator.si--color::before { color: #F0652F; }
.si-yale::before { content: "\f2a0"; }
.si-yale.si--color::before { color: #FFD900; }
.si-yamahacorporation::before { content: "\f2a1"; }
.si-yamahacorporation.si--color::before { color: #4B1E78; }
.si-yamahamotorcorporation::before { content: "\f2a2"; }
.si-yamahamotorcorporation.si--color::before { color: #E60012; }
.si-yammer::before { content: "\f2a3"; }
.si-yammer.si--color::before { color: #106EBE; }
.si-yelp::before { content: "\f2a4"; }
.si-yelp.si--color::before { color: #D32323; }
.si-yarn::before { content: "\f2a5"; }
.si-yarn.si--color::before { color: #2C8EBB; }
.si-yoast::before { content: "\f2a6"; }
.si-yoast.si--color::before { color: #A4286A; }
.si-yolo::before { content: "\f2a7"; }
.si-yolo.si--color::before { color: #00FFFF; }
.si-youtube::before { content: "\f2a8"; }
.si-youtube.si--color::before { color: #FF0000; }
.si-yourtraveldottv::before { content: "\f2a9"; }
.si-yourtraveldottv.si--color::before { color: #F79025; }
.si-youtubegaming::before { content: "\f2aa"; }
.si-youtubegaming.si--color::before { color: #FF0000; }
.si-youtubemusic::before { content: "\f2ab"; }
.si-youtubemusic.si--color::before { color: #FF0000; }
.si-youtubestudio::before { content: "\f2ac"; }
.si-youtubestudio.si--color::before { color: #FF0000; }
.si-youtubetv::before { content: "\f2ad"; }
.si-youtubetv.si--color::before { color: #FF0000; }
.si-yubico::before { content: "\f2ae"; }
.si-yubico.si--color::before { color: #84BD00; }
.si-zwave::before { content: "\f2af"; }
.si-zwave.si--color::before { color: #1B365D; }
.si-zabka::before { content: "\f2b0"; }
.si-zabka.si--color::before { color: #006420; }
.si-zalando::before { content: "\f2b1"; }
.si-zalando.si--color::before { color: #FF6900; }
.si-zalo::before { content: "\f2b2"; }
.si-zalo.si--color::before { color: #0068FF; }
.si-zapier::before { content: "\f2b3"; }
.si-zapier.si--color::before { color: #FF4A00; }
.si-zara::before { content: "\f2b4"; }
.si-zara.si--color::before { color: #000000; }
.si-zazzle::before { content: "\f2b5"; }
.si-zazzle.si--color::before { color: #212121; }
.si-zdf::before { content: "\f2b6"; }
.si-zdf.si--color::before { color: #FA7D19; }
.si-zcash::before { content: "\f2b7"; }
.si-zcash.si--color::before { color: #F4B728; }
.si-zelle::before { content: "\f2b8"; }
.si-zelle.si--color::before { color: #6D1ED4; }
.si-zendframework::before { content: "\f2b9"; }
.si-zendframework.si--color::before { color: #68B604; }
.si-zend::before { content: "\f2ba"; }
.si-zend.si--color::before { color: #0679EA; }
.si-zendesk::before { content: "\f2bb"; }
.si-zendesk.si--color::before { color: #03363D; }
.si-zenn::before { content: "\f2bc"; }
.si-zenn.si--color::before { color: #3EA8FF; }
.si-zenodo::before { content: "\f2bd"; }
.si-zenodo.si--color::before { color: #1682D4; }
.si-zerodha::before { content: "\f2be"; }
.si-zerodha.si--color::before { color: #387ED1; }
.si-zeromq::before { content: "\f2bf"; }
.si-zeromq.si--color::before { color: #DF0000; }
.si-zerply::before { content: "\f2c0"; }
.si-zerply.si--color::before { color: #7BBB6E; }
.si-zhihu::before { content: "\f2c1"; }
.si-zhihu.si--color::before { color: #0084FF; }
.si-zig::before { content: "\f2c2"; }
.si-zig.si--color::before { color: #F7A41D; }
.si-zigbee::before { content: "\f2c3"; }
.si-zigbee.si--color::before { color: #EB0443; }
.si-zillow::before { content: "\f2c4"; }
.si-zillow.si--color::before { color: #006AFF; }
.si-zingat::before { content: "\f2c5"; }
.si-zingat.si--color::before { color: #009CFB; }
.si-zoho::before { content: "\f2c6"; }
.si-zoho.si--color::before { color: #C8202B; }
.si-zoiper::before { content: "\f2c7"; }
.si-zoiper.si--color::before { color: #F47920; }
.si-zomato::before { content: "\f2c8"; }
.si-zomato.si--color::before { color: #E23744; }
.si-zorin::before { content: "\f2c9"; }
.si-zorin.si--color::before { color: #0CC1F3; }
.si-zoom::before { content: "\f2ca"; }
.si-zoom.si--color::before { color: #2D8CFF; }
.si-zotero::before { content: "\f2cb"; }
.si-zotero.si--color::before { color: #CC2936; }
.si-zulip::before { content: "\f2cc"; }
.si-zulip.si--color::before { color: #FFFFFF; }
.si-zyte::before { content: "\f2cd"; }
.si-zyte.si--color::before { color: #B02CCE; }
.si-androidstudio::before { content: "\f2ce"; }
.si-androidstudio.si--color::before { color: #3DDC84; }
.si-typo3::before { content: "\f2cf"; }
.si-typo3.si--color::before { color: #FF8700; }